@@ -95,7 +95,7 @@ bool Collection::addField(Tellico::Data::FieldPtr field_) {
   m_fieldByTitle.insert(field_->title(), field_.data());
 
   // always default to using field with title name as title
-  if(field_->name() == QLatin1String("title")) m_titleField = field_->name();
+  if(field_->name() == QLatin1StringView("title")) m_titleField = field_->name();
 
   if(field_->formatType() == FieldFormat::FormatName) {
     m_peopleFields.append(field_); // list of people attributes
@@ -141,7 +141,7 @@ bool Collection::addField(Tellico::Data::FieldPtr field_) {
   // refresh all dependent fields, in case one references this new one
   foreach(FieldPtr existingField, m_fields) {
     if(existingField->hasFlag(Field::Derived)) {
-      emit signalRefreshField(existingField);
+      Q_EMIT signalRefreshField(existingField);
     }
   }
 
@@ -160,7 +160,7 @@ bool Collection::mergeField(Tellico::Data::FieldPtr newField_) {
     Data::FieldPtr f(new Field(*newField_));
     bool success = addField(f);
     if(success) {
-      emit mergeAddedField(CollPtr(this), f);
+      Q_EMIT mergeAddedField(CollPtr(this), f);
     } else {
       myDebug() << "Failed to add field:" << f->name();
     }
@@ -207,10 +207,10 @@ bool Collection::mergeField(Tellico::Data::FieldPtr newField_) {
       currField->setProperty(propName, it.value());
       structuralChange = true;
     } else if (it.value() != currValue) {
-      if(currField->type() == Field::URL && propName == QLatin1String("relative")) {
+      if(currField->type() == Field::URL && propName == QLatin1StringView("relative")) {
         myWarning() << "relative URL property does not match for " << currField->name();
-      } else if((currField->type() == Field::Table && propName == QLatin1String("columns"))
-             || (currField->type() == Field::Rating && propName == QLatin1String("maximum"))) {
+      } else if((currField->type() == Field::Table && propName == QLatin1StringView("columns"))
+             || (currField->type() == Field::Rating && propName == QLatin1StringView("maximum"))) {
         bool ok;
         uint currNum = Tellico::toUInt(currValue, &ok);
         uint newNum = Tellico::toUInt(it.value(), &ok);
@@ -218,7 +218,7 @@ bool Collection::mergeField(Tellico::Data::FieldPtr newField_) {
           currField->setProperty(propName, QString::number(newNum));
           structuralChange = true;
         }
-      } else if(currField->type() == Field::Rating && propName == QLatin1String("minimum")) {
+      } else if(currField->type() == Field::Rating && propName == QLatin1StringView("minimum")) {
         bool ok;
         uint currNum = Tellico::toUInt(currValue, &ok);
         uint newNum = Tellico::toUInt(it.value(), &ok);
@@ -228,7 +228,7 @@ bool Collection::mergeField(Tellico::Data::FieldPtr newField_) {
         }
       }
     }
-    if(propName == QLatin1String("template") && currField->hasFlag(Field::Derived)) {
+    if(propName == QLatin1StringView("template") && currField->hasFlag(Field::Derived)) {
       DerivedValue dv(currField);
       if(dv.isRecursive(this)) {
         currField->setProperty(QStringLiteral("template"), QString());
@@ -369,7 +369,7 @@ bool Collection::modifyField(Tellico::Data::FieldPtr newField_) {
   // now to update all entries if the field is a derived value and the template changed
   if(newField_->hasFlag(Field::Derived) &&
      oldField->property(QStringLiteral("template")) != newField_->property(QStringLiteral("template"))) {
-    emit signalRefreshField(newField_);
+    Q_EMIT signalRefreshField(newField_);
   }
 
   return true;
@@ -430,7 +430,7 @@ bool Collection::removeField(Tellico::Data::FieldPtr field_, bool force_/*=false
   // while removing one, so refresh all of them
   foreach(FieldPtr field, m_fields) {
     if(field->hasFlag(Field::Derived)) {
-      emit signalRefreshField(field);
+      Q_EMIT signalRefreshField(field);
     }
   }
 
@@ -455,6 +455,8 @@ void Collection::addEntries(const Tellico::Data::EntryList& entries_) {
     return;
   }
 
+  const QString cdateName(QStringLiteral("cdate"));
+  const QString mdateName(QStringLiteral("mdate"));
   foreach(EntryPtr entry, entries_) {
     if(!entry) {
       Q_ASSERT(entry);
@@ -483,16 +485,16 @@ void Collection::addEntries(const Tellico::Data::EntryList& entries_) {
     }
     m_entryById.insert(entry->id(), entry.data());
 
-    if(hasField(QStringLiteral("cdate")) && entry->field(QStringLiteral("cdate")).isEmpty()) {
+    if(hasField(cdateName) && entry->field(cdateName).isEmpty()) {
       // use mdate if it exists
-      QString cdate = entry->field(QStringLiteral("mdate"));
+      QString cdate = entry->field(mdateName);
       if(cdate.isEmpty()) {
         cdate = QDate::currentDate().toString(Qt::ISODate);
       }
-      entry->setField(QStringLiteral("cdate"), cdate, false);
+      entry->setField(cdateName, cdate, false);
     }
-    if(hasField(QStringLiteral("mdate")) && entry->field(QStringLiteral("mdate")).isEmpty()) {
-      entry->setField(QStringLiteral("mdate"), QDate::currentDate().toString(Qt::ISODate), false);
+    if(hasField(mdateName) && entry->field(mdateName).isEmpty()) {
+      entry->setField(mdateName, QDate::currentDate().toString(Qt::ISODate), false);
     }
   }
   if(m_trackGroups) {
@@ -520,7 +522,7 @@ void Collection::removeEntriesFromDicts(const Tellico::Data::EntryList& entries_
     }
   }
   if(!modifiedGroups.isEmpty()) {
-    emit signalGroupsModified(CollPtr(this), modifiedGroups.values());
+    Q_EMIT signalGroupsModified(CollPtr(this), modifiedGroups.values());
   }
 }
 
@@ -571,17 +573,6 @@ Tellico::Data::FieldList Collection::fieldsByCategory(const QString& cat_) {
   return list;
 }
 
-QString Collection::fieldNameByTitle(const QString& title_) const {
-  if(title_.isEmpty()) {
-    return QString();
-  }
-  FieldPtr f = fieldByTitle(title_);
-  if(!f) { // might happen in MainWindow::saveCollectionOptions
-    return QString();
-  }
-  return f->name();
-}
-
 QStringList Collection::fieldNames() const {
   return m_fieldByName.keys();
 }
@@ -590,18 +581,6 @@ QStringList Collection::fieldTitles() const {
   return m_fieldByTitle.keys();
 }
 
-QString Collection::fieldTitleByName(const QString& name_) const {
-  if(name_.isEmpty()) {
-    return QString();
-  }
-  FieldPtr f = fieldByName(name_);
-  if(!f) {
-    myWarning() << "no field named " << name_;
-    return QString();
-  }
-  return f->title();
-}
-
 QStringList Collection::valuesByFieldName(const QString& name_) const {
   if(name_.isEmpty()) {
     return QStringList();
@@ -669,7 +648,8 @@ Tellico::Data::EntryGroupDict* Collection::entryGroupDictByName(const QString& n
 void Collection::populateDict(Tellico::Data::EntryGroupDict* dict_, const QString& fieldName_, const Tellico::Data::EntryList& entries_) {
 //  myDebug() << fieldName_;
   Q_ASSERT(dict_);
-  const bool isBool = hasField(fieldName_) && fieldByName(fieldName_)->type() == Field::Bool;
+  auto f = fieldByName(fieldName_);
+  const bool isBool = f && f->type() == Field::Bool;
 
   QSet<EntryGroup*> modifiedGroups;
   foreach(EntryPtr entry, entries_) {
@@ -678,7 +658,8 @@ void Collection::populateDict(Tellico::Data::EntryGroupDict* dict_, const QStrin
       // find the group for this group name
       // bool fields use the field title
       if(isBool && !groupTitle.isEmpty()) {
-        groupTitle = fieldTitleByName(fieldName_);
+        // the f value is valid since isBool is true
+        groupTitle = f->title();
       }
       EntryGroup* group = dict_->value(groupTitle);
       // if the group doesn't exist, create it
@@ -696,7 +677,7 @@ void Collection::populateDict(Tellico::Data::EntryGroupDict* dict_, const QStrin
     } // end group loop
   } // end entry loop
   if(!modifiedGroups.isEmpty()) {
-    emit signalGroupsModified(CollPtr(this), modifiedGroups.values());
+    Q_EMIT signalGroupsModified(CollPtr(this), modifiedGroups.values());
   }
 }
 
@@ -849,6 +830,7 @@ void Collection::clear() {
   m_entryGroupDicts.clear();
   m_entryGroups.clear();
   m_groupsToDelete.clear();
+  m_imagesToRemove.clear();
   m_filters.clear();
   m_borrowers.clear();
 }
@@ -879,11 +861,11 @@ int Collection::sameEntry(Tellico::Data::EntryPtr entry1_, Tellico::Data::EntryP
   int res = 0;
   // start with twice the title score
   // and since the minimum is > 10, then need more than just a perfect title match
-  res += EntryComparison::MATCH_WEIGHT_MED*EntryComparison::score(entry1_, entry2_, QStringLiteral("title"), this);
+  res += EntryComparison::MATCH_WEIGHT_MED*EntryComparison::score(entry1_, entry2_, entry1_->collection()->titleField(), this);
   // then add score for each field
   foreach(FieldPtr field, entry1_->collection()->fields()) {
     // skip title field and personal category
-    if(field->name() == QLatin1String("title") ||
+    if(field->name() == entry1_->collection()->titleField() ||
        field->category() == i18n("Personal")) {
       continue;
     }
@@ -898,6 +880,15 @@ int Collection::sameEntry(Tellico::Data::EntryPtr entry1_, Tellico::Data::EntryP
   return res;
 }
 
+void Collection::imageChanged(const QString& oldValue_, const QString& newValue_) {
+  m_imagesToRemove.insert(oldValue_);
+  m_imagesToRemove.remove(newValue_);
+}
+
+QStringList Collection::imagesToRemove() const {
+  return m_imagesToRemove.values();
+}
+
 Tellico::Data::ID Collection::getID() {
   static ID id = 0;
   return ++id;
