@@ -53,12 +53,8 @@
 #include <KMessageWidget>
 
 #ifdef ENABLE_KNEWSTUFF3
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
-#include <KNS3/Button>
-#else
 #include <KNSWidgets/Button>
 #endif
-#endif
 
 #include <QSpinBox>
 #include <QLineEdit>
@@ -126,11 +122,7 @@ ConfigDialog::ConfigDialog(QWidget* parent_)
   connect(this, &KPageDialog::currentPageChanged, this, &ConfigDialog::slotInitPage);
 }
 
-ConfigDialog::~ConfigDialog() {
-  foreach(Fetch::ConfigWidget* widget, m_newStuffConfigWidgets) {
-    widget->removed();
-  }
-}
+ConfigDialog::~ConfigDialog() = default;
 
 void ConfigDialog::slotInitPage(KPageWidgetItem* item_) {
   Q_ASSERT(item_);
@@ -163,7 +155,7 @@ void ConfigDialog::accept() {
 }
 
 void ConfigDialog::slotApply() {
-  emit signalConfigChanged();
+  Q_EMIT signalConfigChanged();
   button(QDialogButtonBox::Apply)->setEnabled(false);
 }
 
@@ -262,12 +254,7 @@ void ConfigDialog::initGeneralPage(QFrame* frame) {
   imageGroup->addButton(m_rbImageInFile);
   imageGroup->addButton(m_rbImageInAppDir);
   imageGroup->addButton(m_rbImageInLocalDir);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-  void (QButtonGroup::* buttonClicked)(int) = &QButtonGroup::buttonClicked;
-  connect(imageGroup, buttonClicked, this, &ConfigDialog::slotModified);
-#else
   connect(imageGroup, &QButtonGroup::idClicked, this, &ConfigDialog::slotModified);
-#endif
 
   QGroupBox* formatGroup = new QGroupBox(i18n("Formatting Options"), frame);
   l->addWidget(formatGroup);
@@ -573,13 +560,8 @@ void ConfigDialog::initTemplatePage(QFrame* frame) {
   b1->setWhatsThis(whats);
 
 #ifdef ENABLE_KNEWSTUFF3
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
-  auto b2 = new KNS3::Button(i18n("Download..."), QStringLiteral("tellico-template.knsrc"), box1);
-  connect(b2, &KNS3::Button::dialogFinished, this, &ConfigDialog::slotUpdateTemplates);
-#else
   auto b2 = new KNSWidgets::Button(i18n("Download..."), QStringLiteral("tellico-template.knsrc"), box1);
   connect(b2, &KNSWidgets::Button::dialogFinished, this, &ConfigDialog::slotUpdateTemplates);
-#endif
 #else
   QPushButton* b2 = new QPushButton(i18n("Download..."), box1);
   b2->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
@@ -668,8 +650,8 @@ void ConfigDialog::initFetchPage(QFrame* frame) {
   hb2HBoxLayout->addWidget(m_sourceTypeCombo);
   void (QComboBox::* currentIndexChanged)(int) = &QComboBox::currentIndexChanged;
   connect(m_sourceTypeCombo, currentIndexChanged, this, &ConfigDialog::slotSourceFilterChanged);
-  // we want to remove the item for a custom collection
-  int index = m_sourceTypeCombo->findData(Data::Collection::Base);
+  // remove the item for a custom collection
+  const auto index = m_sourceTypeCombo->findData(Data::Collection::Base);
   if(index > -1) {
     m_sourceTypeCombo->removeItem(index);
   }
@@ -733,7 +715,7 @@ void ConfigDialog::readGeneralConfig() {
   bool autoFormat = Config::autoFormat();
   m_cbFormat->setChecked(autoFormat);
 
-  static const QRegularExpression comma(QLatin1String("\\s*,\\s*"));
+  static const QRegularExpression comma(QStringLiteral("\\s*,\\s*"));
 
   m_leCapitals->setText(Config::noCapitalizationString().replace(comma, FieldFormat::delimiterString()));
   m_leArticles->setText(Config::articlesString().replace(comma, FieldFormat::delimiterString()));
@@ -828,7 +810,7 @@ void ConfigDialog::saveGeneralConfig() {
   Config::setAutoCapitalization(m_cbCapitalize->isChecked());
   Config::setAutoFormat(m_cbFormat->isChecked());
 
-  static const QRegularExpression semicolon(QLatin1String("\\s*;\\s*"));
+  static const QRegularExpression semicolon(QStringLiteral("\\s*;\\s*"));
   const QChar comma = QLatin1Char(',');
 
   Config::setNoCapitalizationString(m_leCapitals->text().replace(semicolon, comma));
@@ -882,7 +864,6 @@ void ConfigDialog::saveFetchConfig() {
     if(!cw || (!cw->shouldSave() && !item->isNewSource())) {
       continue;
     }
-    m_newStuffConfigWidgets.removeAll(cw);
     QString group = QStringLiteral("Data Source %1").arg(count);
     // in case we later change the order, clear the group now
     KSharedConfig::openConfig()->deleteGroup(group);
@@ -898,7 +879,7 @@ void ConfigDialog::saveFetchConfig() {
     reloadFetchers = true;
   }
   // now update total number of sources
-  KConfigGroup sourceGroup(KSharedConfig::openConfig(), QLatin1String("Data Sources"));
+  KConfigGroup sourceGroup(KSharedConfig::openConfig(), QStringLiteral("Data Sources"));
   sourceGroup.writeEntry("Sources Count", count);
   // and purge old config groups
   const QString dataSource1(QStringLiteral("Data Source %1"));
@@ -1110,19 +1091,19 @@ void ConfigDialog::slotShowTemplatePreview() {
   Data::EntryPtr e(new Data::Entry(c));
   foreach(Data::FieldPtr f, c->fields()) {
     if(f->name() == QLatin1String("title")) {
-      e->setField(f->name(), m_templateCombo->currentText());
+      e->setField(f, m_templateCombo->currentText());
     } else if(f->type() == Data::Field::Image) {
       continue;
     } else if(f->type() == Data::Field::Choice) {
-      e->setField(f->name(), f->allowed().front());
+      e->setField(f, f->allowed().front());
     } else if(f->type() == Data::Field::Number) {
-      e->setField(f->name(), QStringLiteral("1"));
+      e->setField(f, QStringLiteral("1"));
     } else if(f->type() == Data::Field::Bool) {
-      e->setField(f->name(), QStringLiteral("true"));
+      e->setField(f, QStringLiteral("true"));
     } else if(f->type() == Data::Field::Rating) {
-      e->setField(f->name(), QStringLiteral("4"));
+      e->setField(f, QStringLiteral("4"));
     } else if(f->type() == Data::Field::URL) {
-      e->setField(f->name(), QStringLiteral("https://tellico-project.org"));
+      e->setField(f, QStringLiteral("https://tellico-project.org"));
       hasLink = true;
     } else if(f->type() == Data::Field::Table) {
       QStringList values;
@@ -1134,18 +1115,18 @@ void ConfigDialog::slotShowTemplatePreview() {
         const auto col = f->property(prop);
         values += col.isEmpty() ? prop : col;
       }
-      e->setField(f->name(), values.join(FieldFormat::columnDelimiterString()));
+      e->setField(f, values.join(FieldFormat::columnDelimiterString()));
     } else {
-      e->setField(f->name(), f->title());
+      e->setField(f, f->title());
     }
   }
   if(!hasLink) {
     Data::FieldPtr f(new Data::Field(QStringLiteral("url"),
-                                     QLatin1String("URL"),
+                                     QStringLiteral("URL"),
                                      Data::Field::URL));
     f->setCategory(i18n("General"));
     c->addField(f);
-    e->setField(f->name(), QStringLiteral("https://tellico-project.org"));
+    e->setField(f, QStringLiteral("https://tellico-project.org"));
   }
 
   dlg->showEntry(e);
@@ -1192,11 +1173,7 @@ void ConfigDialog::slotInstallTemplate() {
 }
 
 #ifdef ENABLE_KNEWSTUFF3
-#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
-void ConfigDialog::slotUpdateTemplates(const QList<KNS3::Entry>& list_) {
-#else
 void ConfigDialog::slotUpdateTemplates(const QList<KNSCore::Entry>& list_) {
-#endif
   if(!list_.isEmpty()) {
     loadTemplateList();
   }
