@@ -52,12 +52,6 @@
 
 #include <QMenu>
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#define ACTSTR(str) str
-#else
-#define ACTSTR(str) QLatin1String(str)
-#endif
-
 using Tellico::Controller;
 
 Controller* Controller::s_self = nullptr;
@@ -134,12 +128,10 @@ void Controller::slotCollectionAdded(Tellico::Data::CollPtr coll_) {
   if(!coll_->filters().isEmpty()) {
     m_mainWindow->addFilterView();
     m_mainWindow->m_filterView->addCollection(coll_);
-    m_mainWindow->m_viewTabs->setTabBarHidden(false);
   }
   if(!coll_->borrowers().isEmpty()) {
     m_mainWindow->addLoanView();
     m_mainWindow->m_loanView->addCollection(coll_);
-    m_mainWindow->m_viewTabs->setTabBarHidden(false);
   }
 
   m_mainWindow->slotStatusMsg(i18n("Ready."));
@@ -152,7 +144,7 @@ void Controller::slotCollectionAdded(Tellico::Data::CollPtr coll_) {
   connect(&*coll_, &Data::Collection::mergeAddedField,
           this, &Controller::slotFieldAdded);
 
-  emit collectionAdded(coll_->type());
+  Q_EMIT collectionAdded(coll_->type());
 
   updateActions();
 
@@ -188,12 +180,10 @@ void Controller::slotCollectionModified(Tellico::Data::CollPtr coll_, bool struc
   if(!coll_->filters().isEmpty()) {
     m_mainWindow->addFilterView();
     m_mainWindow->m_filterView->addCollection(coll_);
-    m_mainWindow->m_viewTabs->setTabBarHidden(false);
   }
   if(!coll_->borrowers().isEmpty()) {
     m_mainWindow->addLoanView();
     m_mainWindow->m_loanView->addCollection(coll_);
-    m_mainWindow->m_viewTabs->setTabBarHidden(false);
   }
 
   m_mainWindow->slotStatusMsg(i18n("Ready."));
@@ -501,9 +491,9 @@ void Controller::plugCollectionActions(QMenu* popup_) {
     return;
   }
 
-  popup_->addAction(m_mainWindow->action(ACTSTR("coll_rename_collection")));
-  popup_->addAction(m_mainWindow->action(ACTSTR("coll_fields")));
-  popup_->addAction(m_mainWindow->action(ACTSTR("change_entry_grouping")));
+  popup_->addAction(m_mainWindow->action(QStringLiteral("coll_rename_collection")));
+  popup_->addAction(m_mainWindow->action(QStringLiteral("coll_fields")));
+  popup_->addAction(m_mainWindow->action(QStringLiteral("change_entry_grouping")));
 }
 
 void Controller::plugEntryActions(QMenu* popup_) {
@@ -585,8 +575,8 @@ void Controller::updateActions() const {
   //only enable citation items when it's a bibliography
   const bool isBibtex = Kernel::self()->collectionType() == Data::Collection::Bibtex;
   if(isBibtex) {
-    m_mainWindow->action(ACTSTR("cite_clipboard"))->setEnabled(!emptySelection);
-    m_mainWindow->action(ACTSTR("cite_lyxpipe"))->setEnabled(!emptySelection);
+    m_mainWindow->action(QStringLiteral("cite_clipboard"))->setEnabled(!emptySelection);
+    m_mainWindow->action(QStringLiteral("cite_lyxpipe"))->setEnabled(!emptySelection);
   }
   m_mainWindow->m_checkInEntry->setEnabled(canCheckIn());
 
@@ -610,7 +600,6 @@ void Controller::addedBorrower(Tellico::Data::BorrowerPtr borrower_) {
   foreach(Observer* obs, m_observers) {
     obs->addBorrower(borrower_);
   }
-  m_mainWindow->m_viewTabs->setTabBarHidden(false);
 }
 
 void Controller::modifiedBorrower(Tellico::Data::BorrowerPtr borrower_) {
@@ -629,7 +618,6 @@ void Controller::addedFilter(Tellico::FilterPtr filter_) {
   foreach(Observer* obs, m_observers) {
     obs->addFilter(filter_);
   }
-  m_mainWindow->m_viewTabs->setTabBarHidden(false);
 }
 
 void Controller::removedFilter(Tellico::FilterPtr filter_) {
@@ -708,11 +696,21 @@ void Controller::slotCheckIn(const Tellico::Data::EntryList& entries_) {
 }
 
 void Controller::hideTabs() const {
-  if((!m_mainWindow->m_filterView || m_mainWindow->m_filterView->isEmpty()) &&
-     (!m_mainWindow->m_loanView || m_mainWindow->m_loanView->isEmpty())) {
-    int idx = m_mainWindow->m_viewTabs->indexOf(m_mainWindow->m_groupView);
+  bool hasFilterView = m_mainWindow->m_filterView;
+  if(hasFilterView && m_mainWindow->m_filterView->isEmpty()) {
+    hasFilterView = false;
+    const int idx = m_mainWindow->m_viewTabs->indexOf(m_mainWindow->m_filterView);
+    m_mainWindow->m_viewTabs->removeTab(idx);
+  }
+  bool hasLoanView = m_mainWindow->m_loanView;
+  if(hasLoanView && m_mainWindow->m_loanView->isEmpty()) {
+    hasLoanView = false;
+    const int idx = m_mainWindow->m_viewTabs->indexOf(m_mainWindow->m_loanView);
+    m_mainWindow->m_viewTabs->removeTab(idx);
+  }
+  if(!hasFilterView && !hasLoanView) {
+    const int idx = m_mainWindow->m_viewTabs->indexOf(m_mainWindow->m_groupView);
     m_mainWindow->m_viewTabs->setCurrentIndex(idx);
-    m_mainWindow->m_viewTabs->setTabBarHidden(true);
   }
 }
 
