@@ -116,11 +116,7 @@ QString FileHandler::readTextFile(const QUrl& url_, bool quiet_/*=false*/, bool
   if(f.open(quiet_)) {
     QTextStream stream(f.file());
     if(useUTF8_) {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-      stream.setCodec("UTF-8");
-#else
       stream.setEncoding(QStringConverter::Utf8);
-#endif
     }
     return stream.readAll();
   }
@@ -149,25 +145,18 @@ QDomDocument FileHandler::readXMLDocument(const QUrl& url_, bool processNamespac
     return QDomDocument();
   }
   QDomDocument doc;
-  QString errorMsg;
-  int errorLine, errorColumn;
-  #if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-  if(!doc.setContent(f.file(), processNamespace_, &errorMsg, &errorLine, &errorColumn)) {
-#else
   const auto parseResult = doc.setContent(f.file(), processNamespace_ ?
                                                     QDomDocument::ParseOption::UseNamespaceProcessing :
                                                     QDomDocument::ParseOption::Default);
 
   if(!parseResult) {
-    errorMsg = parseResult.errorMessage;
-    errorLine = parseResult.errorLine;
-    errorColumn = parseResult.errorColumn;
-#endif
     if(!quiet_) {
-      QString details = i18n("There is an XML parsing error in line %1, column %2.", errorLine, errorColumn);
+      QString details = i18n("There is an XML parsing error in line %1, column %2.",
+                             parseResult.errorLine,
+                             parseResult.errorColumn);
       details += QLatin1String("\n");
       details += i18n("The error message from Qt is:");
-      details += QLatin1String("\n\t") + errorMsg;
+      details += QLatin1String("\n\t") + parseResult.errorMessage;
       GUI::CursorSaver cs(Qt::ArrowCursor);
       if(GUI::Proxy::widget()) {
         KMessageBox::detailedError(GUI::Proxy::widget(), TC_I18N2(errorLoad, url_.fileName()), details);
@@ -245,8 +234,7 @@ bool FileHandler::writeTextURL(const QUrl& url_, const QString& text_, bool enco
       return true;
     }
     QSaveFile f(url_.toLocalFile());
-    f.open(QIODevice::WriteOnly);
-    if(f.error() != QFile::NoError) {
+    if(!f.open(QIODevice::WriteOnly) || f.error() != QFile::NoError) {
       if(!quiet_) {
         GUI::Proxy::sorry(TC_I18N2(errorWrite, url_.fileName()));
       }
@@ -257,10 +245,12 @@ bool FileHandler::writeTextURL(const QUrl& url_, const QString& text_, bool enco
 
   // save to remote file
   QTemporaryFile tempfile;
-  tempfile.open();
+  if(!tempfile.open()) {
+    myWarning() << "Failed to open temporary file";
+    return false;
+  }
   QSaveFile f(tempfile.fileName());
-  f.open(QIODevice::WriteOnly);
-  if(f.error() != QFile::NoError) {
+  if(!f.open(QIODevice::WriteOnly) || f.error() != QFile::NoError) {
     tempfile.remove();
     if(!quiet_) {
       GUI::Proxy::sorry(TC_I18N2(errorWrite, url_.fileName()));
@@ -295,11 +285,7 @@ bool FileHandler::writeTextFile(QSaveFile& file_, const QString& text_, bool enc
 
 void FileHandler::writeTextStream(QTextStream& ts_, const QString& text_, bool encodeUTF8_) {
   if(encodeUTF8_) {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    ts_.setCodec("UTF-8");
-#else
     ts_.setEncoding(QStringConverter::Utf8);
-#endif
   }
   // KDE Bug 380832. If string is longer than MAX_TEXT_CHUNK_WRITE_SIZE characters, split into chunks.
   for(int i = 0; i < text_.length(); i += MAX_TEXT_CHUNK_WRITE_SIZE) {
@@ -314,8 +300,7 @@ bool FileHandler::writeDataURL(const QUrl& url_, const QByteArray& data_, bool f
 
   if(url_.isLocalFile()) {
     QSaveFile f(url_.toLocalFile());
-    f.open(QIODevice::WriteOnly);
-    if(f.error() != QFile::NoError) {
+    if(!f.open(QIODevice::WriteOnly) || f.error() != QFile::NoError) {
       if(!quiet_) {
         GUI::Proxy::sorry(TC_I18N2(errorWrite, url_.fileName()));
       }
@@ -326,10 +311,12 @@ bool FileHandler::writeDataURL(const QUrl& url_, const QByteArray& data_, bool f
 
   // save to remote file
   QTemporaryFile tempfile;
-  tempfile.open();
+  if(!tempfile.open()) {
+    myWarning() << "Failed to open temporary file";
+    return false;
+  }
   QSaveFile f(tempfile.fileName());
-  f.open(QIODevice::WriteOnly);
-  if(f.error() != QFile::NoError) {
+  if(!f.open(QIODevice::WriteOnly) || f.error() != QFile::NoError) {
     if(!quiet_) {
       GUI::Proxy::sorry(TC_I18N2(errorWrite, url_.fileName()));
     }
