@@ -61,7 +61,7 @@ void Logger::log(const QString& msg_) {
   }
 
   (*m_logStream) << msg_ << "\n";
-  emit updated();
+  Q_EMIT updated();
 }
 
 void Logger::log(QtMsgType type_, const QMessageLogContext& ctx_, const QString& msg_) {
@@ -94,7 +94,9 @@ void Logger::setLogFile(const QString& logFile_) {
   }
 
   if(logFile_ == QLatin1String("-")) {
-    m_logFile.open(stdout, QIODevice::WriteOnly);
+    if(!m_logFile.open(stdout, QIODevice::WriteOnly)) {
+      return;
+    }
   } else {
     m_logFile.setFileName(logFile_);
     if(!m_logFile.open(QIODevice::WriteOnly)) {
