@@ -88,7 +88,7 @@ void Document::setURL(const QUrl& url_) {
 void Document::setModified(bool modified_) {
   if(modified_ != m_isModified) {
     m_isModified = modified_;
-    emit signalModified(m_isModified);
+    Q_EMIT signalModified(m_isModified);
   }
 }
 
@@ -119,8 +119,8 @@ bool Document::newDocument(int type_) {
   const QUrl url = QUrl::fromLocalFile(TC_I18N1(Tellico::untitledFilename));
   setURL(url);
 
-  emit signalCollectionAdded(m_coll);
-  emit signalCollectionImagesLoaded(m_coll);
+  Q_EMIT signalCollectionAdded(m_coll);
+  Q_EMIT signalCollectionImagesLoaded(m_coll);
 
   setModified(false);
   m_validFile = false;
@@ -176,7 +176,7 @@ bool Document::openDocument(const QUrl& url_) {
   setURL(url_);
   m_validFile = true;
 
-  emit signalCollectionAdded(m_coll);
+  Q_EMIT signalCollectionAdded(m_coll);
 
   // m_importer might have been deleted?
   setModified(m_importer && m_importer->modifiedOriginal());
@@ -187,7 +187,7 @@ bool Document::openDocument(const QUrl& url_) {
     m_cancelImageWriting = false;
     m_loadImagesTimer.start();
   } else {
-    emit signalCollectionImagesLoaded(m_coll);
+    Q_EMIT signalCollectionImagesLoaded(m_coll);
     if(m_importer) {
       m_importer->deleteLater();
       m_importer = nullptr;
@@ -236,10 +236,10 @@ bool Document::saveDocument(const QUrl& url_, bool force_) {
   }
   QScopedPointer<Export::Exporter> exporter;
   if(m_fileFormat == Import::TellicoImporter::XML) {
-    exporter.reset(new Export::TellicoXMLExporter(m_coll));
+    exporter.reset(new Export::TellicoXMLExporter(m_coll, m_url));
     static_cast<Export::TellicoXMLExporter*>(exporter.data())->setIncludeImages(includeImages);
   } else {
-    exporter.reset(new Export::TellicoZipExporter(m_coll));
+    exporter.reset(new Export::TellicoZipExporter(m_coll, m_url));
     static_cast<Export::TellicoZipExporter*>(exporter.data())->setIncludeImages(includeImages);
   }
   item.setProgress(int(0.8*totalSteps));
@@ -273,7 +273,7 @@ bool Document::saveDocumentTemplate(const QUrl& url_, const QString& title_) {
   foreach(auto filter, m_coll->filters()) {
     collTemplate->addFilter(filter);
   }
-  QScopedPointer<Export::Exporter> exporter(new Export::TellicoXMLExporter(collTemplate));
+  QScopedPointer<Export::Exporter> exporter(new Export::TellicoXMLExporter(collTemplate, m_url));
   exporter->setURL(url_);
   // since we already asked about overwriting the file, force the save
   exporter->setOptions(exporter->options() | Export::ExportForce | Export::ExportComplete);
@@ -291,7 +291,7 @@ bool Document::closeDocument() {
 
 void Document::deleteContents() {
   if(m_coll) {
-    emit signalCollectionDeleted(m_coll);
+    Q_EMIT signalCollectionDeleted(m_coll);
   }
   // don't delete the m_importer here, bad things will happen
 
@@ -308,7 +308,7 @@ void Document::deleteContents() {
 void Document::appendCollection(Tellico::Data::CollPtr coll_) {
   bool structuralChange = false;
   appendCollection(m_coll, coll_, &structuralChange);
-  emit signalCollectionModified(m_coll, structuralChange);
+  Q_EMIT signalCollectionModified(m_coll, structuralChange);
 }
 
 void Document::appendCollection(Tellico::Data::CollPtr coll1_, Tellico::Data::CollPtr coll2_, bool* structuralChange_) {
@@ -338,7 +338,7 @@ void Document::appendCollection(Tellico::Data::CollPtr coll1_, Tellico::Data::Co
 Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll_) {
   bool structuralChange = false;
   const auto mergeResult = mergeCollection(m_coll, coll_, &structuralChange);
-  emit signalCollectionModified(m_coll, structuralChange);
+  Q_EMIT signalCollectionModified(m_coll, structuralChange);
   return mergeResult;
 }
 
@@ -418,11 +418,11 @@ void Document::replaceCollection(Tellico::Data::CollPtr coll_) {
   setURL(url);
   m_validFile = false;
 
-  emit signalCollectionDeleted(m_coll);
+  Q_EMIT signalCollectionDeleted(m_coll);
   m_coll = coll_;
   m_coll->setTrackGroups(true);
   m_cancelImageWriting = true;
-  emit signalCollectionAdded(m_coll);
+  Q_EMIT signalCollectionAdded(m_coll);
 }
 
 void Document::unAppendCollection(Tellico::Data::FieldList origFields_, QList<int> addedEntries_) {
@@ -447,13 +447,13 @@ void Document::unAppendCollection(Tellico::Data::FieldList origFields_, QList<in
   // don't removeField() until after removeEntry() is done
   FieldList currFields = m_coll->fields();
   foreach(FieldPtr field, currFields) {
-    if(!origFieldNames.has(field->name())) {
+    if(!origFieldNames.contains(field->name())) {
       m_coll->removeField(field);
       structuralChange = true;
     }
   }
   m_coll->blockSignals(false);
-  emit signalCollectionModified(m_coll, structuralChange);
+  Q_EMIT signalCollectionModified(m_coll, structuralChange);
 }
 
 void Document::unMergeCollection(Tellico::Data::FieldList origFields_, Tellico::Data::MergePair entryPair_) {
@@ -491,7 +491,7 @@ void Document::unMergeCollection(Tellico::Data::FieldList origFields_, Tellico::
     }
   }
   m_coll->blockSignals(false);
-  emit signalCollectionModified(m_coll, structuralChange);
+  Q_EMIT signalCollectionModified(m_coll, structuralChange);
 }
 
 bool Document::isEmpty() const {
@@ -511,17 +511,6 @@ bool Document::loadAllImagesNow() const {
   return Import::TellicoImporter::loadAllImages(m_url);
 }
 
-Tellico::Data::EntryList Document::filteredEntries(Tellico::FilterPtr filter_) const {
-  Data::EntryList matches;
-  Data::EntryList entries = m_coll->entries();
-  foreach(EntryPtr entry, entries) {
-    if(filter_->matches(entry)) {
-      matches.append(entry);
-    }
-  }
-  return matches;
-}
-
 void Document::checkOutEntry(Tellico::Data::EntryPtr entry_) {
   if(!entry_) {
     return;
@@ -557,9 +546,9 @@ void Document::renameCollection(const QString& newTitle_) {
   m_coll->setTitle(newTitle_);
 }
 
-// this only gets called when a zip file with images is opened
-// by loading every image, it gets pulled out of the zip file and
-// copied to disk. Then the zip file can be closed and not retained in memory
+// this only gets called when a file with images include (either zip or xml) is opened
+// by loading every image, it gets pulled out of the file and
+// copied to disk. Then the file can be closed and not retained in memory
 void Document::slotLoadAllImages() {
   myLog() << "Loading all images into cache...";
   QString id;
@@ -567,11 +556,11 @@ void Document::slotLoadAllImages() {
   foreach(EntryPtr entry, m_coll->entries()) {
     foreach(FieldPtr field, m_coll->imageFields()) {
       id = entry->field(field);
-      if(id.isEmpty() || images.has(id)) {
+      if(id.isEmpty() || images.contains(id)) {
         continue;
       }
       // this is the early loading, so just by calling imageById()
-      // the image gets sucked from the zip file and written to disk
+      // the image gets sucked from the file and written to disk
       // by ImageFactory::imageById()
       // TODO:: does this need to check against images with link only?
       if(ImageFactory::imageById(id).isNull()) {
@@ -592,7 +581,7 @@ void Document::slotLoadAllImages() {
   if(m_cancelImageWriting) {
     myLog() << "slotLoadAllImages() - cancel image writing";
   } else {
-    emit signalCollectionImagesLoaded(m_coll);
+    Q_EMIT signalCollectionImagesLoaded(m_coll);
   }
 
   m_cancelImageWriting = false;
@@ -622,7 +611,7 @@ void Document::writeAllImages(int cacheDir_, const QUrl& localDir_) {
   foreach(EntryPtr entry, entries) {
     foreach(FieldPtr field, imageFields) {
       id = entry->field(field);
-      if(id.isEmpty() || images.has(id)) {
+      if(id.isEmpty() || images.contains(id)) {
         continue;
       }
       images.add(id);
@@ -652,6 +641,17 @@ void Document::writeAllImages(int cacheDir_, const QUrl& localDir_) {
     }
   }
 
+  // for saving to local directory, might need to remove images who are no longer in collection
+  if(cacheDir == ImageFactory::LocalDir) {
+    const auto imagesToRemove = m_coll->imagesToRemove();
+    for(const auto& imageToRemove : imagesToRemove) {
+      // possible that images removed from one entry are also used in a different entry
+      if(!images.contains(imageToRemove)) {
+        imgDir->removeImage(imageToRemove);
+      }
+    }
+  }
+
   if(m_cancelImageWriting) {
     myLog() << "Document::writeAllImages() - image writing was cancelled";
   }
@@ -668,7 +668,7 @@ bool Document::pruneImages() {
   foreach(EntryPtr entry, entries) {
     foreach(FieldPtr field, imageFields) {
       id = entry->field(field);
-      if(id.isEmpty() || images.has(id)) {
+      if(id.isEmpty() || images.contains(id)) {
         continue;
       }
       const Data::Image& img = ImageFactory::imageById(id);
@@ -722,7 +722,7 @@ void Document::removeImagesNotInCollection(Tellico::Data::EntryList entries_, Te
   foreach(FieldPtr field, fields) {
     foreach(EntryPtr entry, entries_) {
       QString id = entry->field(field);
-      if(!id.isEmpty() && imagesToCheck.has(id) && !images.has(id)) {
+      if(!id.isEmpty() && imagesToCheck.contains(id) && !images.contains(id)) {
         imagesToRemove.add(id);
       }
     }
