@@ -40,7 +40,6 @@
 #include <KSharedConfig>
 #include <KWindowConfig>
 #include <KHelpClient>
-#include <kwidgetsaddons_version.h>
 
 #include <QStringList>
 #include <QObject>
@@ -96,8 +95,7 @@ EntryEditDialog::EntryEditDialog(QWidget* parent_)
   connect(m_newButton, &QAbstractButton::clicked, this, &EntryEditDialog::slotHandleNew);
 }
 
-EntryEditDialog::~EntryEditDialog() {
-}
+EntryEditDialog::~EntryEditDialog() = default;
 
 void EntryEditDialog::reject() {
   slotClose();
@@ -334,15 +332,9 @@ void EntryEditDialog::slotHandleSave() {
     }
     QString str(i18n("Do you really want to modify these entries?"));
     QString dontAsk = QStringLiteral("SaveMultipleBooks"); // don't change 'books', invisible anyway
-#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 100, 0)
-    auto ret = KMessageBox::questionYesNoList(this, str, names, i18n("Modify Multiple Entries"),
-                                              KStandardGuiItem::cont(), KStandardGuiItem::cancel(), dontAsk);
-    if(ret != KMessageBox::Yes) {
-#else
     auto ret = KMessageBox::questionTwoActionsList(this, str, names, i18n("Modify Multiple Entries"),
                                                    KStandardGuiItem::cont(), KStandardGuiItem::cancel(), dontAsk);
     if(ret != KMessageBox::ButtonCode::PrimaryAction) {
-#endif
       m_isWorking = false;
       return;
     }
@@ -362,7 +354,7 @@ void EntryEditDialog::slotHandleSave() {
     foreach(Data::FieldPtr field, m_modifiedFields) {
       QString key = QString::number(m_currColl->id()) + field->name();
       GUI::FieldWidget* widget = m_widgetDict.value(key);
-      if(widget && widget->isEnabled()) {
+      if(widget && widget->isEditEnabled()) {
         const QString temp = widget->text();
         // ok to set field empty string, just not all of them
         if(modified == false && entry->field(field) != temp) {
@@ -387,15 +379,9 @@ void EntryEditDialog::slotHandleSave() {
       titles << it->title();
     }
     QString dontAsk = QStringLiteral("SaveWithoutRequired");
-#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 100, 0)
-    auto ret = KMessageBox::questionYesNoList(this, str, titles, i18n("Modify Entries"),
-                                              KStandardGuiItem::cont(), KStandardGuiItem::cancel(), dontAsk);
-    if(ret != KMessageBox::Yes) {
-#else
     auto ret = KMessageBox::questionTwoActionsList(this, str, titles, i18n("Modify Entries"),
                                                    KStandardGuiItem::cont(), KStandardGuiItem::cancel(), dontAsk);
     if(ret != KMessageBox::ButtonCode::PrimaryAction) {
-#endif
       m_isWorking = false;
       return;
     }
@@ -499,7 +485,7 @@ void EntryEditDialog::setContents(Tellico::Data::EntryList entries_) {
     QString value = entries_[0]->field(fIt);
     for(int i = 1; i < entries_.count(); ++i) {  // skip checking the first one
       if(entries_[i]->field(fIt) != value) {
-        widget->setEnabled(false);
+        widget->setEditEnabled(false);
         break;
       }
     }
@@ -547,7 +533,7 @@ void EntryEditDialog::setEntry(Tellico::Data::EntryPtr entry_) {
     }
 
     widget->setText(entry_->field(field));
-    widget->setEnabled(true);
+    widget->setEditEnabled(true);
     widget->editMultiple(false);
   } // end field loop
 
@@ -671,25 +657,6 @@ bool EntryEditDialog::queryModified() {
                       "Do you want to enter the changes?"));
     KGuiItem item = KStandardGuiItem::save();
     item.setText(i18n("Save Entry"));
-#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 100, 0)
-    auto want_save = KMessageBox::warningYesNoCancel(this, str, i18n("Unsaved Changes"),
-                                                     item, KStandardGuiItem::discard());
-    switch(want_save) {
-      case KMessageBox::Yes:
-        slotHandleSave();
-        ok = true;
-        break;
-
-      case KMessageBox::No:
-        m_modified = false;
-        ok = true;
-        break;
-
-      case KMessageBox::Cancel:
-        ok = false;
-        break;
-    }
-#else
     auto want_save = KMessageBox::warningTwoActionsCancel(this, str, i18n("Unsaved Changes"),
                                                           item, KStandardGuiItem::discard());
     switch(want_save) {
@@ -708,7 +675,6 @@ bool EntryEditDialog::queryModified() {
         ok = false;
         break;
     }
-#endif
   }
   return ok;
 }
