@@ -26,10 +26,10 @@
 #include "entry.h"
 #include "utils/string_utils.h"
 
-#include <KLocalizedString>
+#include <KLazyLocalizedString>
 
 namespace {
-  static const char* emptyString = I18N_NOOP("(Empty)");
+  static KLazyLocalizedString emptyString = kli18n("(Empty)");
 }
 
 using Tellico::Data::EntryGroup;
@@ -47,7 +47,7 @@ EntryGroup::~EntryGroup() {
 }
 
 QString EntryGroup::groupName() const {
-  return hasEmptyGroupName() ? i18n(emptyString) : m_group;
+  return hasEmptyGroupName() ? emptyGroupName() : m_group;
 }
 
 QString EntryGroup::fieldName() const {
@@ -57,3 +57,8 @@ QString EntryGroup::fieldName() const {
 bool EntryGroup::hasEmptyGroupName() const {
   return m_group.isEmpty();
 }
+
+QString EntryGroup::emptyGroupName() {
+  static const QString name = emptyString.toString();
+  return name;
+}
