@@ -122,7 +122,7 @@ void ArxivFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void ArxivFetcher::slotComplete(KJob*) {
@@ -163,11 +163,7 @@ void ArxivFetcher::slotComplete(KJob*) {
 
   if(m_total == -1) {
     QDomDocument dom;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-    if(!dom.setContent(data, true /*namespace*/)) {
-#else
     if(!dom.setContent(data, QDomDocument::ParseOption::UseNamespaceProcessing)) {
-#endif
       myWarning() << "server did not return valid XML.";
       stop();
       return;
@@ -198,7 +194,7 @@ void ArxivFetcher::slotComplete(KJob*) {
     }
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
 
   m_start = m_entries.count();
@@ -228,7 +224,7 @@ Tellico::Data::EntryPtr ArxivFetcher::fetchEntryHook(uint uid_) {
       }
     }
   }
-  static const QRegularExpression versionRx(QLatin1String("v\\d+$"));
+  static const QRegularExpression versionRx(QStringLiteral("v\\d+$"));
   // if the original search was not for a versioned ID, remove it
   if(request().key() != ArxivID || !request().value().contains(versionRx)) {
     QString arxiv = entry->field(QStringLiteral("arxiv"));
@@ -287,8 +283,9 @@ QUrl ArxivFetcher::searchURL(FetchKey key_, const QString& value_) const {
     case ArxivID:
       {
       // remove prefix and/or version number
-      static const QRegularExpression arxivRx(QLatin1String("^arxiv:"), QRegularExpression::CaseInsensitiveOption);
-      static const QRegularExpression vRx(QLatin1String("v\\d+$"));
+      static const QRegularExpression arxivRx(QStringLiteral("^arxiv:"),
+                                              QRegularExpression::CaseInsensitiveOption);
+      static const QRegularExpression vRx(QStringLiteral("v\\d+$"));
       id = value_;
       id.remove(arxivRx);
       id.remove(vRx);
@@ -311,8 +308,9 @@ Tellico::Fetch::FetchRequest ArxivFetcher::updateRequest(Data::EntryPtr entry_)
   QString id = entry_->field(QStringLiteral("arxiv"));
   if(!id.isEmpty()) {
     // remove prefix and/or version number
-    static const QRegularExpression arxivRx(QLatin1String("^arxiv:"), QRegularExpression::CaseInsensitiveOption);
-    static const QRegularExpression vRx(QLatin1String("v\\d+$"));
+    static const QRegularExpression arxivRx(QStringLiteral("^arxiv:"),
+                                            QRegularExpression::CaseInsensitiveOption);
+    static const QRegularExpression vRx(QStringLiteral("v\\d+$"));
     id.remove(arxivRx);
     id.remove(vRx);
     return FetchRequest(Fetch::ArxivID, id);
