@@ -22,8 +22,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h> // for TELLICO_VERSION
-
 #include "colnectfetcher.h"
 #include "../collections/coincollection.h"
 #include "../collections/stampcollection.h"
@@ -34,6 +32,7 @@
 #include "../gui/combobox.h"
 #include "../gui/lineedit.h"
 #include "../utils/guiproxy.h"
+#include "../utils/tellico_utils.h"
 #include "../entry.h"
 #include "../fieldformat.h"
 #include "../core/filehandler.h"
@@ -41,10 +40,11 @@
 
 #include <KLocalizedString>
 #include <KConfigGroup>
-#include <KJob>
 #include <KJobUiDelegate>
 #include <KJobWidgets>
 #include <KIO/StoredTransferJob>
+#include <KCountryFlagEmojiIconEngine>
+#include <KLanguageName>
 
 #include <QLabel>
 #include <QFile>
@@ -54,7 +54,6 @@
 #include <QJsonArray>
 #include <QJsonValue>
 #include <QRegularExpression>
-#include <QStandardPaths>
 
 #include <algorithm>
 
@@ -67,6 +66,7 @@ namespace {
 
 using namespace Tellico;
 using Tellico::Fetch::ColnectFetcher;
+using namespace Qt::Literals::StringLiterals;
 
 ColnectFetcher::ColnectFetcher(QObject* parent_)
     : Fetcher(parent_)
@@ -76,8 +76,7 @@ ColnectFetcher::ColnectFetcher(QObject* parent_)
     , m_lastCollType(-1) {
 }
 
-ColnectFetcher::~ColnectFetcher() {
-}
+ColnectFetcher::~ColnectFetcher() = default;
 
 QString ColnectFetcher::source() const {
   return m_name.isEmpty() ? defaultName() : m_name;
@@ -132,6 +131,8 @@ void ColnectFetcher::search() {
       myLog() << "Capturing year value from search string:" << m_year;
     }
   }
+  // now the search value can't continue a slash so swap for a space
+  value.replace(QLatin1Char('/'), QLatin1Char(' '));
 
   switch(collectionType()) {
     case Data::Collection::Coin:
@@ -162,6 +163,8 @@ void ColnectFetcher::search() {
         if(!m_year.isEmpty()) {
           if(collectionType() == Data::Collection::Coin) {
             query += QStringLiteral("/mint_year/");
+          } else if(collectionType() == Data::Collection::Card) {
+            query += QStringLiteral("/season/");
           } else {
             query += QStringLiteral("/year/");
           }
@@ -205,13 +208,10 @@ void ColnectFetcher::search() {
   }
 
   u.setPath(u.path() + query);
-  myLog() << "Reading" << u.toDisplayString();
+//  myLog() << "Reading" << u.toDisplayString();
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->addMetaData(QLatin1String("SendUserAgent"), QLatin1String("true"));
-  m_job->addMetaData(QStringLiteral("UserAgent"),
-                     QStringLiteral("Tellico/%1 ( https://tellico-project.org )").arg(QStringLiteral(TELLICO_VERSION)));
-
+  Tellico::addUserAgent(m_job);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job.data(), &KJob::result, this, &ColnectFetcher::slotComplete);
 }
@@ -225,7 +225,7 @@ void ColnectFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 Tellico::Data::EntryPtr ColnectFetcher::fetchEntryHook(uint uid_) {
@@ -239,8 +239,9 @@ Tellico::Data::EntryPtr ColnectFetcher::fetchEntryHook(uint uid_) {
   const QString id = entry->field(QStringLiteral("colnect-id"));
   if(!id.isEmpty()) {
     QUrl u(QString::fromLatin1(COLNECT_API_URL));
-    QString query(QLatin1Char('/') + m_locale + QStringLiteral("/item/cat/")
-                  + m_category + QStringLiteral("/id/") + id);
+    const QString query(QLatin1Char('/') + m_locale +
+                        QStringLiteral("/item/cat/") + m_category +
+                        QStringLiteral("/id/") + id);
     u.setPath(u.path() + query);
 //    myLog() << "Reading" << u.toDisplayString();
 
@@ -392,7 +393,7 @@ void ColnectFetcher::slotComplete(KJob* job_) {
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
 
     stop();
     return;
@@ -430,7 +431,7 @@ void ColnectFetcher::slotComplete(KJob* job_) {
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
 
   stop();
@@ -653,11 +654,11 @@ void ColnectFetcher::populateStampEntry(Data::EntryPtr entry_, const QVariantLis
       const QString prefix = code.section(QLatin1Char(':'), 0, 0).trimmed();
       const QString value = code.section(QLatin1Char(':'), 1, 1).trimmed();
       // 'SG' for Stanley Gibbons, 'Sc' for Scott, 'Mi' for Michel and 'Yv' for Yvert & Tellier.
-      if(prefix == QLatin1String("Sc")) {
+      if(prefix == "Sc"_L1) {
         entry_->setField(QStringLiteral("scott"), value);
-      } else if(prefix == QLatin1String("Sg") && optionalFields().contains(QStringLiteral("stanley-gibbons"))) {
+      } else if(prefix == "Sg"_L1 && optionalFields().contains(QStringLiteral("stanley-gibbons"))) {
         entry_->setField(QStringLiteral("stanley-gibbons"), value);
-      } else if(prefix == QLatin1String("Mi") && optionalFields().contains(QStringLiteral("michel"))) {
+      } else if(prefix == "Mi"_L1 && optionalFields().contains(QStringLiteral("michel"))) {
         entry_->setField(QStringLiteral("michel"), value);
       }
     }
@@ -675,7 +676,7 @@ void ColnectFetcher::populateComicEntry(Data::EntryPtr entry_, const QVariantLis
     entry_->setField(QStringLiteral("pub_year"), resultList_.at(idx).toString().left(4));
   }
 
-  static const QRegularExpression spaceCommaRx(QLatin1String("\\s*,\\s*"));
+  static const QRegularExpression spaceCommaRx(QStringLiteral("\\s*,\\s*"));
   auto hasSpace = [](const QString& s) {
     return s.contains(QLatin1Char(' '));
   };
@@ -794,24 +795,24 @@ void ColnectFetcher::populateGameEntry(Data::EntryPtr entry_, const QVariantList
   idx = m_colnectFields.value(QStringLiteral("Rating"), -1);
   if(idx > -1) {
     // can have both esrb and pegi rating
-    QStringList ratings = resultList_.at(idx).toString().split(QLatin1String("/"));
-    Q_FOREACH(QString rating, ratings) {
+    const auto ratings = resultList_.at(idx).toString().split(QLatin1Char('/'));
+    Q_FOREACH(auto rating, ratings) {
       rating = rating.simplified();
-      if(rating.startsWith(QLatin1String("ESRB"))) {
+      if(rating.startsWith("ESRB"_L1)) {
         rating = rating.mid(5);
         Data::GameCollection::EsrbRating esrb = Data::GameCollection::UnknownEsrb;
-        if(rating == QLatin1String("U"))         esrb = Data::GameCollection::Unrated;
-        else if(rating == QLatin1String("T"))    esrb = Data::GameCollection::Teen;
-        else if(rating == QLatin1String("E"))    esrb = Data::GameCollection::Everyone;
-        else if(rating == QLatin1String("E10+")) esrb = Data::GameCollection::Everyone10;
-        else if(rating == QLatin1String("EC"))   esrb = Data::GameCollection::EarlyChildhood;
-        else if(rating == QLatin1String("A"))    esrb = Data::GameCollection::Adults;
-        else if(rating == QLatin1String("M"))    esrb = Data::GameCollection::Mature;
-        else if(rating == QLatin1String("RP"))   esrb = Data::GameCollection::Pending;
+        if(rating == "U"_L1)         esrb = Data::GameCollection::Unrated;
+        else if(rating == "T"_L1)    esrb = Data::GameCollection::Teen;
+        else if(rating == "E"_L1)    esrb = Data::GameCollection::Everyone;
+        else if(rating == "E10+"_L1) esrb = Data::GameCollection::Everyone10;
+        else if(rating == "EC"_L1)   esrb = Data::GameCollection::EarlyChildhood;
+        else if(rating == "A"_L1)    esrb = Data::GameCollection::Adults;
+        else if(rating == "M"_L1)    esrb = Data::GameCollection::Mature;
+        else if(rating == "RP"_L1)   esrb = Data::GameCollection::Pending;
         if(esrb != Data::GameCollection::UnknownEsrb) {
           entry_->setField(QStringLiteral("certification"), Data::GameCollection::esrbRating(esrb));
         }
-      } else if(rating.startsWith(QLatin1String("PEGI")) && optionalFields().contains(QStringLiteral("pegi"))) {
+      } else if(rating.startsWith("PEGI"_L1) && optionalFields().contains(QStringLiteral("pegi"))) {
         static const QRegularExpression pegiRx(QStringLiteral("^PEGI \\d\\d?"));
         auto pegiMatch = pegiRx.match(rating);
         if(pegiMatch.hasMatch()) {
@@ -875,11 +876,11 @@ Tellico::StringHash ColnectFetcher::allOptionalFields() {
 //  $str = preg_replace('/[\s_]+/', '_', $str); # any space sequence becomes a single underscore
 //  $str = trim($str, '_'); # trim underscores
 QString ColnectFetcher::URLize(const QString& name_) {
-  QString slug = name_;
   static const QString underscore(QStringLiteral("_"));
   static const QRegularExpression htmlElements(QStringLiteral("&[^;]+;"));
   static const QRegularExpression toRemove(QStringLiteral("[.\"><\\:/?#\\[\\]@!$&'()*+,;=]"));
   static const QRegularExpression spaces(QStringLiteral("\\s"));
+  QString slug = name_;
   slug.replace(htmlElements, underscore);
   slug.remove(toRemove);
   slug.replace(spaces, underscore);
@@ -895,7 +896,7 @@ QString ColnectFetcher::imageUrl(const QString& name_, const QString& id_) {
   if(id == 0) return QString();
   QUrl u(QString::fromLatin1(COLNECT_IMAGE_URL));
   // uses 't' for thumbnail, use 'f' for full-size
-  u.setPath(QString::fromLatin1("/%1/%2/%3/%4.jpg")
+  u.setPath(QStringLiteral("/%1/%2/%3/%4.jpg")
                            .arg(m_imageSize == SmallImage ? QLatin1Char('t') : QLatin1Char('f'))
                            .arg(id / 1000)
                            .arg(id % 1000, 3, 10, QLatin1Char('0'))
@@ -907,7 +908,9 @@ QString ColnectFetcher::imageUrl(const QString& name_, const QString& id_) {
 void ColnectFetcher::readDataList() {
   QUrl u(QString::fromLatin1(COLNECT_API_URL));
   // Colnect API calls are encoded as a path
-  QString query(QLatin1Char('/') + m_locale + QStringLiteral("/fields/cat/") + m_category + QLatin1Char('/'));
+  const QString query(QLatin1Char('/') + m_locale +
+                      QStringLiteral("/fields/cat/") + m_category +
+                      QLatin1Char('/'));
   u.setPath(u.path() + query);
 //  myLog() << "Reading Colnect fields from" << u.toDisplayString();
 
@@ -933,9 +936,11 @@ void ColnectFetcher::readDataList() {
 void ColnectFetcher::readItemNames(const QByteArray& item_, const QString& filter_) {
   QUrl u(QString::fromLatin1(COLNECT_API_URL));
   // Colnect API calls are encoded as a path
-  QString query(QLatin1Char('/') + m_locale + QLatin1Char('/') + QLatin1String(item_) + QStringLiteral("/cat/") + m_category);
+  const QString query(QLatin1Char('/') + m_locale +
+                      QLatin1Char('/') + QLatin1String(item_) +
+                      QStringLiteral("/cat/") + m_category);
   u.setPath(u.path() + query + filter_);
-//  myLog() << "Reading item names from" << u.toDisplayString();
+//  myLog() << "Reading item names from" << (query + filter_);
 
   QJsonParseError jsonError;
   const QByteArray data = FileHandler::readDataFile(u, true);
@@ -972,21 +977,20 @@ ColnectFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ColnectFetche
   l->addWidget(label, ++row, 0);
   m_langCombo = new GUI::ComboBox(optionsWidget());
 
-#define LANG_ITEM(NAME, CY, ISO) \
-  m_langCombo->addItem(QIcon(QStandardPaths::locate(QStandardPaths::GenericDataLocation,                       \
-                                                    QStringLiteral("kf5/locale/countries/" CY "/flag.png"))), \
-                       i18nc("Language", NAME),                                                                \
-                       QLatin1String(ISO));
-  LANG_ITEM("English", "us", "en");
-  LANG_ITEM("French",  "fr", "fr");
-  LANG_ITEM("German",  "de", "de");
-  LANG_ITEM("Spanish", "es", "es");
+#define LANG_ITEM(CY, ISO) \
+  m_langCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QStringLiteral(CY))), \
+                       KLanguageName::nameForCode(QStringLiteral(ISO)),            \
+                       QStringLiteral(ISO));
+  LANG_ITEM("us", "en");
+  LANG_ITEM("fr", "fr");
+  LANG_ITEM("de", "de");
+  LANG_ITEM("es", "es");
 #undef LANG_ITEM
 
   // instead of trying to include all possible languages offered by Colnect
   // allow the user to enter it
   m_langCombo->setEditable(true);
-  QRegularExpression rx(QLatin1String("\\w\\w")); // only 2 characters
+  QRegularExpression rx(QStringLiteral("\\w\\w")); // only 2 characters
   QRegularExpressionValidator* val = new QRegularExpressionValidator(rx, this);
   m_langCombo->setValidator(val);
 
@@ -1044,9 +1048,9 @@ void ColnectFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
 }
 
 QString ColnectFetcher::ConfigWidget::preferredName() const {
-  return QString::fromLatin1("Colnect (%1)").arg(m_langCombo->currentText());
+  return QStringLiteral("Colnect (%1)").arg(m_langCombo->currentText());
 }
 
 void ColnectFetcher::ConfigWidget::slotLangChanged() {
-  emit signalName(preferredName());
+  Q_EMIT signalName(preferredName());
 }
