@@ -114,7 +114,7 @@ void CrossRefFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void CrossRefFetcher::slotComplete(KJob*) {
@@ -172,8 +172,8 @@ void CrossRefFetcher::slotComplete(KJob*) {
     }
 
     FetchResult* r = new FetchResult(this, entry);
-    m_entries.insert(r->uid, Data::EntryPtr(entry));
-    emit signalResultFound(r);
+    m_entries.insert(r->uid, entry);
+    Q_EMIT signalResultFound(r);
   }
 
   stop(); // required
