@@ -102,7 +102,7 @@ private:
   friend class ::DiscogsFetcherTest;
   virtual void search() override;
   virtual FetchRequest updateRequest(Data::EntryPtr entry) override;
-  void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap, bool fullData);
+  void populateEntry(Data::EntryPtr entry, const QJsonObject& obj, bool fullData);
 
   int m_limit;
   bool m_started;
