@@ -171,7 +171,7 @@ void EntrezFetcher::stop() {
   }
   m_started = false;
   m_step = Step::Begin;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void EntrezFetcher::slotComplete(KJob*) {
@@ -220,11 +220,7 @@ void EntrezFetcher::slotComplete(KJob*) {
 
 void EntrezFetcher::searchResults(const QByteArray& data_) {
   QDomDocument dom;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-  if(!dom.setContent(data_, false)) {
-#else
   if(!dom.setContent(data_, QDomDocument::ParseOption::Default)) {
-#endif
     myWarning() << "server did not return valid XML.";
     stop();
     return;
@@ -284,11 +280,7 @@ void EntrezFetcher::doSummary() {
 
 void EntrezFetcher::summaryResults(const QByteArray& data_) {
   QDomDocument dom;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-  if(!dom.setContent(data_, false)) {
-#else
   if(!dom.setContent(data_, QDomDocument::ParseOption::Default)) {
-#endif
     myWarning() << "server did not return valid XML.";
     stop();
     return;
@@ -330,7 +322,7 @@ void EntrezFetcher::summaryResults(const QByteArray& data_) {
     }
     FetchResult* r = new FetchResult(this, title, pubdate + QLatin1Char('/') + authors);
     m_matches.insert(r->uid, id);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
   m_start = m_matches.count() + 1;
   m_hasMoreResults = m_start <= m_total;
@@ -392,8 +384,8 @@ Tellico::Data::EntryPtr EntrezFetcher::fetchEntryHook(uint uid_) {
   if(str.isEmpty()) {
     // might be an API error, and message is in JSON
     QJsonDocument doc = QJsonDocument::fromJson(xmlOutput.toUtf8());
-    if(!doc.isNull() && doc.object().contains(QStringLiteral("error"))) {
-      const QString error = doc.object().value(QStringLiteral("error")).toString();
+    if(!doc.isNull() && doc.object().contains(QLatin1StringView("error"))) {
+      const QString error = doc.object().value(QLatin1StringView("error")).toString();
       message(error, MessageHandler::Error);
       myLog() << "EntrezFetcher -" << error;
     }
