@@ -52,33 +52,27 @@
 #include <QGridLayout>
 #include <QStandardItemModel>
 
+#include <memory>
+
 using Tellico::Fetch::ExecExternalFetcher;
 
 QStringList ExecExternalFetcher::parseArguments(const QString& str_) {
   // matching escaped quotes is too hard... :(
-  static const QRegularExpression quotes(QLatin1String("(['\"])(.*?)\\1"));
-  static const QRegularExpression spaces(QLatin1String("\\s+?"));
+  static const QRegularExpression quotes(QStringLiteral("(['\"])(.*?)\\1"));
+  static const QRegularExpression spaces(QStringLiteral("\\s+?"));
 
   QStringList args;
   QRegularExpressionMatch match;
   int pos = 0;
   for(int nextPos = str_.indexOf(quotes, pos, &match); nextPos > -1; pos = nextPos+1, nextPos = str_.indexOf(quotes, pos, &match)) {
     // a non-quotes arguments runs from pos to nextPos
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    args += str_.mid(pos, nextPos-pos).split(spaces, QString::SkipEmptyParts);
-#else
     args += str_.mid(pos, nextPos-pos).split(spaces, Qt::SkipEmptyParts);
-#endif
     // move nextpos marker to end of match
     nextPos += match.capturedLength();
     args += match.captured(2);
   }
   // catch the end stuff
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-  args += str_.mid(pos).split(spaces, QString::SkipEmptyParts);
-#else
   args += str_.mid(pos).split(spaces, Qt::SkipEmptyParts);
-#endif
 
   return args;
 }
@@ -91,6 +85,7 @@ ExecExternalFetcher::~ExecExternalFetcher() {
   if(m_process) {
     m_process->kill();
     m_process->deleteLater();
+    m_process = nullptr;
   }
 }
 
@@ -172,7 +167,7 @@ void ExecExternalFetcher::search() {
     value = QLatin1Char('"') + value + QLatin1Char('"');
   }
   QString args = m_args.value(request().key());
-  static const QRegularExpression rx(QLatin1String("(['\"])%1\\1"));
+  static const QRegularExpression rx(QStringLiteral("(['\"])%1\\1"));
   args.replace(rx, QStringLiteral("%1"));
   startSearch(parseArguments(args.arg(value))); // replace %1 with search value
 }
@@ -191,7 +186,7 @@ void ExecExternalFetcher::startSearch(const QStringList& args_) {
   connect(m_process, finished, this, &ExecExternalFetcher::slotProcessExited);
   m_process->setOutputChannelMode(KProcess::SeparateChannels);
   m_process->setProgram(m_path, args_);
-  if(m_process && m_process->execute() < 0) {
+  if(m_process->execute() < 0) {
     myDebug() << "process failed to start";
     stop();
   }
@@ -209,7 +204,7 @@ void ExecExternalFetcher::stop() {
   m_data.clear();
   m_started = false;
   m_errors.clear();
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void ExecExternalFetcher::slotData() {
@@ -228,7 +223,6 @@ void ExecExternalFetcher::slotError() {
 }
 
 void ExecExternalFetcher::slotProcessExited() {
-//  DEBUG_LINE;
   if(m_process->exitStatus() != QProcess::NormalExit || m_process->exitCode() != 0) {
     myDebug() << source() << ": process did not exit successfully";
     if(!m_errors.isEmpty()) {
@@ -258,34 +252,33 @@ void ExecExternalFetcher::slotProcessExited() {
   f.close();
 #endif
   Import::Format format = static_cast<Import::Format>(m_formatType > -1 ? m_formatType : Import::TellicoXML);
-  Import::Importer* imp = nullptr;
-  // only 4 formats re supported here
+  std::unique_ptr<Tellico::Import::Importer> imp;
+  // only 4 formats are supported here
   switch(format) {
     case Import::TellicoXML:
-      imp = new Import::TellicoImporter(text);
+      imp.reset(new Import::TellicoImporter(text));
       break;
 
     case Import::Bibtex:
-      imp = new Import::BibtexImporter(text);
+      imp.reset(new Import::BibtexImporter(text));
       break;
 
     case Import::MODS:
-      imp = new Import::XSLTImporter(text);
+      imp.reset(new Import::XSLTImporter(text));
       {
         QString xsltFile = DataFileRegistry::self()->locate(QStringLiteral("mods2tellico.xsl"));
         if(!xsltFile.isEmpty()) {
           QUrl u = QUrl::fromLocalFile(xsltFile);
-          static_cast<Import::XSLTImporter*>(imp)->setXSLTURL(u);
+          static_cast<Import::XSLTImporter*>(imp.get())->setXSLTURL(u);
         } else {
           myWarning() << "unable to find mods2tellico.xml!";
-          delete imp;
-          imp = nullptr;
+          imp.reset(nullptr);
         }
       }
       break;
 
     case Import::RIS:
-      imp = new Import::RISImporter(text);
+      imp.reset(new Import::RISImporter(text));
       break;
 
     default:
@@ -302,12 +295,10 @@ void ExecExternalFetcher::slotProcessExited() {
       message(imp->statusMessage(), MessageHandler::Status);
     }
     myDebug() << source() << ": no collection pointer";
-    delete imp;
     stop();
     return;
   }
 
-  delete imp;
   if(coll->entryCount() == 0) {
 //    myDebug() << "no results";
     stop();
@@ -318,7 +309,7 @@ void ExecExternalFetcher::slotProcessExited() {
   foreach(Data::EntryPtr entry, entries) {
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
   stop(); // be sure to call this
 }
@@ -415,7 +406,7 @@ ExecExternalFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ExecExte
   row = -1;
   const Fetch::KeyMap keyMap = Fetch::Manager::self()->keyMap();
   for(Fetch::KeyMap::ConstIterator it = keyMap.begin(); it != keyMap.end(); ++it) {
-    FetchKey key = it.key();
+    const FetchKey key = it.key();
     if(key == Raw) {
       continue;
     }
@@ -483,6 +474,11 @@ ExecExternalFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const ExecExte
 }
 
 ExecExternalFetcher::ConfigWidget::~ConfigWidget() {
+//  As of 2/15/26, with KF 6.22 and 6.10.2, the KUrlRequester m_pathEdit variable
+  // causes a double-delete crash. It has the same widget parent as the other widgets
+  // so it's unclear why the crash, which only happens after opening the file dialog
+  // and selecting a URL. BUG 516054, and workaround to avoid the crash:
+  m_pathEdit->setParent(nullptr);
 }
 
 void ExecExternalFetcher::ConfigWidget::readConfig(const KConfigGroup& config_) {
@@ -490,9 +486,9 @@ void ExecExternalFetcher::ConfigWidget::readConfig(const KConfigGroup& config_)
   QList<int> argKeys = config_.readEntry("ArgumentKeys", QList<int>());
   QStringList argValues = config_.readEntry("Arguments", QStringList());
   if(argKeys.count() != argValues.count()) {
-    myWarning() << "unequal number of arguments and keys";
+    myWarning() << "ConfigWidget is reading unequal number of arguments and keys";
   }
-  int n = qMin(argKeys.count(), argValues.count());
+  const int n = qMin(argKeys.count(), argValues.count());
   QMap<FetchKey, QString> args;
   for(int i = 0; i < n; ++i) {
     args[static_cast<FetchKey>(argKeys[i])] = argValues[i];
@@ -527,10 +523,10 @@ void ExecExternalFetcher::ConfigWidget::readConfig(const KConfigGroup& config_)
     m_leUpdate->clear();
   }
 
-  int collType = config_.readEntry("CollectionType", -1);
+  const int collType = config_.readEntry("CollectionType", -1);
   m_collCombo->setCurrentType(collType);
 
-  int formatType = config_.readEntry("FormatType", -1);
+  const int formatType = config_.readEntry("FormatType", -1);
   m_formatCombo->setCurrentData(static_cast<Import::Format>(formatType));
   m_deleteOnRemove = config_.readEntry("DeleteOnRemove", false);
   m_name = config_.readEntry("Name");
@@ -538,9 +534,9 @@ void ExecExternalFetcher::ConfigWidget::readConfig(const KConfigGroup& config_)
 }
 
 void ExecExternalFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
-  QUrl u = m_pathEdit->url();
+  const QUrl u = m_pathEdit->url();
   if(!u.isEmpty()) {
-    config_.writePathEntry("ExecPath", u.path());
+    config_.writePathEntry("ExecPath", u.toLocalFile());
   }
   QList<int> keys;
   QStringList args;
