@@ -81,6 +81,9 @@
 #include "opdsfetcher.h"
 #include "adsfetcher.h"
 #include "vgcollectfetcher.h"
+#include "isfdbfetcher.h"
+#include "metronfetcher.h"
+#include "doifetcher.h"
 
 /**
  * Ideally, I'd like these initializations to be in each cpp file for each collection type
@@ -140,11 +143,14 @@ Tellico::Fetch::FetcherInitializer::FetcherInitializer() {
   RegisterFetcher<Fetch::OPDSFetcher> registerOPDS(OPDS);
   RegisterFetcher<Fetch::ADSFetcher> registerADS(ADS);
   RegisterFetcher<Fetch::VGCollectFetcher> registerVGCollect(VGCollect);
+  RegisterFetcher<Fetch::ISFDBFetcher> registerISFDB(ISFDB);
+  RegisterFetcher<Fetch::MetronFetcher> registerMetron(Metron);
 
 // these data sources depend on being able to import bibtex
 #ifdef ENABLE_BTPARSE
   RegisterFetcher<Fetch::MRLookupFetcher> registerMRLookup(MRLookup);
   RegisterFetcher<Fetch::GoogleScholarFetcher> registerGoogle(GoogleScholar);
   RegisterFetcher<Fetch::BibsonomyFetcher> registerBibsonomy(Bibsonomy);
+  RegisterFetcher<Fetch::DOIFetcher> registerDOI(DOIorg);
 #endif
 }
