@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2003-2009 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2003-2020 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -27,7 +27,7 @@
 
 #include "../datavectors.h"
 
-#include <QExplicitlySharedDataPointer>
+#include <QPointer>
 #include <QString>
 
 namespace Tellico {
@@ -37,19 +37,21 @@ class Fetcher;
 
 class FetchResult {
 public:
-  FetchResult(QExplicitlySharedDataPointer<Fetcher> f, Data::EntryPtr entry);
-  FetchResult(QExplicitlySharedDataPointer<Fetcher> f, const QString& t, const QString& d, const QString& i = QString());
+  FetchResult(Fetcher* fetcher_, Data::EntryPtr entry_);
+  FetchResult(Fetcher* f, const QString& t, const QString& d, const QString& i = QString());
 
   Data::EntryPtr fetchEntry();
+  Fetcher* fetcher();
 
-  uint uid;
-  QExplicitlySharedDataPointer<Fetcher> fetcher;
+  quint32 uid;
   QString title;
   QString desc;
   QString isbn;
 
 private:
   static QString makeDescription(Data::EntryPtr entry);
+
+  QPointer<Fetcher> m_fetcher;
 };
 
   } // end namespace
