@@ -37,11 +37,8 @@
 #include <KIO/StoredTransferJob>
 #include <KJobUiDelegate>
 #include <KJobWidgets>
-#include <KLanguageName>
-#include <kguiaddons_version.h>
-#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
 #include <KCountryFlagEmojiIconEngine>
-#endif
+#include <KLanguageName>
 
 #include <QRegularExpression>
 #include <QLabel>
@@ -74,19 +71,19 @@ const FilmAffinityFetcher::LocaleData& FilmAffinityFetcher::localeData(int local
     {
       QStringLiteral("es"),
       QStringLiteral("(Serie de TV)"),
-      QString::fromUtf8("Año"),
+      QStringLiteral("Año"),
       QStringLiteral("Título original"),
       QStringLiteral("País"),
-      QString::fromUtf8("Duración"),
-      QString::fromUtf8("Dirección"),
+      QStringLiteral("Duración"),
+      QStringLiteral("Dirección"),
       QStringLiteral("Reparto"),
-      QString::fromUtf8("Género"),
+      QStringLiteral("Género"),
       QStringLiteral("Guion"),
       QStringLiteral("Historia:"),
-      QString::fromUtf8("Compañías"),
+      QStringLiteral("Compañías"),
       QStringLiteral("Distribuidora"),
       QStringLiteral("Emitida por:"),
-      QString::fromUtf8("Música"),
+      QStringLiteral("Música"),
       QStringLiteral("Sinopsis")
     },
     {
@@ -153,7 +150,7 @@ void FilmAffinityFetcher::search() {
   switch(request().key()) {
     case Title:
       //q.addQueryItem(QStringLiteral("year"), QStringLiteral("yes"));
-      q.addQueryItem(QStringLiteral("stype[]"), QLatin1String("title"));
+      q.addQueryItem(QStringLiteral("stype[]"), QStringLiteral("title"));
       break;
 
     default:
@@ -179,7 +176,7 @@ void FilmAffinityFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void FilmAffinityFetcher::slotComplete(KJob*) {
@@ -239,7 +236,7 @@ void FilmAffinityFetcher::slotComplete(KJob*) {
 //      myDebug() << url << title << year;
       FetchResult* r = new FetchResult(this, title, year);
       m_matches.insert(r->uid, url);
-      emit signalResultFound(r);
+      Q_EMIT signalResultFound(r);
     }
   }
 
@@ -483,11 +480,7 @@ FilmAffinityFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const FilmAffi
   m_numCast->setMaximum(99);
   m_numCast->setMinimum(0);
   m_numCast->setValue(FILMAFFINITY_DEFAULT_CAST_SIZE);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-  void (QSpinBox::* textChanged)(const QString&) = &QSpinBox::valueChanged;
-#else
   void (QSpinBox::* textChanged)(const QString&) = &QSpinBox::textChanged;
-#endif
   connect(m_numCast, textChanged, this, &ConfigWidget::slotSetModified);
   l->addWidget(m_numCast, row, 1);
   QString w = i18n("The list of cast members may include many people. Set the maximum number returned from the search.");
@@ -498,19 +491,12 @@ FilmAffinityFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const FilmAffi
   label = new QLabel(i18n("Language: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_localeCombo = new GUI::ComboBox(optionsWidget());
-#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
   m_localeCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QLatin1String("es"))),
-                         KLanguageName::nameForCode(QLatin1String("es")),
+                         KLanguageName::nameForCode(QStringLiteral("es")),
                          int(FilmAffinityFetcher::ES));
   m_localeCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QLatin1String("us"))),
-                         KLanguageName::nameForCode(QLatin1String("en")),
+                         KLanguageName::nameForCode(QStringLiteral("en")),
                          int(FilmAffinityFetcher::US));
-#else
-  m_localeCombo->addItem(KLanguageName::nameForCode(QLatin1String("es")),
-                         int(FilmAffinityFetcher::ES));
-  m_localeCombo->addItem(KLanguageName::nameForCode(QLatin1String("en")),
-                         int(FilmAffinityFetcher::US));
-#endif
   void (GUI::ComboBox::* activatedInt)(int) = &GUI::ComboBox::activated;
   connect(m_localeCombo, activatedInt, this, &ConfigWidget::slotSetModified);
   l->addWidget(m_localeCombo, row, 1);
