@@ -136,7 +136,7 @@ void GoogleScholarFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void GoogleScholarFetcher::slotComplete(KJob*) {
@@ -202,8 +202,8 @@ void GoogleScholarFetcher::slotComplete(KJob*) {
     }
 
     FetchResult* r = new FetchResult(this, entry);
-    m_entries.insert(r->uid, Data::EntryPtr(entry));
-    emit signalResultFound(r);
+    m_entries.insert(r->uid, entry);
+    Q_EMIT signalResultFound(r);
     ++count;
   }
   m_start = m_entries.count();
@@ -243,8 +243,8 @@ void GoogleScholarFetcher::setBibtexCookie() {
   // have to set preferences to have bibtex output
   const QString text = FileHandler::readTextFile(QUrl(QString::fromLatin1(SCHOLAR_SET_CONFIG_URL)), true);
   // find hidden input variables
-  static const QRegularExpression inputRx(QLatin1String("<input\\s+[^>]*?\\s*?type\\s*?=\\s*?\"?hidden\"?\\s+?[^>]+?>"));
-  static const QRegularExpression pairRx(QLatin1String("([^=\\s<]+?)\\s*=\\s*\"?([^=\\s\">]+?)\"?"));
+  static const QRegularExpression inputRx(QStringLiteral("<input\\s+[^>]*?\\s*?type\\s*?=\\s*?\"?hidden\"?\\s+?[^>]+?>"));
+  static const QRegularExpression pairRx(QStringLiteral("([^=\\s<]+?)\\s*=\\s*\"?([^=\\s\">]+?)\"?"));
   QHash<QString, QString> nameValues;
   auto i = inputRx.globalMatch(text);
   while(i.hasNext()) {
