@@ -117,7 +117,7 @@ void HathiTrustFetcher::stop() {
     m_job->kill();
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 bool HathiTrustFetcher::initMARC21Handler() {
@@ -221,30 +221,25 @@ void HathiTrustFetcher::slotComplete(KJob* job_) {
 #endif
 
   QJsonDocument doc = QJsonDocument::fromJson(data);
-  QVariantMap resultMap = doc.object().toVariantMap();
-  if(resultMap.isEmpty()) {
+  const auto docObj = doc.object();
+  if(docObj.isEmpty()) {
     stop();
     return;
   }
 
-  QVariantMap::const_iterator i = resultMap.constBegin();
-  for( ; i != resultMap.constEnd(); ++i) {
-    const QVariantMap recordMap = i.value().toMap().value(QStringLiteral("records")).toMap();
-    if(recordMap.isEmpty()) {
+  for(auto i = docObj.constBegin(); i != docObj.constEnd(); ++i) {
+    const auto obj = i.value()[QLatin1StringView("records")].toObject();
+    if(obj.isEmpty()) {
       continue;
     }
     // we know there's a record, so no need to check for existence of first iterator in map
-    QVariantMap::const_iterator ri = recordMap.constBegin();
-    QString marcxml = ri.value().toMap().value(QStringLiteral("marc-xml")).toString();
+    auto ri = obj.constBegin();
+    QString marcxml = ri.value()[QLatin1StringView("marc-xml")].toString();
     // HathiTrust doesn't always include the XML NS in the JSON results. Assume it's always
     // MARC XML and check that
     QDomDocument dom;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-    if(dom.setContent(marcxml, true /* namespace processing */) && dom.documentElement().namespaceURI().isEmpty()) {
-#else
     if(dom.setContent(marcxml, QDomDocument::ParseOption::UseNamespaceProcessing) &&
        dom.documentElement().namespaceURI().isEmpty()) {
-#endif
       const QString rootName = dom.documentElement().tagName();
       myDebug() << "no namespace, attempting to set on" << rootName << "element";
       QRegularExpression rootRx(QLatin1Char('<') + rootName + QLatin1Char('>'));
@@ -277,7 +272,7 @@ void HathiTrustFetcher::slotComplete(KJob* job_) {
     foreach(Data::EntryPtr entry, coll->entries()) {
       FetchResult* r = new FetchResult(this, entry);
       m_entries.insert(r->uid, entry);
-      emit signalResultFound(r);
+      Q_EMIT signalResultFound(r);
     }
   }
 
