@@ -31,7 +31,7 @@
 #include "../images/imagefactory.h"
 #include "../utils/isbnvalidator.h"
 #include "../utils/string_utils.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -138,7 +138,7 @@ void IBSFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void IBSFetcher::slotComplete(KJob*) {
@@ -166,13 +166,13 @@ void IBSFetcher::slotComplete(KJob*) {
 #endif
 
   QString s = Tellico::decodeHTML(data);
-  static const QRegularExpression itemRx(QLatin1String("<div class=\"cc-product-list-item.*?>(.+?)<!--"),
+  static const QRegularExpression itemRx(QStringLiteral("<div class=\"cc-product-list-item.*?>(.+?)<!--"),
                                          QRegularExpression::DotMatchesEverythingOption);
   static const QRegularExpression titleRx(QStringLiteral("<a [^>]*href=\"(.+?)\"[^>]*?class=\"cc-title\">(.+?)</a"),
                                           QRegularExpression::DotMatchesEverythingOption);
-  static const QRegularExpression yearRx(QLatin1String("<span class=\"cc-publisher\">.*?([12]\\d{3}).*?</"),
+  static const QRegularExpression yearRx(QStringLiteral("<span class=\"cc-publisher\">.*?([12]\\d{3}).*?</"),
                                          QRegularExpression::DotMatchesEverythingOption);
-  static const QRegularExpression tagRx(QLatin1String("<.*?>"));
+  static const QRegularExpression tagRx(QStringLiteral("<.*?>"));
 
   QString url, title, year;
   auto matchIterator = itemRx.globalMatch(s);
@@ -195,7 +195,7 @@ void IBSFetcher::slotComplete(KJob*) {
 //      myDebug() << u << title << year;
       FetchResult* r = new FetchResult(this, title, year);
       m_matches.insert(r->uid, u);
-      emit signalResultFound(r);
+      Q_EMIT signalResultFound(r);
     }
   }
 
@@ -244,7 +244,7 @@ Tellico::Data::EntryPtr IBSFetcher::fetchEntryHook(uint uid_) {
 }
 
 Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
-  static const QRegularExpression jsonRx(QLatin1String("<script type=\"application/ld\\+json\">(.*?)</script"),
+  static const QRegularExpression jsonRx(QStringLiteral("<script type=\"application/ld\\+json\">(.*?)</script"),
                                          QRegularExpression::DotMatchesEverythingOption);
 
   const auto jsonMatch = jsonRx.match(str_);
@@ -263,9 +263,9 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
   f.close();
 #endif
   QJsonDocument doc = QJsonDocument::fromJson(jsonMatch.captured(1).toUtf8());
-  QVariantMap objectMap = doc.object().toVariantMap();
-  QVariantMap resultMap = objectMap.value(QStringLiteral("mainEntity")).toMap();
-  if(resultMap.isEmpty()) {
+  const auto docObj = doc.object();
+  const auto mainObj = docObj[QLatin1StringView("mainEntity")].toObject();
+  if(mainObj.isEmpty()) {
     myDebug() << "no JSON object";
     return Data::EntryPtr();
   }
@@ -274,15 +274,15 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
   Data::EntryPtr entry(new Data::Entry(coll));
 
   // as genre, take the last breadcrumb
-  QString genre = mapValue(objectMap, "breadcrumb");
+  QString genre = objValue(docObj, "breadcrumb");
   genre = genre.section(QStringLiteral(">"), -1);
   entry->setField(QStringLiteral("genre"), genre);
 
   // the title in the embedded loses it's identifier? "La..."
-  entry->setField(QStringLiteral("title"), mapValue(resultMap, "name"));
-  entry->setField(QStringLiteral("author"), mapValue(resultMap, "author"));
+  entry->setField(QStringLiteral("title"), objValue(mainObj, "name"));
+  entry->setField(QStringLiteral("author"), objValue(mainObj, "author"));
 
-  const QString bookFormat = mapValue(resultMap, "bookFormat");
+  const QString bookFormat = objValue(mainObj, "bookFormat");
   if(bookFormat == QLatin1String("https://schema.org/Paperback")) {
     entry->setField(QStringLiteral("binding"), i18n("Paperback"));
   } else if(bookFormat == QLatin1String("https://schema.org/Hardcover")) {
@@ -291,10 +291,10 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
     entry->setField(QStringLiteral("binding"), i18n("E-Book"));
   }
 
-  entry->setField(QStringLiteral("pub_year"), mapValue(resultMap, "datePublished"));
-  entry->setField(QStringLiteral("isbn"), mapValue(resultMap, "isbn"));
+  entry->setField(QStringLiteral("pub_year"), objValue(mainObj, "datePublished"));
+  entry->setField(QStringLiteral("isbn"), objValue(mainObj, "isbn"));
 
-  const QString id = ImageFactory::addImage(QUrl::fromUserInput(mapValue(resultMap, "image")),
+  const QString id = ImageFactory::addImage(QUrl::fromUserInput(objValue(mainObj, "image")),
                                             true /* quiet */);
   if(id.isEmpty()) {
     message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
@@ -303,20 +303,20 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
   entry->setField(QStringLiteral("cover"), id);
 
   // inLanguage is upper-case language code
-  const QString lang = mapValue(resultMap, "inLanguage");
+  const QString lang = objValue(mainObj, "inLanguage");
   entry->setField(QStringLiteral("language"), QLocale(lang.toLower()).nativeLanguageName());
 
-  entry->setField(QStringLiteral("plot"), mapValue(resultMap, "description"));
-  entry->setField(QStringLiteral("pages"), mapValue(resultMap, "numberOfPages"));
-  entry->setField(QStringLiteral("publisher"), mapValue(resultMap, "publisher"));
+  entry->setField(QStringLiteral("plot"), objValue(mainObj, "description"));
+  entry->setField(QStringLiteral("pages"), objValue(mainObj, "numberOfPages"));
+  entry->setField(QStringLiteral("publisher"), objValue(mainObj, "publisher"));
 
   // multiple authors do not show up in the embedded JSON
-  static const QRegularExpression titleDivRx(QLatin1String("<div id=\"title\">(.*?)</div>"),
+  static const QRegularExpression titleDivRx(QStringLiteral("<div id=\"title\">(.*?)</div>"),
                                              QRegularExpression::DotMatchesEverythingOption);
   const auto titleDivMatch = titleDivRx.match(str_);
   if(titleDivMatch.hasMatch()) {
     const QString titleDiv = titleDivMatch.captured(1);
-    static const QRegularExpression authorRx(QLatin1String("<a href=\"/libri/autori/[^>]+?>(.*?)</a>"),
+    static const QRegularExpression authorRx(QStringLiteral("<a href=\"/libri/autori/[^>]+?>(.*?)</a>"),
                                              QRegularExpression::DotMatchesEverythingOption);
     QStringList authors;
     auto i = authorRx.globalMatch(titleDiv);
@@ -328,7 +328,7 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
       entry->setField(QStringLiteral("author"), authors.join(FieldFormat::delimiterString()));
     }
     // the title in the embedded loses its identifier? "La..."
-    static const QRegularExpression labelRx(QLatin1String("<label>(.*?)</label>"),
+    static const QRegularExpression labelRx(QStringLiteral("<label>(.*?)</label>"),
                                             QRegularExpression::DotMatchesEverythingOption);
     const auto labelMatch = labelRx.match(titleDiv);
     if(labelMatch.hasMatch()) {
@@ -336,10 +336,10 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
     }
   }
 
-  static const QRegularExpression tagRx(QLatin1String("<.*?>"));
+  static const QRegularExpression tagRx(QStringLiteral("<.*?>"));
 
   // editor is not in embedded json
-  static const QRegularExpression editorRx(QLatin1String("Curatore:.*?>(.*?)</a"),
+  static const QRegularExpression editorRx(QStringLiteral("Curatore:.*?>(.*?)</a"),
                                            QRegularExpression::DotMatchesEverythingOption);
   auto match = editorRx.match(str_);
   if(match.hasMatch()) {
@@ -347,7 +347,7 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
   }
 
   // translator is not in embedded json
-  static const QRegularExpression translatorRx(QLatin1String("Traduttore:.*?>(.*?)</a"),
+  static const QRegularExpression translatorRx(QStringLiteral("Traduttore:.*?>(.*?)</a"),
                                                QRegularExpression::DotMatchesEverythingOption);
   match = translatorRx.match(str_);
   if(match.hasMatch()) {
@@ -355,7 +355,7 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
   }
 
   // edition is not in embedded json
-  static const QRegularExpression editionRx(QLatin1String("Editore:.*?>(.*?)</a"),
+  static const QRegularExpression editionRx(QStringLiteral("Editore:.*?>(.*?)</a"),
                                             QRegularExpression::DotMatchesEverythingOption);
   match = editionRx.match(str_);
   if(match.hasMatch()) {
@@ -363,7 +363,7 @@ Tellico::Data::EntryPtr IBSFetcher::parseEntry(const QString& str_) {
   }
 
   // series is not in embedded json
-  static const QRegularExpression seriesRx(QLatin1String("Collana:.*?>(.*?)</a"),
+  static const QRegularExpression seriesRx(QStringLiteral("Collana:.*?>(.*?)</a"),
                                            QRegularExpression::DotMatchesEverythingOption);
   match = seriesRx.match(str_);
   if(match.hasMatch()) {
