@@ -37,6 +37,7 @@ class KJob;
 namespace KIO {
   class StoredTransferJob;
 }
+class ISBNdbFetcherTest;
 
 namespace Tellico {
   namespace Fetch {
@@ -83,10 +84,13 @@ private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
+  friend class ::ISBNdbFetcherTest;
+  void setTestUrl1(const QUrl& url) { m_testUrl1 = url; }
+
   virtual void search() override;
   void doSearch(const QString& term);
   virtual FetchRequest updateRequest(Data::EntryPtr entry) override;
-  void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
+  void populateEntry(Data::EntryPtr entry, const QJsonObject& obj);
   void endJob(KIO::StoredTransferJob* job);
 
   int m_limit;
@@ -99,6 +103,8 @@ private:
   bool m_started;
   QString m_apiKey;
   bool m_batchIsbn;
+
+  QUrl m_testUrl1;
 };
 
   }
