@@ -97,9 +97,9 @@ private Q_SLOTS:
 private:
   virtual void search() override;
   virtual FetchRequest updateRequest(Data::EntryPtr entry) override;
-  void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
+  void populateEntry(Data::EntryPtr entry, const QJsonObject& obj);
   void populateEpisodes(Data::EntryPtr entry);
-  void readTrackInfo(const QVariantMap& resultMap);
+  void readTrackInfo(const QJsonObject& resultMap);
 
   bool m_started;
 
