@@ -30,7 +30,7 @@
 #include "../core/filehandler.h"
 #include "../images/imagefactory.h"
 #include "../utils/string_utils.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -111,7 +111,7 @@ void KinoFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void KinoFetcher::slotComplete(KJob*) {
@@ -142,9 +142,9 @@ void KinoFetcher::slotComplete(KJob*) {
   f.close();
 #endif
 
-  QRegularExpression linkRx(QStringLiteral("<div class=\"poster__title\">.*?<a .+?poster__link.+?href=\"(.+?)\".*?>(.+?)</"),
+  QRegularExpression linkRx(QStringLiteral("<div class=\"alice-teaser-title\">.*?<a .+?teaser-link.+?href=\"(.+?)\".*?>(.+?)</a"),
                             QRegularExpression::DotMatchesEverythingOption);
-  QRegularExpression dateSpanRx(QStringLiteral("<span .+?movie-startdate.+?>(.+?)</span"));
+  QRegularExpression dateSpanRx(QStringLiteral("<li>Kinostart: (.+?)</li"));
   QRegularExpression dateRx(QStringLiteral("\\d{2}\\.\\d{2}\\.(\\d{4})"));
   QRegularExpression yearEndRx(QStringLiteral("(\\d{4})/?$"));
 
@@ -152,10 +152,12 @@ void KinoFetcher::slotComplete(KJob*) {
   while(i.hasNext()) {
     auto match = i.next();
     QString u = match.captured(1);
-    if(u.isEmpty() || u.contains(QLatin1String("news")) || !u.contains(QLatin1String("film"))) {
+    if(u.isEmpty() ||
+       u.contains(QLatin1StringView("news")) ||
+       !u.contains(QLatin1StringView("film"))) {
       continue;
     }
-    if(u.startsWith(QLatin1String("//"))) {
+    if(u.startsWith(QLatin1StringView("//"))) {
       u.prepend(QLatin1String("https:"));
     }
     Data::CollPtr coll(new Data::VideoCollection(true));
@@ -179,7 +181,7 @@ void KinoFetcher::slotComplete(KJob*) {
     m_matches.insert(r->uid, url);
     m_entries.insert(r->uid, entry);
     // don't emit signal until after putting url in matches hash
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
 
   stop();
@@ -227,16 +229,18 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
   auto i = jsonRx.globalMatch(str_);
   while(i.hasNext()) {
     QJsonDocument doc = QJsonDocument::fromJson(i.next().captured(1).toUtf8());
-    QVariantMap objectMap = doc.object().toVariantMap();
-    if(mapValue(objectMap, "@type") != QStringLiteral("Movie")) {
+    const auto obj = doc.object();
+    if(objValue(obj, "@type") != QLatin1StringView("Movie")) {
       continue;
     }
-    entry->setField(QStringLiteral("director"), mapValue(objectMap, "director", "name"));
-    hasDirector = !mapValue(objectMap, "director", "name").isEmpty();
+    const auto dirName = objValue(obj, "director", "name");
+    entry->setField(QStringLiteral("director"), dirName);
+    hasDirector = !dirName.isEmpty();
 
     QStringList actors;
-    foreach(QVariant v, objectMap.value(QLatin1String("actor")).toList()) {
-      const QString actor = mapValue(v.toMap(), "name");
+    const auto actorArray = obj[QLatin1StringView("actor")].toArray();
+    for(const auto&v : actorArray) {
+      const QString actor = objValue(v.toObject(), "name");
       if(!actor.isEmpty()) actors += actor;
     }
     if(!actors.isEmpty()) {
@@ -244,15 +248,15 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
       hasCast = true;
     }
     // cover could be a relative link
-    QString coverLink = mapValue(objectMap, "image");
+    QString coverLink = objValue(obj, "image");
     if(coverLink.startsWith(QLatin1String("//"))) {
       coverLink.prepend(QLatin1String("https:"));
     }
     entry->setField(QStringLiteral("cover"), coverLink);
 
-    QString genreString = mapValue(objectMap, "genre");
+    const QString genreString = objValue(obj, "genre");
     if(!genreString.isEmpty()) {
-      static const QRegularExpression commaRx(QLatin1String(",\\s+"));
+      static const QRegularExpression commaRx(QStringLiteral(",\\s+"));
       QStringList genres = genreString.split(commaRx);
       entry->setField(QStringLiteral("genre"), genres.join(FieldFormat::delimiterString()));
     }
@@ -289,7 +293,7 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
     }
   }
   if(!lengthStr.isEmpty()) {
-    const QString l = lengthStr.remove(QStringLiteral(" Min")).trimmed();
+    const QString l = lengthStr.remove(QLatin1StringView(" Min")).trimmed();
     entry->setField(QStringLiteral("running-time"), l);
   }
 
@@ -322,15 +326,15 @@ void KinoFetcher::parseEntry(Data::EntryPtr entry, const QString& str_) {
       entry->collection()->fieldByName(QStringLiteral("certification"))->setAllowed(allowed);
     }
     QString c = certMatch.captured(1).remove(tagRx).trimmed();
-    if(c == QLatin1String("ab 0") || c == QLatin1String("0")) {
+    if(c == QLatin1StringView("ab 0") || c == QLatin1StringView("0")) {
       c = QStringLiteral("FSK 0 (DE)");
-    } else if(c == QLatin1String("ab 6") || c == QLatin1String("6")) {
+    } else if(c == QLatin1StringView("ab 6") || c == QLatin1StringView("6")) {
       c = QStringLiteral("FSK 6 (DE)");
-    } else if(c == QLatin1String("ab 12") || c == QLatin1String("12")) {
+    } else if(c == QLatin1StringView("ab 12") || c == QLatin1StringView("12")) {
       c = QStringLiteral("FSK 12 (DE)");
-    } else if(c == QLatin1String("ab 16") || c == QLatin1String("16")) {
+    } else if(c == QLatin1StringView("ab 16") || c == QLatin1StringView("16")) {
       c = QStringLiteral("FSK 16 (DE)");
-    } else if(c == QLatin1String("ab 18") || c == QLatin1String("18")) {
+    } else if(c == QLatin1StringView("ab 18") || c == QLatin1StringView("18")) {
       c = QStringLiteral("FSK 18 (DE)");
     }
     entry->setField(QStringLiteral("certification"), c);
