@@ -29,7 +29,7 @@
 #include "../fieldformat.h"
 #include "../images/imagefactory.h"
 #include "../utils/string_utils.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -127,7 +127,7 @@ void KinoPoiskFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void KinoPoiskFetcher::slotRedirection(KIO::Job*, const QUrl& toUrl_) {
@@ -167,7 +167,7 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
     // don't pull the data here, just add it to a single response
     auto res = new FetchResult(this, request().value(), QString());
     m_matches.insert(res->uid, m_redirectUrl);
-    emit signalResultFound(res);
+    Q_EMIT signalResultFound(res);
   }
 
   // look for a paragraph, class=",", with an internal /ink to "/level/1/film..."
@@ -188,7 +188,7 @@ void KinoPoiskFetcher::slotComplete(KJob*) {
 //      myDebug() << url << title << year;
       auto res = new FetchResult(this, title, year);
       m_matches.insert(res->uid, url);
-      emit signalResultFound(res);
+      Q_EMIT signalResultFound(res);
     }
   }
 
@@ -239,9 +239,9 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::fetchEntryHook(uint uid_) {
   f.close();
 #endif
 
-  if(results.contains(QStringLiteral("captcha")) || results.endsWith(QLatin1String("</script>"))) {
+  if(results.contains(QLatin1StringView("captcha")) || results.endsWith(QLatin1StringView("</script>"))) {
 //    myDebug() << "KinoPoiskFetcher: captcha triggered";
-    static const QRegularExpression re(QLatin1String("/(\\d+)"));
+    static const QRegularExpression re(QStringLiteral("/(\\d+)"));
     QRegularExpressionMatch match = re.match(url.url());
     if(match.hasMatch()) {
       entry = requestEntry(match.captured(1));
@@ -310,24 +310,24 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::requestEntry(const QString& filmId_) {
   coll->addEntries(entry);
 
   QJsonDocument doc = QJsonDocument::fromJson(data);
-  const QVariantMap resultMap = doc.object().toVariantMap();
+  const auto obj = doc.object();
 
-  entry->setField(QStringLiteral("title"), mapValue(resultMap, "nameRu"));
-  entry->setField(QStringLiteral("year"), mapValue(resultMap, "year"));
-  entry->setField(QStringLiteral("nationality"), mapValue(resultMap, "countries", "country"));
-  entry->setField(QStringLiteral("genre"), mapValue(resultMap, "genres", "genre"));
-  entry->setField(QStringLiteral("running-time"), mapValue(resultMap, "filmLength"));
-  entry->setField(QStringLiteral("plot"), mapValue(resultMap, "description"));
-  entry->setField(QStringLiteral("cover"), mapValue(resultMap, "posterUrl"));
+  entry->setField(QStringLiteral("title"), objValue(obj, "nameRu"));
+  entry->setField(QStringLiteral("year"), objValue(obj, "year"));
+  entry->setField(QStringLiteral("nationality"), objValue(obj, "countries", "country"));
+  entry->setField(QStringLiteral("genre"), objValue(obj, "genres", "genre"));
+  entry->setField(QStringLiteral("running-time"), objValue(obj, "filmLength"));
+  entry->setField(QStringLiteral("plot"), objValue(obj, "description"));
+  entry->setField(QStringLiteral("cover"), objValue(obj, "posterUrl"));
 
   const QString cert(QStringLiteral("certification"));
   auto certField = coll->fieldByName(cert);
   if(certField) {
-    entry->setField(cert, mpaaRating(mapValue(resultMap, "ratingMpaa"), certField->allowed()));
+    entry->setField(cert, mpaaRating(objValue(obj, "ratingMpaa"), certField->allowed()));
   }
 
   const QString imdb(QStringLiteral("imdb"));
-  const QString imdbId = mapValue(resultMap, "imdbId");
+  const QString imdbId = objValue(obj, "imdbId");
   if(optionalFields().contains(imdb) && !imdbId.isEmpty()) {
     coll->addField(Data::Field::createDefaultField(Data::Field::ImdbField));
     entry->setField(imdb, QStringLiteral("https://www.imdb.com/title/") + imdbId);
@@ -339,7 +339,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::requestEntry(const QString& filmId_) {
       f->setFormatType(FieldFormat::FormatTitle);
       coll->addField(f);
     }
-    entry->setField(origTitle, mapValue(resultMap, "nameOriginal"));
+    entry->setField(origTitle, objValue(obj, "nameOriginal"));
   }
 
   url = QUrl(QLatin1String(KINOPOISK_API_STAFF_URL));
@@ -373,16 +373,16 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::requestEntry(const QString& filmId_) {
   const auto staffArray = QJsonDocument::fromJson(data).array();
   const int sz = staffArray.size();
   for(int i = 0; i < sz; ++i) {
-    const auto obj = staffArray.at(i).toObject().toVariantMap();
-    const QString key = mapValue(obj, "professionKey");
-    QString name = mapValue(obj, "nameRu");
-    if(name.isEmpty()) name = mapValue(obj, "nameEn");
+    const auto obj = staffArray.at(i).toObject();
+    const QString key = objValue(obj, "professionKey");
+    QString name = objValue(obj, "nameRu");
+    if(name.isEmpty()) name = objValue(obj, "nameEn");
     if(name.isEmpty()) continue;
     if(key == QLatin1String("DIRECTOR")) {
       directors += name;
     } else if(key == QLatin1String("ACTOR")) {
       if(actors.size() < m_numCast) {
-        actors += (name + FieldFormat::columnDelimiterString() + mapValue(obj, "description"));
+        actors += (name + FieldFormat::columnDelimiterString() + objValue(obj, "description"));
       }
     } else if(key == QLatin1String("WRITER")) {
       writers += name;
@@ -419,8 +419,8 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     return Data::EntryPtr();
   }
 
-  const QString queryId = doc.object().value(QStringLiteral("query")).toObject()
-                                      .value(QStringLiteral("id")).toString();
+  const QString queryId = doc.object().value(QLatin1StringView("query")).toObject()
+                                      .value(QLatin1StringView("id")).toString();
   // if there's no query ID, then this is not a film object to parse
   if(queryId.isEmpty()) {
 //    myDebug() << "No query ID...";
@@ -432,9 +432,9 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
   Data::EntryPtr entry(new Data::Entry(coll));
   coll->addEntries(entry);
 
-  QJsonObject dataObject = doc.object().value(QStringLiteral("props")).toObject()
-                                        .value(QStringLiteral("apolloState")).toObject()
-                                        .value(QStringLiteral("data")).toObject();
+  QJsonObject dataObject = doc.object().value(QLatin1StringView("props")).toObject()
+                                       .value(QLatin1StringView("apolloState")).toObject()
+                                       .value(QLatin1StringView("data")).toObject();
   QJsonObject filmObject = dataObject.value(QStringLiteral("Film:") + queryId).toObject();
   if(filmObject.isEmpty()) {
     filmObject = dataObject.value(QStringLiteral("TvSeries:") + queryId).toObject();
@@ -458,7 +458,7 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntry(const QString& str_) {
     }
 
     // also add original title
-    if(fieldName == QLatin1String("title")) {
+    if(fieldName == QLatin1StringView("title")) {
       const QString origTitle(QStringLiteral("origtitle"));
       if(optionalFields().contains(origTitle)) {
         if(!entry->collection()->hasField(origTitle)) {
@@ -497,16 +497,16 @@ Tellico::Data::EntryPtr KinoPoiskFetcher::parseEntryLinkedData(const QString& st
   Data::EntryPtr entry(new Data::Entry(coll));
   coll->addEntries(entry);
 
-  QVariantMap objectMap = doc.object().toVariantMap();
-  entry->setField(QStringLiteral("title"), mapValue(objectMap, "name"));
-  entry->setField(QStringLiteral("year"), mapValue(objectMap, "datePublished").left(4));
-  entry->setField(QStringLiteral("nationality"), mapValue(objectMap, "countryOfOrigin"));
-  entry->setField(QStringLiteral("cast"), mapValue(objectMap, "actor", "name"));
-  entry->setField(QStringLiteral("director"), mapValue(objectMap, "director", "name"));
-  entry->setField(QStringLiteral("producer"), mapValue(objectMap, "producer", "name"));
-  entry->setField(QStringLiteral("genre"), mapValue(objectMap, "genre"));
-  entry->setField(QStringLiteral("plot"), mapValue(objectMap, "description"));
-  QString cover = mapValue(objectMap, "image");
+  const auto obj = doc.object();
+  entry->setField(QStringLiteral("title"), objValue(obj, "name"));
+  entry->setField(QStringLiteral("year"), objValue(obj, "datePublished").left(4));
+  entry->setField(QStringLiteral("nationality"), objValue(obj, "countryOfOrigin"));
+  entry->setField(QStringLiteral("cast"), objValue(obj, "actor", "name"));
+  entry->setField(QStringLiteral("director"), objValue(obj, "director", "name"));
+  entry->setField(QStringLiteral("producer"), objValue(obj, "producer", "name"));
+  entry->setField(QStringLiteral("genre"), objValue(obj, "genre"));
+  entry->setField(QStringLiteral("plot"), objValue(obj, "description"));
+  QString cover = objValue(obj, "image");
   if(cover.startsWith(QLatin1Char('/'))) {
     cover.prepend(QLatin1String("https:"));
   }
@@ -533,19 +533,19 @@ QString KinoPoiskFetcher::fieldNameFromKey(const QString& key_) {
   }
 
   // otherwise some wonky key names
-  if(key_.contains(QLatin1String("DIRECTOR"), Qt::CaseInsensitive)) {
+  if(key_.contains(QLatin1StringView("DIRECTOR"), Qt::CaseInsensitive)) {
     return QStringLiteral("director");
   }
-  if(key_.contains(QLatin1String("WRITER"), Qt::CaseInsensitive)) {
+  if(key_.contains(QLatin1StringView("WRITER"), Qt::CaseInsensitive)) {
     return QStringLiteral("writer");
   }
-  if(key_.contains(QLatin1String("PRODUCER"), Qt::CaseInsensitive)) {
+  if(key_.contains(QLatin1StringView("PRODUCER"), Qt::CaseInsensitive)) {
     return QStringLiteral("producer");
   }
-  if(key_.contains(QLatin1String("COMPOSER"), Qt::CaseInsensitive)) {
+  if(key_.contains(QLatin1StringView("COMPOSER"), Qt::CaseInsensitive)) {
     return QStringLiteral("composer");
   }
-  if(key_.contains(QLatin1String("ACTOR"), Qt::CaseInsensitive)) {
+  if(key_.contains(QLatin1StringView("ACTOR"), Qt::CaseInsensitive)) {
     return QStringLiteral("cast");
   }
   return QString();
@@ -579,43 +579,44 @@ QString KinoPoiskFetcher::fieldValueFromObject(const QJsonObject& obj_, const QS
 
   QJsonObject valueObj = value_.toObject();
   // if there's a reference to another object, need to pull it from the higher level data object
-  if(valueObj.contains(QStringLiteral("__ref"))) {
-    valueObj = obj_.value(valueObj.value(QStringLiteral("__ref")).toString()).toObject();
+  if(valueObj.contains(QLatin1StringView("__ref"))) {
+    valueObj = obj_.value(valueObj.value(QLatin1StringView("__ref")).toString()).toObject();
   }
 
   // if it has a 'person' field, gotta grab the person name
-  if(valueObj.contains(QLatin1String("person"))) {
-    return fieldValueFromObject(obj_, field_, valueObj.value(QLatin1String("person")), allowed_);
+  if(valueObj.contains(QLatin1StringView("person"))) {
+    return fieldValueFromObject(obj_, field_, valueObj.value(QLatin1StringView("person")), allowed_);
   }
 
-  if(field_ == QLatin1String("title")) {
-    const QString title = valueObj.value(QStringLiteral("russian")).toString();
+  if(field_ == QLatin1StringView("title")) {
+    const QString title = valueObj.value(QLatin1StringView("russian")).toString();
     // return original if russian is not available
-    return title.isEmpty() ? valueObj.value(QStringLiteral("original")).toString() : title;
-  } else if(field_ == QLatin1String("origtitle")) {
-    return valueObj.value(QStringLiteral("original")).toString();
-  } else if(field_ == QLatin1String("cover")) {
-    QString url = valueObj.value(QStringLiteral("avatarsUrl")).toString();
+    return title.isEmpty() ? valueObj.value(QLatin1StringView("original")).toString() : title;
+  } else if(field_ == QLatin1StringView("origtitle")) {
+    return valueObj.value(QLatin1StringView("original")).toString();
+  } else if(field_ == QLatin1StringView("cover")) {
+    QString url = valueObj.value(QLatin1StringView("avatarsUrl")).toString();
     if(url.startsWith(QLatin1Char('/'))) {
       url.prepend(QLatin1String("https:"));
     }
     // also add size
     url.append(QLatin1Char('/') + QLatin1String(KINOPOISK_IMAGE_SIZE));
     return url;
-  } else if(field_ == QLatin1String("certification")) {
-    return mpaaRating(valueObj.value(QLatin1String("mpaa")).toString(), allowed_);
+  } else if(field_ == QLatin1StringView("certification")) {
+    return mpaaRating(valueObj.value(QLatin1StringView("mpaa")).toString(), allowed_);
   // with an 'originalName' or 'name' field return that
   // and check this before comparing against field names for people, like 'director'
-  } else if(valueObj.contains(QLatin1String("originalName")) || valueObj.contains(QLatin1String("name"))) {
-    const QString name = valueObj.value(QStringLiteral("name")).toString();
+  } else if(valueObj.contains(QLatin1StringView("originalName")) ||
+            valueObj.contains(QLatin1StringView("name"))) {
+    const QString name = valueObj.value(QLatin1StringView("name")).toString();
     // prefer name to originalName
-    return name.isEmpty() ? valueObj.value(QStringLiteral("originalName")).toString() : name;
-  } else if(valueObj.contains(QLatin1String("items"))) {
+    return name.isEmpty() ? valueObj.value(QLatin1StringView("originalName")).toString() : name;
+  } else if(valueObj.contains(QLatin1StringView("items"))) {
     // some additional nesting apparently
     // key in film object points to director object, whose 'items' is an array where each 'is' points to
     // a director object which has a person.id pointing to a person object with a 'name' and 'original' value
     // valueObj is the director so we want the items array
-    QJsonValue itemsValue = valueObj.value(QLatin1String("items"));
+    QJsonValue itemsValue = valueObj.value(QLatin1StringView("items"));
     if(!itemsValue.isArray()) {
       myDebug() << "items value is not an array";
       return QString();
@@ -629,13 +630,13 @@ QString KinoPoiskFetcher::fieldValueFromObject(const QJsonObject& obj_, const QS
 QString KinoPoiskFetcher::mpaaRating(const QString& value_, const QStringList& allowed_) {
   // default collection has 5 MPAA values
   if(allowed_.size() != 5) return value_;
-  if(value_ == QLatin1String("g")) {
+  if(value_ == QLatin1StringView("g")) {
     return allowed_.at(0);
-  } else if(value_ == QLatin1String("pg")) {
+  } else if(value_ == QLatin1StringView("pg")) {
     return allowed_.at(1);
-  } else if(value_ == QLatin1String("pg13")) {
+  } else if(value_ == QLatin1StringView("pg13")) {
     return allowed_.at(2);
-  } else if(value_ == QLatin1String("r")) {
+  } else if(value_ == QLatin1StringView("r")) {
     return allowed_.at(3);
   } else {
     return allowed_.at(4);
@@ -684,11 +685,7 @@ KinoPoiskFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const KinoPoiskFe
   m_numCast->setMaximum(99);
   m_numCast->setMinimum(0);
   m_numCast->setValue(KINOPOISK_DEFAULT_CAST_SIZE);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-  void (QSpinBox::* textChanged)(const QString&) = &QSpinBox::valueChanged;
-#else
   void (QSpinBox::* textChanged)(const QString&) = &QSpinBox::textChanged;
-#endif
   connect(m_numCast, textChanged, this, &ConfigWidget::slotSetModified);
   l->addWidget(m_numCast, row, 1);
   QString w = i18n("The list of cast members may include many people. Set the maximum number returned from the search.");
