@@ -174,9 +174,9 @@ void MultiFetcher::slotDone() {
   foreach(Data::EntryPtr entry, m_entries) {
     FetchResult* r = new FetchResult(this, entry);
     m_entryHash.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 Tellico::Data::EntryPtr MultiFetcher::fetchEntryHook(uint uid_) {
@@ -275,7 +275,6 @@ MultiFetcher::FetcherItemWidget::FetcherItemWidget(QWidget* parent_)
   QHBoxLayout* layout = new QHBoxLayout(this);
   layout->setSpacing(0);
   layout->setContentsMargins(0, 0, 0, 0);
-  setLayout(layout);
 
   QLabel* label = new QLabel(i18n("Data source:"), this);
   layout->addWidget(label);
