@@ -22,18 +22,17 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h> // for TELLICO_VERSION
-
 #include "musicbrainzfetcher.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
 #include "../images/imagefactory.h"
-#include "../utils/guiproxy.h"
-#include "../utils/string_utils.h"
 #include "../collection.h"
 #include "../entry.h"
+#include "../utils/guiproxy.h"
+#include "../utils/string_utils.h"
 #include "../utils/datafileregistry.h"
 #include "../utils/xmlhandler.h"
+#include "../utils/tellico_utils.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -61,7 +60,7 @@ using Tellico::Fetch::MusicBrainzFetcher;
 MusicBrainzFetcher::MusicBrainzFetcher(QObject* parent_)
     : Fetcher(parent_), m_xsltHandler(nullptr),
       m_limit(MUSICBRAINZ_MAX_RETURNS_TOTAL), m_total(-1), m_offset(0), m_multiDiscTracks(true),
-      m_job(nullptr), m_started(false) {
+      m_mbidSearch(false), m_job(nullptr), m_started(false) {
 }
 
 MusicBrainzFetcher::~MusicBrainzFetcher() {
@@ -93,6 +92,7 @@ void MusicBrainzFetcher::setLimit(int limit_) {
 
 void MusicBrainzFetcher::search() {
   m_started = true;
+  m_mbidSearch = false;
   m_total = -1;
   m_offset = 0;
   doSearch();
@@ -133,9 +133,24 @@ void MusicBrainzFetcher::doSearch() {
       return;
   }
   QUrlQuery q;
-  q.addQueryItem(QStringLiteral("query"), queryString);
-  q.addQueryItem(QStringLiteral("limit"), QString::number(m_limit));
-  q.addQueryItem(QStringLiteral("offset"), QString::number(m_offset));
+  // special case for searching for MBID directly
+  if(request().key() == Fetch::Keyword || request().key() == Fetch::Raw) {
+    static const QRegularExpression mbrx(QStringLiteral("^\\w{8}-\\w{4}-\\w{4}-\\w{4}-\\w{12}$"));
+    if(request().value().startsWith(QLatin1StringView("reid:")) ||
+       request().value().startsWith(QLatin1StringView("mbid:"))) {
+      u.setPath(u.path() + QLatin1Char('/') + request().value().mid(5));
+      q.addQueryItem(QStringLiteral("inc"), QStringLiteral("artists+recordings+release-groups+labels+url-rels"));
+      m_mbidSearch = true;
+    } else if(request().value().contains(mbrx)) {
+      u.setPath(u.path() + QLatin1Char('/') + request().value());
+      q.addQueryItem(QStringLiteral("inc"), QStringLiteral("artists+recordings+release-groups+labels+url-rels"));
+      m_mbidSearch = true;
+    }
+  } else {
+    q.addQueryItem(QStringLiteral("query"), queryString);
+    q.addQueryItem(QStringLiteral("limit"), QString::number(m_limit));
+    q.addQueryItem(QStringLiteral("offset"), QString::number(m_offset));
+  }
   q.addQueryItem(QStringLiteral("fmt"), QStringLiteral("xml"));
   u.setQuery(q);
 //  myDebug() << "url: " << u.url();
@@ -143,9 +158,7 @@ void MusicBrainzFetcher::doSearch() {
   m_requestTimer.start();
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   // see https://musicbrainz.org/doc/XML_Web_Service/Rate_Limiting#Provide_meaningful_User-Agent_strings
-  m_job->addMetaData(QLatin1String("SendUserAgent"), QLatin1String("true"));
-  m_job->addMetaData(QStringLiteral("UserAgent"),
-                     QStringLiteral("Tellico/%1 ( https://tellico-project.org )").arg(QStringLiteral(TELLICO_VERSION)));
+  Tellico::addUserAgent(m_job);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job.data(), &KJob::result,
           this, &MusicBrainzFetcher::slotComplete);
@@ -160,7 +173,7 @@ void MusicBrainzFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void MusicBrainzFetcher::slotComplete(KJob* ) {
@@ -170,7 +183,7 @@ void MusicBrainzFetcher::slotComplete(KJob* ) {
     return;
   }
 
-  QByteArray data = m_job->data();
+  const QByteArray data = m_job->data();
   if(data.isEmpty()) {
     myDebug() << "no data";
     stop();
@@ -192,11 +205,7 @@ void MusicBrainzFetcher::slotComplete(KJob* ) {
 
   if(m_total == -1) {
     QDomDocument dom;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-    if(!dom.setContent(data, false)) {
-#else
     if(!dom.setContent(data, QDomDocument::ParseOption::Default)) {
-#endif
       myWarning() << "server did not return valid XML:" << data;
       stop();
       return;
@@ -242,8 +251,8 @@ void MusicBrainzFetcher::slotComplete(KJob* ) {
     }
 
     FetchResult* r = new FetchResult(this, entry);
-    m_entries.insert(r->uid, Data::EntryPtr(entry));
-    emit signalResultFound(r);
+    m_entries.insert(r->uid, entry);
+    Q_EMIT signalResultFound(r);
     ++count;
   }
 
@@ -260,8 +269,8 @@ Tellico::Data::EntryPtr MusicBrainzFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
-  QString mbid = entry->field(QStringLiteral("mbid"));
-  if(mbid.isEmpty()) {
+  const QString mbid = entry->field(QStringLiteral("mbid"));
+  if(mbid.isEmpty() || m_mbidSearch) { // no further searching if it was already by MBID
     return entry;
   }
 
@@ -280,9 +289,7 @@ Tellico::Data::EntryPtr MusicBrainzFetcher::fetchEntryHook(uint uid_) {
   m_requestTimer.start();
 
   KIO::StoredTransferJob* dataJob = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  dataJob->addMetaData(QLatin1String("SendUserAgent"), QLatin1String("true"));
-  dataJob->addMetaData(QStringLiteral("UserAgent"), QStringLiteral("Tellico/%1 ( http://tellico-project.org )")
-                                                                .arg(QStringLiteral(TELLICO_VERSION)));
+  Tellico::addUserAgent(dataJob);
   if(!dataJob->exec()) {
     myDebug() << "Failed to load" << u;
     return entry;
@@ -363,6 +370,12 @@ Tellico::Fetch::FetchRequest MusicBrainzFetcher::updateRequest(Data::EntryPtr en
     return FetchRequest(UPC, barcode);
   }
 
+  QString mbid = entry_->field(QStringLiteral("musicbrainz"));
+  if(!mbid.isEmpty()) {
+    mbid = mbid.section(QLatin1Char('/'), -1);
+    return FetchRequest(Raw, QStringLiteral("reid:") + mbid);
+  }
+
   const QString title = entry_->field(QStringLiteral("title"));
   const QString artist = entry_->field(QStringLiteral("artist"));
   if(artist.isEmpty() && !title.isEmpty()) {
@@ -390,6 +403,7 @@ QString MusicBrainzFetcher::defaultIcon() {
 Tellico::StringHash MusicBrainzFetcher::allOptionalFields() {
   StringHash hash;
   hash[QStringLiteral("barcode")] = i18n("Barcode");
+  hash[QStringLiteral("musicbrainz")] = i18n("MusicBrainz Link");
   return hash;
 }
 
