@@ -29,7 +29,7 @@
 #include "../gui/combobox.h"
 #include "../utils/guiproxy.h"
 #include "../utils/string_utils.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
@@ -37,11 +37,8 @@
 #include <KJobUiDelegate>
 #include <KJobWidgets>
 #include <KConfigGroup>
-#include <KLanguageName>
-#include <kguiaddons_version.h>
-#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
 #include <KCountryFlagEmojiIconEngine>
-#endif
+#include <KLanguageName>
 
 #include <QLabel>
 #include <QLineEdit>
@@ -163,7 +160,7 @@ void NumistaFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void NumistaFetcher::slotComplete(KJob* ) {
@@ -201,40 +198,40 @@ void NumistaFetcher::slotComplete(KJob* ) {
     stop();
     return;
   }
-  QJsonObject obj = doc.object();
+  const auto obj = doc.object();
 
   // check for error
-  if(obj.contains(QStringLiteral("error"))) {
-    const QString msg = obj.value(QStringLiteral("error")).toString();
+  if(obj.contains(QLatin1StringView("error"))) {
+    const QString msg = obj.value(QLatin1StringView("error")).toString();
     message(msg, MessageHandler::Error);
     myDebug() << "NumistaFetcher -" << msg;
     stop();
     return;
   }
 
-  m_total = obj.value(QLatin1String("count")).toInt();
+  m_total = obj.value(QLatin1StringView("count")).toInt();
   m_hasMoreResults = m_total > m_page*m_limit;
 
   int count = 0;
-  QJsonArray results = obj.value(QLatin1String("coins")).toArray();
+  QJsonArray results = obj.value(QLatin1StringView("coins")).toArray();
   for(QJsonArray::const_iterator i = results.constBegin(); i != results.constEnd(); ++i) {
     if(count >= m_limit) {
       break;
     }
     QJsonObject result = (*i).toObject();
 
-    QString desc = result.value(QLatin1String("issuer")).toObject()
-                         .value(QLatin1String("name")).toString();
-    const QString minYear = result.value(QLatin1String("minYear")).toString();
+    QString desc = result.value(QLatin1StringView("issuer")).toObject()
+                         .value(QLatin1StringView("name")).toString();
+    const QString minYear = result.value(QLatin1StringView("minYear")).toString();
     if(!minYear.isEmpty()) {
-      desc += QLatin1Char('/') + minYear + QLatin1Char('-') + result.value(QLatin1String("maxYear")).toString();
+      desc += QLatin1Char('/') + minYear + QLatin1Char('-') + result.value(QLatin1StringView("maxYear")).toString();
     }
-    QString title = result.value(QLatin1String("title")).toString();
+    QString title = result.value(QLatin1StringView("title")).toString();
     // some results include &quot;
-    title.replace(QLatin1String("&quot;"), QLatin1String("\""));
+    title.replace(QLatin1StringView("&quot;"), QLatin1StringView("\""));
     FetchResult* r = new FetchResult(this, title, desc);
-    m_matches.insert(r->uid, result.value(QLatin1String("id")).toInt());
-    emit signalResultFound(r);
+    m_matches.insert(r->uid, result.value(QLatin1StringView("id")).toInt());
+    Q_EMIT signalResultFound(r);
     ++count;
   }
 
@@ -315,58 +312,58 @@ Tellico::Data::EntryPtr NumistaFetcher::parseEntry(const QByteArray& data_) {
   Data::EntryPtr entry(new Data::Entry(coll));
   coll->addEntries(entry);
 
-  QVariantMap objectMap = doc.object().toVariantMap();
+  const auto obj = doc.object();
   // for type, try to tease out from title
   // use ruler name as a possible fallback
   QRegularExpression titleQuote(QStringLiteral("\"(.+)\""));
-  QRegularExpressionMatch quoteMatch = titleQuote.match(mapValue(objectMap, "title"));
+  QRegularExpressionMatch quoteMatch = titleQuote.match(objValue(obj, "title"));
   if(quoteMatch.hasMatch()) {
     entry->setField(QStringLiteral("type"), quoteMatch.captured(1));
   } else {
-    entry->setField(QStringLiteral("type"), mapValue(objectMap, "ruler", "name"));
+    entry->setField(QStringLiteral("type"), objValue(obj, "ruler", "name"));
   }
 
-  entry->setField(QStringLiteral("denomination"), mapValue(objectMap, "value", "text"));
-  entry->setField(QStringLiteral("currency"), mapValue(objectMap, "value", "currency", "name"));
-  entry->setField(QStringLiteral("country"), mapValue(objectMap, "issuer", "name"));
-  entry->setField(QStringLiteral("mintmark"), mapValue(objectMap, "mintLetter"));
+  entry->setField(QStringLiteral("denomination"), objValue(obj, "value", "text"));
+  entry->setField(QStringLiteral("currency"), objValue(obj, "value", "currency", "name"));
+  entry->setField(QStringLiteral("country"), objValue(obj, "issuer", "name"));
+  entry->setField(QStringLiteral("mintmark"), objValue(obj, "mintLetter"));
 
   // if minyear = maxyear, then set the year of the coin
-  auto year = objectMap.value(QLatin1String("minYear"));
-  if(year == objectMap.value(QLatin1String("maxYear"))) {
-    entry->setField(QStringLiteral("year"), year.toString());
+  const auto year = obj[QLatin1StringView("minYear")];
+  if(year == obj[QLatin1StringView("maxYear")]) {
+    entry->setField(QStringLiteral("year"), QString::number(year.toDouble()));
   } else if(!m_year.isEmpty()) {
     entry->setField(QStringLiteral("year"), m_year);
   }
 
-  entry->setField(QStringLiteral("obverse"), mapValue(objectMap, "obverse", "picture"));
-  entry->setField(QStringLiteral("reverse"), mapValue(objectMap, "reverse", "picture"));
+  entry->setField(QStringLiteral("obverse"), objValue(obj, "obverse", "picture"));
+  entry->setField(QStringLiteral("reverse"), objValue(obj, "reverse", "picture"));
 
   const QString numista(QStringLiteral("numista"));
   if(optionalFields().contains(numista)) {
     Data::FieldPtr field(new Data::Field(numista, i18n("Numista Link"), Data::Field::URL));
     field->setCategory(i18n("General"));
     coll->addField(field);
-    entry->setField(numista, mapValue(objectMap, "url"));
+    entry->setField(numista, objValue(obj, "url"));
   }
 
   const QString desc(QStringLiteral("description"));
   if(!coll->hasField(desc) && optionalFields().contains(desc)) {
     Data::FieldPtr field(new Data::Field(desc, i18n("Description"), Data::Field::Para));
     coll->addField(field);
-    entry->setField(QStringLiteral("description"), mapValue(objectMap, "comments"));
+    entry->setField(QStringLiteral("description"), objValue(obj, "comments"));
   }
 
-  QVariantList refs = objectMap.value(QStringLiteral("references")).toList();
   const QString krause(QStringLiteral("km"));
   if(!coll->hasField(krause) && optionalFields().contains(krause)) {
     Data::FieldPtr field(new Data::Field(krause, allOptionalFields().value(krause)));
     field->setCategory(i18n("General"));
     coll->addField(field);
-    foreach(const QVariant& ref, refs) {
-      QVariantMap refMap = ref.toMap();
-      if(mapValue(refMap, "catalogue", "code") == QLatin1String("KM")) {
-        entry->setField(krause, mapValue(refMap, "number"));
+    const auto refArray = obj[QLatin1StringView("references")].toArray();
+    for(const auto& ref : refArray) {
+      const auto refObj = ref.toObject();
+      if(objValue(refObj, "catalogue", "code") == QLatin1String("KM")) {
+        entry->setField(krause, objValue(refObj, "number"));
         // don't break out, there could be multiple KM values and we want the last one
       }
     }
@@ -427,19 +424,12 @@ NumistaFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const NumistaFetche
   label = new QLabel(i18n("Language: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_langCombo = new GUI::ComboBox(optionsWidget());
-#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
   m_langCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QLatin1String("us"))),
-                       KLanguageName::nameForCode(QLatin1String("en")),
+                       KLanguageName::nameForCode(QStringLiteral("en")),
                        QLatin1String("en"));
   m_langCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QLatin1String("fr"))),
-                       KLanguageName::nameForCode(QLatin1String("fr")),
+                       KLanguageName::nameForCode(QStringLiteral("fr")),
                        QLatin1String("fr"));
-#else
-  m_langCombo->addItem(KLanguageName::nameForCode(QLatin1String("en")),
-                       QLatin1String("en"));
-  m_langCombo->addItem(KLanguageName::nameForCode(QLatin1String("fr")),
-                       QLatin1String("fr"));
-#endif
   void (GUI::ComboBox::* activatedInt)(int) = &GUI::ComboBox::activated;
   connect(m_langCombo, activatedInt, this, &ConfigWidget::slotSetModified);
   connect(m_langCombo, activatedInt, this, &ConfigWidget::slotLangChanged);
@@ -474,5 +464,5 @@ QString NumistaFetcher::ConfigWidget::preferredName() const {
 }
 
 void NumistaFetcher::ConfigWidget::slotLangChanged() {
-  emit signalName(preferredName());
+  Q_EMIT signalName(preferredName());
 }
