@@ -29,7 +29,7 @@
 #include "../gui/combobox.h"
 #include "../utils/isbnvalidator.h"
 #include "../utils/guiproxy.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../entry.h"
 #include "../core/filehandler.h"
 #include "../tellico_debug.h"
@@ -143,7 +143,8 @@ void OpenLibraryFetcher::doSearch(const QString& term_) {
       {
         // raw query comes in as a query string, combine it
         QUrlQuery newQuery(term_);
-        for(const auto& item : newQuery.queryItems()) {
+        const auto newQueryItems = newQuery.queryItems();
+        for(const auto& item : newQueryItems) {
           q.addQueryItem(item.first, item.second);
         }
       }
@@ -181,7 +182,7 @@ void OpenLibraryFetcher::stop() {
   }
   m_jobs.clear();
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 Tellico::Data::EntryPtr OpenLibraryFetcher::fetchEntryHook(uint uid_) {
@@ -220,27 +221,26 @@ Tellico::Data::EntryPtr OpenLibraryFetcher::fetchEntryHook(uint uid_) {
     const auto obj = doc.object();
 
     if(entry->field(plotString).isEmpty()) {
-      const auto map = obj.toVariantMap();
-      QString desc = mapValue(map, "description", "value");
+      QString desc = objValue(obj, "description", "value");
       if(desc.isEmpty()) {
-        desc = mapValue(map, "description");
+        desc = objValue(obj, "description");
       }
       desc.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
       entry->setField(plotString, desc);
     }
 
     if(entry->field(authorString).isEmpty()) {
-      QStringList authors = getAuthorNames(obj[QLatin1String("authors")].toArray().toVariantList());
+      QStringList authors = getAuthorNames(obj.value(QLatin1StringView("authors")).toArray());
       if(!authors.isEmpty()) {
         entry->setField(authorString, authors.join(FieldFormat::delimiterString()));
       }
     }
 
     if(entry->field(seriesString).isEmpty()) {
-      const auto subjArray = obj.value(QLatin1String("subjects")).toArray();
+      const auto subjArray = obj.value(QLatin1StringView("subjects")).toArray();
       for(const auto& res : subjArray) {
         QString value = res.toString();
-        if(value.startsWith(QLatin1String("series:"))) {
+        if(value.startsWith(QLatin1StringView("series:"))) {
           value.remove(0, 7); // remove first 7 characters
           value.replace(QLatin1Char('_'), QLatin1Char(' '));
           value = FieldFormat::capitalize(value);
@@ -340,7 +340,7 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
 #endif
 
   QJsonDocument doc = QJsonDocument::fromJson(data);
-  QJsonArray array = doc.array();
+  const auto array = doc.array();
   if(array.isEmpty()) {
     endJob(job);
     return;
@@ -353,34 +353,34 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
     coll = new Data::BookCollection(true);
   }
 
-  for(int i = 0; i < array.count(); i++) {
+  for(const auto& result : array) {
     // be sure to check that the fetcher has not been stopped
     // crashes can occur if not
     if(!m_started) {
       break;
     }
 
-    const QVariantMap resultMap = array.at(i).toObject().toVariantMap();
+    const auto resObj = result.toObject();
     if(coll->type() == Data::Collection::ComicBook) {
-      const auto binding = mapValue(resultMap, "physical_format");
+      const auto binding = objValue(resObj, "physical_format");
       if(!binding.isEmpty() && binding != QLatin1String("comic")) {
-        myLog() << "Skipping non-comic result:" << mapValue(resultMap, "title");
+        myLog() << "Skipping non-comic result:" << objValue(resObj, "title");
         continue;
       }
     }
 
     Data::EntryPtr entry(new Data::Entry(coll));
-    populate(entry, resultMap);
+    populate(entry, resObj);
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
 
     // retain olid and link to parent work
-    m_olidLink.insert(r->uid, mapValue(resultMap, "key"));
-    const auto works = resultMap[QLatin1String("works")].toList();
-    if(!works.isEmpty()) {
-      const auto workMap = works.first().toMap();
-      const QString key = mapValue(workMap, "key");
+    m_olidLink.insert(r->uid, objValue(resObj, "key"));
+    const auto worksArray = resObj[QLatin1StringView("works")].toArray();
+    if(!worksArray.isEmpty()) {
+      const auto workObj = worksArray.first().toObject();
+      const QString key = objValue(workObj, "key");
       if(!key.isEmpty()) {
         m_workLink.insert(r->uid, key);
       }
@@ -395,35 +395,37 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
   endJob(job);
 }
 
-void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_) {
+void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QJsonObject& obj_) {
   static const QRegularExpression yearRx(QStringLiteral("\\d{4}"));
 
-  entry_->setField(QStringLiteral("title"), mapValue(map_, "title"));
-  QString binding = mapValue(map_, "physical_format");
+  entry_->setField(QStringLiteral("title"), objValue(obj_, "title"));
+
+  // only allow comic format for comic book collections
+  QString binding = objValue(obj_, "physical_format");
   const auto bindingLower = binding.toLower();
-  if(bindingLower == QLatin1String("hardcover")) {
+  if(bindingLower == QLatin1StringView("hardcover")) {
     binding = QStringLiteral("Hardback");
-  } else if(bindingLower == QLatin1String("ebook")) {
+  } else if(bindingLower == QLatin1StringView("ebook")) {
     binding = QStringLiteral("E-Book");
-  } else if(bindingLower.contains(QStringLiteral("paperback"))) {
+  } else if(bindingLower.contains(QLatin1StringView("paperback"))) {
     binding = QStringLiteral("Paperback");
   }
   if(!binding.isEmpty()) {
     entry_->setField(QStringLiteral("binding"), i18n(binding.toUtf8().constData()));
   }
 
-  entry_->setField(QStringLiteral("subtitle"), mapValue(map_, "subtitle"));
-  auto yearMatch = yearRx.match(mapValue(map_, "publish_date"));
+  entry_->setField(QStringLiteral("subtitle"), objValue(obj_, "subtitle"));
+  auto yearMatch = yearRx.match(objValue(obj_, "publish_date"));
   if(yearMatch.hasMatch()) {
     entry_->setField(QStringLiteral("pub_year"), yearMatch.captured());
   }
-  yearMatch = yearRx.match(mapValue(map_, "copyright_date"));
+  yearMatch = yearRx.match(objValue(obj_, "copyright_date"));
   if(yearMatch.hasMatch()) {
     entry_->setField(QStringLiteral("cr_year"), yearMatch.captured());
   }
-  QString isbn = mapValue(map_, "isbn_10");
+  QString isbn = objValue(obj_, "isbn_10");
   if(isbn.isEmpty()) {
-    isbn = mapValue(map_, "isbn_13");
+    isbn = objValue(obj_, "isbn_13");
   }
   const QString isbnName(QStringLiteral("isbn"));
   if(!isbn.isEmpty()) {
@@ -435,30 +437,30 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
     entry_->setField(isbnName, isbn);
   }
   const QString lccnName(QStringLiteral("lccn"));
-  const QString lccn = mapValue(map_, "lccn");
+  const QString lccn = objValue(obj_, "lccn");
   if(!lccn.isEmpty()) {
     if(!entry_->collection()->hasField(lccnName)) {
       entry_->collection()->addField(Data::Field::createDefaultField(Data::Field::LccnField));
     }
     entry_->setField(lccnName, lccn);
   }
-  entry_->setField(QStringLiteral("genre"), mapValue(map_, "genres"));
-  entry_->setField(QStringLiteral("keyword"), mapValue(map_, "subjects"));
-  entry_->setField(QStringLiteral("edition"), mapValue(map_, "edition_name"));
-  entry_->setField(QStringLiteral("publisher"), mapValue(map_, "publishers"));
-  entry_->setField(QStringLiteral("series"), mapValue(map_, "series"));
-  entry_->setField(QStringLiteral("pages"), mapValue(map_, "number_of_pages"));
+  entry_->setField(QStringLiteral("genre"), objValue(obj_, "genres"));
+  entry_->setField(QStringLiteral("keyword"), objValue(obj_, "subjects"));
+  entry_->setField(QStringLiteral("edition"), objValue(obj_, "edition_name"));
+  entry_->setField(QStringLiteral("publisher"), objValue(obj_, "publishers"));
+  entry_->setField(QStringLiteral("series"), objValue(obj_, "series"));
+  entry_->setField(QStringLiteral("pages"), objValue(obj_, "number_of_pages"));
 
-  QString desc = mapValue(map_, "description", "value");
+  QString desc = objValue(obj_, "description", "value");
   if(desc.isEmpty()) {
-    desc = mapValue(map_, "description");
+    desc = objValue(obj_, "description");
   }
   desc.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
   entry_->setField(QStringLiteral("plot"), desc);
 
-  QString notes = mapValue(map_, "notes", "value");
+  QString notes = objValue(obj_, "notes", "value");
   if(notes.isEmpty()) {
-    notes = mapValue(map_, "notes");
+    notes = objValue(obj_, "notes");
   }
   notes.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
   entry_->setField(QStringLiteral("comments"), notes);
@@ -470,10 +472,10 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
       field->setCategory(i18n("General"));
       entry_->collection()->addField(field);
     }
-    entry_->setField(openlibraryString, QLatin1String("https://openlibrary.org") + mapValue(map_, "key"));
+    entry_->setField(openlibraryString, QLatin1String("https://openlibrary.org") + objValue(obj_, "key"));
   }
 
-  QStringList authors = getAuthorNames(map_[QLatin1String("authors")].toList());
+  QStringList authors = getAuthorNames(obj_[QLatin1StringView("authors")].toArray());
   if(!authors.isEmpty()) {
     const QString authorString = entry_->collection()->type() == Data::Collection::ComicBook
                                  ? QStringLiteral("writer")
@@ -482,11 +484,12 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
   }
 
   QStringList translators;
-  foreach(const QVariant& contrib, map_.value(QLatin1String("contributors")).toList()) {
-    const auto contribMap = contrib.toMap();
-    const auto role = mapValue(contribMap, "role");
-    if(role == QLatin1String("Translator")) {
-      translators += mapValue(contribMap, "name");
+  const auto contribsArray = obj_[QLatin1StringView("contributors")].toArray();
+  for(const auto& contrib : contribsArray) {
+    const auto contribObj = contrib.toObject();
+    const auto role = objValue(contribObj, "role");
+    if(role == QLatin1StringView("Translator")) {
+      translators += objValue(contribObj, "name");
     }
   }
   if(!translators.isEmpty()) {
@@ -494,8 +497,10 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
   }
 
   QStringList langs;
-  foreach(const QVariant& langMap, map_.value(QLatin1String("languages")).toList()) {
-    const QString key = mapValue(langMap.toMap(), "key");
+  const auto langArray = obj_[QLatin1String("languages")].toArray();
+  for(const auto& lang : langArray) {
+    const auto langObj = lang.toObject();
+    const QString key = objValue(langObj, "key");
     if(m_langHash.contains(key)) {
       langs += m_langHash.value(key);
     } else if(!key.isEmpty()) {
@@ -507,13 +512,14 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
       langUrl.setQuery(q);
 
       const auto output = FileHandler::readDataFile(langUrl, true /*quiet*/);
-      QJsonDocument doc = QJsonDocument::fromJson(output);
-      QJsonArray array = doc.array();
-      QVariantMap langResult = array.isEmpty() ? QVariantMap() : array.at(0).toObject().toVariantMap();
-      const QString name = mapValue(langResult, "name");
-      if(!name.isEmpty()) {
-        langs << i18n(name.toUtf8().constData());
-        m_langHash.insert(key, langs.last());
+      QJsonDocument doc2 = QJsonDocument::fromJson(output);
+      const auto langArray = doc2.array();
+      if(!langArray.isEmpty()) {
+        const QString name = objValue(langArray.at(0).toObject(), "name");
+        if(!name.isEmpty()) {
+          langs << i18n(name.toUtf8().constData());
+          m_langHash.insert(key, langs.last());
+        }
       }
     }
   }
@@ -522,20 +528,20 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
   }
 }
 
-QStringList OpenLibraryFetcher::getAuthorNames(const QVariantList& keys_) {
+QStringList OpenLibraryFetcher::getAuthorNames(const QJsonArray& keys_) {
   QStringList authors;
   if(keys_.isEmpty()) {
     return authors;
   }
 
   bool emptyQuery = true;
-  QString authorQuery(QLatin1String("key:("));
+  QString authorQuery(QStringLiteral("key:("));
   for(int i = 0; i < keys_.count(); i++) {
-    const auto map = keys_.at(i).toMap();
-    QString key = mapValue(map, "author", "key");
-    if(key.isEmpty()) key = mapValue(map, "key");
+    const auto obj = keys_.at(i).toObject();
+    QString key = objValue(obj, "author", "key");
+    if(key.isEmpty()) key = objValue(obj, "key");
     if(key.isEmpty()) {
-      myDebug() << "Failed to pull key from" << map;
+      myDebug() << "Failed to pull key from" << obj;
       continue;
     }
     if(!key.startsWith(QLatin1String("/authors/"))) {
@@ -564,14 +570,14 @@ QStringList OpenLibraryFetcher::getAuthorNames(const QVariantList& keys_) {
 
   const auto output = FileHandler::readDataFile(u, true /*quiet*/);
   const QJsonDocument doc = QJsonDocument::fromJson(output);
-  const auto array = doc.object().value(QLatin1String("docs")).toArray();
+  const auto array = doc.object().value(QLatin1StringView("docs")).toArray();
   for(int i = 0; i < array.count(); i++) {
-    const auto map = array.at(i).toObject().toVariantMap();
-    QString key = mapValue(map, "key");
-    if(!key.startsWith(QLatin1String("/authors/"))) {
+    const auto obj = array.at(i).toObject();
+    QString key = objValue(obj, "key");
+    if(!key.startsWith(QLatin1StringView("/authors/"))) {
       key = QLatin1String("/authors/") + key;
     }
-    const QString author = mapValue(map, "name");
+    const QString author = objValue(obj, "name");
     if(!author.isEmpty()) {
       m_authorHash.insert(key, author);
       authors += author;
@@ -599,14 +605,14 @@ QString OpenLibraryFetcher::getAuthorKeys(const QString& term_) {
   f.close();
 #endif
   const QJsonDocument doc = QJsonDocument::fromJson(output);
-  const auto array = doc.object().value(QLatin1String("docs")).toArray();
+  const auto array = doc.object().value(QLatin1StringView("docs")).toArray();
   if(array.isEmpty()) {
     return QString();
   }
   // right now, only use the first to search on
   const auto obj1 = array.at(0).toObject();
-  const auto key = obj1.value(QLatin1String("key")).toString();
-  const auto name = obj1.value(QLatin1String("name")).toString();
+  const auto key = obj1.value(QLatin1StringView("key")).toString();
+  const auto name = obj1.value(QLatin1StringView("name")).toString();
   m_authorHash.insert(key, name);
   return key;
 }
