@@ -33,6 +33,7 @@
 #include "../gui/combobox.h"
 #include "../gui/stringmapwidget.h"
 #include "../utils/string_utils.h"
+#include "../utils/tellico_utils.h"
 #include "../utils/lccnvalidator.h"
 #include "../utils/isbnvalidator.h"
 #include "../utils/datafileregistry.h"
@@ -171,9 +172,9 @@ void SRUFetcher::search() {
   switch(request().key()) {
     case Title:
       {
-        QString context(QLatin1String("dc.title"));
-        if(m_queryMap.contains(QLatin1String("x-tellico-title"))) {
-          context = m_queryMap[QLatin1String("x-tellico-title")];
+        QString context(QStringLiteral("dc.title"));
+        if(m_queryMap.contains(QStringLiteral("x-tellico-title"))) {
+          context = m_queryMap[QStringLiteral("x-tellico-title")];
         }
         query.addQueryItem(QStringLiteral("query"), queryTerm(context,
                                                               request().value(),
@@ -185,15 +186,15 @@ void SRUFetcher::search() {
       {
         QString s;
         if(type == Data::Collection::Book || type == Data::Collection::Bibtex) {
-          QString context(QLatin1String("author"));
-          if(m_queryMap.contains(QLatin1String("x-tellico-author"))) {
-            context = m_queryMap[QLatin1String("x-tellico-author")];
+          QString context(QStringLiteral("author"));
+          if(m_queryMap.contains(QStringLiteral("x-tellico-author"))) {
+            context = m_queryMap[QStringLiteral("x-tellico-author")];
           }
-          s = queryTerm(QLatin1String("author"), request().value(), cqlVersion);
+          s = queryTerm(QStringLiteral("author"), request().value(), cqlVersion);
         } else {
-          s = queryTerm(QLatin1String("dc.creator"), request().value(), cqlVersion) +
+          s = queryTerm(QStringLiteral("dc.creator"), request().value(), cqlVersion) +
               QLatin1String(" or ") +
-              queryTerm(QLatin1String("dc.editor"), request().value(), cqlVersion);
+              queryTerm(QStringLiteral("dc.editor"), request().value(), cqlVersion);
         }
         query.addQueryItem(QStringLiteral("query"), s);
       }
@@ -218,11 +219,11 @@ void SRUFetcher::search() {
           // make an assumption that DC output uses the dc profile and everything else uses Bath for ISBN
           // no idea if this holds true universally, but matches LOC, COPAC, and KB
           if(m_format == QLatin1String("dc") || m_format == QLatin1String("dublincore")) {
-            q += queryTerm(QLatin1String("dc.identifier"), isbnList.at(i), cqlVersion);
+            q += queryTerm(QStringLiteral("dc.identifier"), isbnList.at(i), cqlVersion);
           } else {
-            QString isbnContext(QLatin1String("bath.isbn"));
-            if(m_queryMap.contains(QLatin1String("x-tellico-isbn"))) {
-              isbnContext = m_queryMap[QLatin1String("x-tellico-isbn")];
+            QString isbnContext(QStringLiteral("bath.isbn"));
+            if(m_queryMap.contains(QStringLiteral("x-tellico-isbn"))) {
+              isbnContext = m_queryMap[QStringLiteral("x-tellico-isbn")];
             }
             q += queryTerm(isbnContext, isbnList.at(i), cqlVersion);
           }
@@ -239,8 +240,8 @@ void SRUFetcher::search() {
         QStringList lccnList = FieldFormat::splitValue(request().value());
         QString q;
         for(int i = 0; i < lccnList.count(); ++i) {
-          q += queryTerm(QLatin1String("bath.lccn"), lccnList.at(i), cqlVersion) + QLatin1String(" or ") +
-               queryTerm(QLatin1String("bath.lccn"), LCCNValidator::formalize(lccnList.at(i)), cqlVersion);
+          q += queryTerm(QStringLiteral("bath.lccn"), lccnList.at(i), cqlVersion) + QLatin1String(" or ") +
+               queryTerm(QStringLiteral("bath.lccn"), LCCNValidator::formalize(lccnList.at(i)), cqlVersion);
           if(i < lccnList.count()-1) {
             q += QLatin1String(" or ");
           }
@@ -278,6 +279,7 @@ void SRUFetcher::search() {
     myLog() << "GETing SRU request:" << u.url();
     m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   }
+  Tellico::addUserAgent(m_job);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job.data(), &KJob::result,
           this, &SRUFetcher::slotComplete);
@@ -293,7 +295,7 @@ void SRUFetcher::stop() {
   }
 
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void SRUFetcher::slotComplete(KJob*) {
@@ -330,11 +332,7 @@ void SRUFetcher::slotComplete(KJob*) {
 
   // first check for SRU errors
   QDomDocument dom;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
-  if(!dom.setContent(result, true /*namespace*/)) {
-#else
   if(!dom.setContent(result, QDomDocument::ParseOption::UseNamespaceProcessing)) {
-#endif
     myWarning() << "The server did not return valid XML.";
     stop();
     return;
@@ -371,15 +369,15 @@ void SRUFetcher::slotComplete(KJob*) {
     HandlerType handlerType = MARC21;
     // brute force marcxchange conversion. This is probably wrong at some level
     QString newResult = result;
-    if(m_format.startsWith(QLatin1String("marcxchange"), Qt::CaseInsensitive)) {
+    if(m_format.startsWith(QLatin1StringView("marcxchange"), Qt::CaseInsensitive)) {
       myLog() << "Replacing marcXchange namespace with MARC21";
-      if(newResult.contains(QLatin1String("format=\"UNIMARC\""))) {
+      if(newResult.contains(QLatin1StringView("format=\"UNIMARC\""))) {
         myLog() << "Reading marcXchange data as UNIMARC";
         handlerType = UNIMARC;
       } else {
         myLog() << "Reading marcXchange data as MARC21";
       }
-      static const QRegularExpression marcRx(QLatin1String("xmlns:([^=]+)=\"info:lc/xmlns/marcxchange-v[12]\""));
+      static const QRegularExpression marcRx(QStringLiteral("xmlns:([^=]+)=\"info:lc/xmlns/marcxchange-v[12]\""));
       newResult.replace(marcRx, QStringLiteral("xmlns:\\1=\"http://www.loc.gov/MARC21/slim\""));
     }
     if(initHandler(handlerType)) {
@@ -394,10 +392,10 @@ void SRUFetcher::slotComplete(KJob*) {
       msg += QLatin1Char('\n');
     }
     msg += imp.statusMessage();
-  } else if((m_format == QLatin1String("pam") ||
-             m_format == QLatin1String("dc") ||
-             m_format == QLatin1String("dublincore") ||
-             m_format == QLatin1String("none")) &&
+  } else if((m_format == QLatin1StringView("pam") ||
+             m_format == QLatin1StringView("dc") ||
+             m_format == QLatin1StringView("dublincore") ||
+             m_format == QLatin1StringView("none")) &&
             initHandler(SRW)) {
     const auto tellicoXml = m_handlers[SRW]->applyStylesheet(result);
 #if 0
@@ -450,7 +448,7 @@ void SRUFetcher::slotComplete(KJob*) {
   foreach(Data::EntryPtr entry, coll->entries()) {
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
   stop();
 }
@@ -526,9 +524,9 @@ bool SRUFetcher::initHandler(HandlerType type_) {
 QString SRUFetcher::queryTerm(const QString& index_, const QString& term_, const QString& ver_) const {
   QString tmp;
   if(ver_ == QLatin1String("1.1")) {
-    tmp = QLatin1String("%1=\"%2\"");
+    tmp = QStringLiteral("%1=\"%2\"");
   } else {
-    tmp = QLatin1String("%1 adj \"%2\"");
+    tmp = QStringLiteral("%1 adj \"%2\"");
   }
   return tmp.arg(index_, term_);
 }
