@@ -26,7 +26,7 @@
 #include "../collectionfactory.h"
 #include "../images/imagefactory.h"
 #include "../utils/guiproxy.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../utils/isbnvalidator.h"
 #include "../tellico_debug.h"
 
@@ -135,7 +135,7 @@ void UPCItemDbFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 Tellico::Fetch::FetchRequest UPCItemDbFetcher::updateRequest(Data::EntryPtr entry_) {
@@ -194,8 +194,8 @@ void UPCItemDbFetcher::slotComplete(KJob* job_) {
   }
   const auto obj = doc.object();
   // check for error
-  if(obj.value(QStringLiteral("code")) == QLatin1String("TOO_FAST")) {
-    const QString msg = obj.value(QStringLiteral("message")).toString();
+  if(obj.value(QLatin1StringView("code")) == QLatin1String("TOO_FAST")) {
+    const auto msg = objValue(obj, "message");
     message(msg, MessageHandler::Error);
     myDebug() << "UPCItemDbFetcher -" << msg;
     stop();
@@ -214,7 +214,7 @@ void UPCItemDbFetcher::slotComplete(KJob* job_) {
     coll->addField(field);
   }
 
-  const auto results = obj.value(QLatin1String("items")).toArray();
+  const auto results = obj.value(QLatin1StringView("items")).toArray();
   if(results.isEmpty()) {
     myLog() << "No results";
     stop();
@@ -226,11 +226,11 @@ void UPCItemDbFetcher::slotComplete(KJob* job_) {
 //    myDebug() << "found result:" << result;
 
     Data::EntryPtr entry(new Data::Entry(coll));
-    populateEntry(entry, result.toObject().toVariantMap());
+    populateEntry(entry, result.toObject());
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
     ++count;
     if(count >= UPCITEMDB_MAX_RETURNS_TOTAL) {
       break;
@@ -265,21 +265,21 @@ Tellico::Data::EntryPtr UPCItemDbFetcher::fetchEntryHook(uint uid_) {
   return entry;
 }
 
-void UPCItemDbFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& resultMap_) {
-  entry_->setField(QStringLiteral("title"), mapValue(resultMap_, "title"));
+void UPCItemDbFetcher::populateEntry(Data::EntryPtr entry_, const QJsonObject& obj_) {
+  entry_->setField(QStringLiteral("title"), objValue(obj_, "title"));
   parseTitle(entry_);
-//  entry_->setField(QStringLiteral("year"),  mapValue(resultMap_, "premiered").left(4));
+//  entry_->setField(QStringLiteral("year"), objValue(obj_, "premiered").left(4));
   const QString barcode = QStringLiteral("barcode");
   if(optionalFields().contains(barcode)) {
-    entry_->setField(barcode, mapValue(resultMap_, "upc"));
+    entry_->setField(barcode, objValue(obj_, "upc"));
   }
 
   // take the first cover
-  const auto imageList = resultMap_.value(QLatin1String("images")).toList();
+  const auto imageList = obj_[QLatin1StringView("images")].toArray();
   for(const auto& imageValue : imageList) {
     // skip booksamillion images
     const QString image = imageValue.toString();
-    if(!image.isEmpty() && !image.contains(QLatin1String("booksamillion.com"))) {
+    if(!image.isEmpty() && !image.contains(QLatin1StringView("booksamillion.com"))) {
       entry_->setField(QStringLiteral("cover"), image);
       break;
     }
@@ -287,19 +287,19 @@ void UPCItemDbFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& r
 
   switch(collectionType()) {
     case Data::Collection::Video:
-      entry_->setField(QStringLiteral("studio"), mapValue(resultMap_, "brand"));
-      entry_->setField(QStringLiteral("plot"), mapValue(resultMap_, "description"));
+      entry_->setField(QStringLiteral("studio"), objValue(obj_, "brand"));
+      entry_->setField(QStringLiteral("plot"), objValue(obj_, "description"));
       break;
 
     case Data::Collection::Book:
-      entry_->setField(QStringLiteral("publisher"), mapValue(resultMap_, "publisher"));
-      entry_->setField(QStringLiteral("isbn"), mapValue(resultMap_, "isbn"));
+      entry_->setField(QStringLiteral("publisher"), objValue(obj_, "publisher"));
+      entry_->setField(QStringLiteral("isbn"), objValue(obj_, "isbn"));
       break;
 
     case Data::Collection::Album:
-      entry_->setField(QStringLiteral("label"), mapValue(resultMap_, "brand"));
+      entry_->setField(QStringLiteral("label"), objValue(obj_, "brand"));
       {
-        const QString cat = mapValue(resultMap_, "category");
+        const QString cat = objValue(obj_, "category");
         if(cat.contains(QStringLiteral("Music CDs"))) {
           entry_->setField(QStringLiteral("medium"), i18n("Compact Disc"));
         }
@@ -308,8 +308,8 @@ void UPCItemDbFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& r
 
     case Data::Collection::Game:
     case Data::Collection::BoardGame:
-      entry_->setField(QStringLiteral("publisher"), mapValue(resultMap_, "brand"));
-      entry_->setField(QStringLiteral("description"), mapValue(resultMap_, "description"));
+      entry_->setField(QStringLiteral("publisher"), objValue(obj_, "brand"));
+      entry_->setField(QStringLiteral("description"), objValue(obj_, "description"));
       break;
 
     default:
@@ -322,7 +322,7 @@ void UPCItemDbFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& r
 
 void UPCItemDbFetcher::parseTitle(Tellico::Data::EntryPtr entry_) {
   // assume that everything in brackets or parentheses is extra
-  static const QRegularExpression rx(QLatin1String("[\\(\\[](.*?)[\\)\\]]"));
+  static const QRegularExpression rx(QStringLiteral("[\\(\\[](.*?)[\\)\\]]"));
   QString title = entry_->field(QStringLiteral("title"));
   int pos = 0;
   QRegularExpressionMatch match = rx.match(title, pos);
@@ -335,14 +335,14 @@ void UPCItemDbFetcher::parseTitle(Tellico::Data::EntryPtr entry_) {
     match = rx.match(title, pos+1);
   }
   // look for "word1 - word2"
-  static const QRegularExpression dashWords(QLatin1String("(.+) - (.+)"));
+  static const QRegularExpression dashWords(QStringLiteral("(.+) - (.+)"));
   QRegularExpressionMatch dashMatch = dashWords.match(title);
   if(dashMatch.hasMatch()) {
     switch(collectionType()) {
       case Data::Collection::Book:
         title = dashMatch.captured(1);
         {
-          static const QRegularExpression byAuthor(QLatin1String("by (.+)"));
+          static const QRegularExpression byAuthor(QStringLiteral("by (.+)"));
           QRegularExpressionMatch authorMatch = byAuthor.match(dashMatch.captured(2));
           if(authorMatch.hasMatch()) {
             entry_->setField(QStringLiteral("author"), authorMatch.captured(1).simplified());
@@ -376,63 +376,63 @@ bool UPCItemDbFetcher::parseTitleToken(Tellico::Data::EntryPtr entry_, const QSt
 //  myDebug() << "title token:" << token_;
   // if res = true, then the token gets removed from the title
   bool res = false;
-  static const QRegularExpression yearRx(QLatin1String("\\d{4}"));
+  static const QRegularExpression yearRx(QStringLiteral("\\d{4}"));
   QRegularExpressionMatch yearMatch = yearRx.match(token_);
   if(yearMatch.hasMatch()) {
     entry_->setField(QStringLiteral("year"), yearMatch.captured());
     res = true;
   }
-  if(token_.indexOf(QLatin1String("widescreen"), 0, Qt::CaseInsensitive) > -1 ||
-     token_.indexOf(i18n("Widescreen"), 0, Qt::CaseInsensitive) > -1) {
+  if(token_.contains(QLatin1StringView("widescreen"), Qt::CaseInsensitive) ||
+     token_.contains(i18n("Widescreen"), Qt::CaseInsensitive)) {
     entry_->setField(QStringLiteral("widescreen"), QStringLiteral("true"));
     // res = true; leave it in the title
-  } else if(token_.indexOf(QLatin1String("full screen"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.contains(QLatin1StringView("full screen"), Qt::CaseInsensitive)) {
     // skip, but go ahead and remove from title
     res = true;
-  } else if(token_.indexOf(QLatin1String("standard edition"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.contains(QLatin1StringView("standard edition"), Qt::CaseInsensitive)) {
     // skip, but go ahead and remove from title
     res = true;
-  } else if(token_.indexOf(QLatin1String("import"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.contains(QLatin1StringView("import"), Qt::CaseInsensitive)) {
     // skip, but go ahead and remove from title
     res = true;
   }
-  if(token_.indexOf(QLatin1String("blu-ray"), 0, Qt::CaseInsensitive) > -1) {
+  if(token_.contains(QLatin1StringView("blu-ray"), Qt::CaseInsensitive)) {
     entry_->setField(QStringLiteral("medium"), i18n("Blu-ray"));
     res = true;
-  } else if(token_.indexOf(QLatin1String("hd dvd"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.contains(QLatin1StringView("hd dvd"), Qt::CaseInsensitive)) {
     entry_->setField(QStringLiteral("medium"), i18n("HD DVD"));
     res = true;
-  } else if(token_.indexOf(QLatin1String("vhs"), 0, Qt::CaseInsensitive) > -1) {
+  } else if(token_.contains(QLatin1StringView("vhs"), Qt::CaseInsensitive)) {
     entry_->setField(QStringLiteral("medium"), i18n("VHS"));
     res = true;
   }
-  if(token_.indexOf(QLatin1String("director's cut"), 0, Qt::CaseInsensitive) > -1 ||
-     token_.indexOf(i18n("Director's Cut"), 0, Qt::CaseInsensitive) > -1) {
+  if(token_.contains(QLatin1StringView("director's cut"), Qt::CaseInsensitive) ||
+     token_.contains(i18n("Director's Cut"), Qt::CaseInsensitive)) {
     entry_->setField(QStringLiteral("directors-cut"), QStringLiteral("true"));
     // res = true; leave it in the title
   }
   const QString tokenLower = token_.toLower();
-  if(tokenLower == QLatin1String("ntsc")) {
+  if(tokenLower == QLatin1StringView("ntsc")) {
     entry_->setField(QStringLiteral("format"), i18n("NTSC"));
     res = true;
   }
-  if(tokenLower == QLatin1String("dvd")) {
+  if(tokenLower == QLatin1StringView("dvd")) {
     entry_->setField(QStringLiteral("medium"), i18n("DVD"));
     res = true;
   }
-  if(tokenLower == QLatin1String("cd") && collectionType() == Data::Collection::Album) {
+  if(tokenLower == QLatin1StringView("cd") && collectionType() == Data::Collection::Album) {
     entry_->setField(QStringLiteral("medium"), i18n("Compact Disc"));
     res = true;
   }
-  if(tokenLower == QLatin1String("dvd")) {
+  if(tokenLower == QLatin1StringView("dvd")) {
     entry_->setField(QStringLiteral("medium"), i18n("DVD"));
     res = true;
   }
-  if(token_.indexOf(QLatin1String("series"), 0, Qt::CaseInsensitive) > -1) {
+  if(token_.contains(QLatin1StringView("series"), Qt::CaseInsensitive)) {
     entry_->setField(QStringLiteral("series"), token_);
     res = true;
   }
-  static const QRegularExpression regionRx(QLatin1String("Region [1-9]"));
+  static const QRegularExpression regionRx(QStringLiteral("Region [1-9]"));
   QRegularExpressionMatch match = regionRx.match(token_);
   if(match.hasMatch()) {
     entry_->setField(QStringLiteral("region"), i18n(match.captured().toUtf8().constData()));
