@@ -48,6 +48,7 @@ namespace {
 }
 
 using namespace Tellico;
+using namespace Qt::StringLiterals;
 using Tellico::Fetch::VGCollectFetcher;
 
 VGCollectFetcher::VGCollectFetcher(QObject* parent_)
@@ -106,7 +107,7 @@ void VGCollectFetcher::search() {
 //  myDebug() << "url:" << u;
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->addMetaData(QStringLiteral("referrer"), QString::fromLatin1("https://vgcollect.com/search"));
+  m_job->addMetaData(QStringLiteral("referrer"), QStringLiteral("https://vgcollect.com/search"));
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job.data(), &KJob::result,
           this, &VGCollectFetcher::slotComplete);
@@ -122,7 +123,7 @@ void VGCollectFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void VGCollectFetcher::slotComplete(KJob*) {
@@ -157,7 +158,7 @@ void VGCollectFetcher::slotComplete(KJob*) {
                                         QRegularExpression::DotMatchesEverythingOption);
   static const QRegularExpression itemRx(QStringLiteral("<a href\\s*=\\s*\"(https://vgcollect.com/item/\\d+)\">(.+?)</a"));
   static const QRegularExpression platformRx(QStringLiteral("<a href=\"https://vgcollect.com/browse/[0-9a-z]+\">(.+?)</a"));
-  static const QRegularExpression tagRx(QLatin1String("<.*?>"));
+  static const QRegularExpression tagRx(QStringLiteral("<.*?>"));
 
   QRegularExpressionMatchIterator i = rowRx.globalMatch(s);
   while(i.hasNext()) {
@@ -175,18 +176,18 @@ void VGCollectFetcher::slotComplete(KJob*) {
       platform = platform.remove(tagRx).trimmed();
     }
     // skip some non-game "platforms"
-    if(platform == QLatin1String("Toys") ||
-       platform == QLatin1String("Clothing") ||
-       platform == QLatin1String("Merchandise") ||
-       platform == QLatin1String("Soundtrack") ||
-       platform == QLatin1String("Books") ||
-       platform == QLatin1String("Comics") ||
-       platform == QLatin1String("GOG.com") ||
-       platform.startsWith(QLatin1String("Amiibo Figures")) ||
-       platform.contains(QLatin1String("Video")) ||
-       platform == QLatin1String("Steam") ||
-       platform == QLatin1String("Consoles") ||
-       platform == QLatin1String("Accessory")) {
+    if(platform == "Toys"_L1 ||
+       platform == "Clothing"_L1 ||
+       platform == "Merchandise"_L1 ||
+       platform == "Soundtrack"_L1 ||
+       platform == "Books"_L1 ||
+       platform == "Comics"_L1 ||
+       platform == "GOG.com"_L1 ||
+       platform.startsWith("Amiibo Figures"_L1) ||
+       platform.contains("Video"_L1) ||
+       platform == "Steam"_L1 ||
+       platform == "Consoles"_L1 ||
+       platform == "Accessory"_L1) {
         continue;
     }
 //    myDebug() << title << platform << u;
@@ -194,7 +195,7 @@ void VGCollectFetcher::slotComplete(KJob*) {
     QUrl url = QUrl(QString::fromLatin1(VGCOLLECT_BASE_URL)).resolved(QUrl(u));
     m_matches.insert(r->uid, url);
     // don't emit signal until after putting url in matches hash
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
 
   stop();
@@ -242,12 +243,12 @@ Tellico::Data::EntryPtr VGCollectFetcher::fetchEntryHook(uint uid_) {
 }
 
 void VGCollectFetcher::parseEntry(Data::EntryPtr entry_, const QString& str_) {
-  static const QRegularExpression divRx(QLatin1String("<div class=\"tab-pane active\" id=\"info\">(.+?)</div"),
+  static const QRegularExpression divRx(QStringLiteral("<div class=\"tab-pane active\" id=\"info\">(.+?)</div"),
                                         QRegularExpression::DotMatchesEverythingOption);
-  static const QRegularExpression trRx(QLatin1String("<tr>(.+?)</tr"),
+  static const QRegularExpression trRx(QStringLiteral("<tr>(.+?)</tr"),
+                                       QRegularExpression::DotMatchesEverythingOption);
+  static const QRegularExpression tdRx(QStringLiteral("<td[^>]*>(.+?)</td"),
                                        QRegularExpression::DotMatchesEverythingOption);
-  static const QRegularExpression tdRx(QLatin1String("<td[^>]*>(.+?)</td"),
-                                        QRegularExpression::DotMatchesEverythingOption);
 
   auto divMatch = divRx.match(str_);
   if(divMatch.hasMatch()) {
@@ -264,13 +265,13 @@ void VGCollectFetcher::parseEntry(Data::EntryPtr entry_, const QString& str_) {
     }
   }
 
-  static const QRegularExpression titleRx(QLatin1String("<meta property=\"og:title\" content=\"([^\"]+?) \\|"));
+  static const QRegularExpression titleRx(QStringLiteral("<meta property=\"og:title\" content=\"([^\"]+?) \\|"));
   auto titleMatch = titleRx.match(str_);
   if(titleMatch.hasMatch()) {
     entry_->setField(QStringLiteral("title"), titleMatch.captured(1));
   }
 
-  static const QRegularExpression coverRx(QLatin1String("<meta property=\"og:image\" content=\"(.+?)\">"));
+  static const QRegularExpression coverRx(QStringLiteral("<meta property=\"og:image\" content=\"(.+?)\">"));
   auto coverMatch = coverRx.match(str_);
   if(coverMatch.hasMatch()) {
     const QString u = coverMatch.captured(1);
@@ -287,39 +288,39 @@ void VGCollectFetcher::parseEntry(Data::EntryPtr entry_, const QString& str_) {
 }
 
 void VGCollectFetcher::populateValue(Data::EntryPtr entry_, const QString& header_, const QString& value_) const {
-  static const QRegularExpression tagRx(QLatin1String("<.*?>"));
+  static const QRegularExpression tagRx(QStringLiteral("<.*?>"));
   auto header = header_;
   header = header.remove(tagRx).simplified();
   auto value = value_.simplified();
-  if(header_.isEmpty() || value_.isEmpty() || value == QLatin1String("NA")) {
+  if(header_.isEmpty() || value_.isEmpty() || value == "NA"_L1) {
     return;
   }
 
-  if(header.startsWith(QLatin1String("Publisher"))) {
+  if(header.startsWith("Publisher"_L1)) {
     entry_->setField(QStringLiteral("publisher"), value);
-  } else if(header.startsWith(QLatin1String("Developer"))) {
+  } else if(header.startsWith("Developer"_L1)) {
     entry_->setField(QStringLiteral("developer"), value);
-  } else if(header.startsWith(QLatin1String("Platform"))) {
+  } else if(header.startsWith("Platform"_L1)) {
     const QString platform = Data::GameCollection::normalizePlatform(value.remove(tagRx).trimmed());
     entry_->setField(QStringLiteral("platform"), platform);
-  } else if(header.startsWith(QLatin1String("Genre"))) {
+  } else if(header.startsWith("Genre"_L1)) {
     entry_->setField(QStringLiteral("genre"), value);
-  } else if(header.startsWith(QLatin1String("Rating"))) {
+  } else if(header.startsWith("Rating"_L1)) {
     QString pegi;
     Data::GameCollection::EsrbRating esrb = Data::GameCollection::UnknownEsrb;
-    if(value.contains(QLatin1String("ratings/u.png")))       esrb = Data::GameCollection::Unrated;
-    else if(value.contains(QLatin1String("ratings/t.png")))  esrb = Data::GameCollection::Teen;
-    else if(value.contains(QLatin1String("ratings/e.png")))  esrb = Data::GameCollection::Everyone;
-    else if(value.contains(QLatin1String("ratings/ka.png")))  esrb = Data::GameCollection::Everyone;
-    else if(value.contains(QLatin1String("ratings/e10.png"))) esrb = Data::GameCollection::Everyone10;
-    else if(value.contains(QLatin1String("ratings/ec.png"))) esrb = Data::GameCollection::EarlyChildhood;
-    else if(value.contains(QLatin1String("ratings/m.png")))  esrb = Data::GameCollection::Mature;
-    else if(value.contains(QLatin1String("ratings/ao.png")))  esrb = Data::GameCollection::Adults;
-    else if(value.contains(QLatin1String("ratings/pegi-3")))  pegi = QLatin1String("PEGI 3");
-    else if(value.contains(QLatin1String("ratings/pegi-7")))  pegi = QLatin1String("PEGI 7");
-    else if(value.contains(QLatin1String("ratings/pegi-12"))) pegi = QLatin1String("PEGI 12");
-    else if(value.contains(QLatin1String("ratings/pegi-16"))) pegi = QLatin1String("PEGI 16");
-    else if(value.contains(QLatin1String("ratings/pegi-18"))) pegi = QLatin1String("PEGI 18");
+    if(value.contains("u.png"_L1))         esrb = Data::GameCollection::Unrated;
+    else if(value.contains("esrb-t"_L1))   esrb = Data::GameCollection::Teen;
+    else if(value.contains("esrb-e"_L1))   esrb = Data::GameCollection::Everyone;
+    else if(value.contains("esrb-ka"_L1))  esrb = Data::GameCollection::Everyone;
+    else if(value.contains("esrb-e10"_L1)) esrb = Data::GameCollection::Everyone10;
+    else if(value.contains("esrb-ec"_L1))  esrb = Data::GameCollection::EarlyChildhood;
+    else if(value.contains("esrb-m"_L1))   esrb = Data::GameCollection::Mature;
+    else if(value.contains("esrb-ao"_L1))  esrb = Data::GameCollection::Adults;
+    else if(value.contains("pegi-3"_L1))   pegi = QStringLiteral("PEGI 3");
+    else if(value.contains("pegi-7"_L1))   pegi = QStringLiteral("PEGI 7");
+    else if(value.contains("pegi-12"_L1))  pegi = QStringLiteral("PEGI 12");
+    else if(value.contains("pegi-16"_L1))  pegi = QStringLiteral("PEGI 16");
+    else if(value.contains("pegi-18"_L1))  pegi = QStringLiteral("PEGI 18");
     if(esrb != Data::GameCollection::UnknownEsrb) {
       entry_->setField(QStringLiteral("certification"), Data::GameCollection::esrbRating(esrb));
     }
@@ -327,19 +328,16 @@ void VGCollectFetcher::populateValue(Data::EntryPtr entry_, const QString& heade
       entry_->collection()->addField(Data::Field::createDefaultField(Data::Field::PegiField));
       entry_->setField(QStringLiteral("pegi"), pegi);
     }
-  } else if(header.startsWith(QLatin1String("Release Date"))) {
+  } else if(header.startsWith("Release Date"_L1)) {
     entry_->setField(QStringLiteral("year"), value.right(4));
-  } else if(header.startsWith(QLatin1String("Box Text"))) {
+  } else if(header.startsWith("Box Text"_L1)) {
     entry_->setField(QStringLiteral("description"), value);
-  } else if(header.startsWith(QLatin1String("Barcode")) &&
+  } else if(header.startsWith("Barcode"_L1) &&
             optionalFields().contains(QStringLiteral("barcode"))) {
     Data::FieldPtr field(new Data::Field(QStringLiteral("barcode"), i18n("Barcode")));
     field->setCategory(i18n("General"));
     entry_->collection()->addField(field);
     entry_->setField(QStringLiteral("barcode"), value);
-  } else {
-//    myDebug() << "Row header:" << header;
-//    myDebug() << "Row data:" << value;
   }
 }
 
