@@ -26,7 +26,7 @@
 #include "vndbfetcher.h"
 #include "../collections/gamecollection.h"
 #include "../images/imagefactory.h"
-#include "../utils/mapvalue.h"
+#include "../utils/objvalue.h"
 #include "../entry.h"
 #include "../fieldformat.h"
 #include "../tellico_debug.h"
@@ -99,13 +99,7 @@ void VNDBFetcher::search() {
     m_socket = new QTcpSocket(this);
     QObject::connect(m_socket, &QTcpSocket::readyRead,     this, &VNDBFetcher::slotRead);
     QObject::connect(m_socket, &QTcpSocket::stateChanged,  this, &VNDBFetcher::slotState);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-    // see https://wiki.qt.io/New_Signal_Slot_Syntax#Overload for why this is necessary
-    void (QTcpSocket::* errorSignal)(QAbstractSocket::SocketError) = &QAbstractSocket::error;
-    QObject::connect(m_socket, errorSignal,                this, &VNDBFetcher::slotError);
-#else
     QObject::connect(m_socket, &QTcpSocket::errorOccurred, this, &VNDBFetcher::slotError);
-#endif
   }
   if(!m_isConnected) {
     myLog() << "Connecting to" << VNDB_HOSTNAME << "at port" << VNDB_PORT;
@@ -146,7 +140,7 @@ void VNDBFetcher::stop() {
     return;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 Tellico::Data::EntryPtr VNDBFetcher::fetchEntryHook(uint uid_) {
@@ -215,9 +209,9 @@ bool VNDBFetcher::verifyData() {
 
   if(m_data.startsWith("error")) { //krazy:exclude=strings
     QJsonDocument doc = QJsonDocument::fromJson(m_data.mid(5));
-    QVariantMap result = doc.object().toVariantMap();
-    if(result.contains(QStringLiteral("msg"))) {
-      const auto msg = result.value(QStringLiteral("msg")).toString();
+    const auto obj = doc.object();
+    if(obj.contains(QLatin1StringView("msg"))) {
+      const auto msg = obj[QLatin1StringView("msg")].toString();
       myDebug() << "Data error:" << msg;
       message(msg, MessageHandler::Error);
     }
@@ -268,8 +262,8 @@ void VNDBFetcher::parseVNResults() {
     stop();
     return;
   }
-  QVariantMap topResultMap = doc.object().toVariantMap();
-  QVariantList resultList = topResultMap.value(QStringLiteral("items")).toList();
+  const auto topResult = doc.object();
+  const auto resultList = topResult.value(QLatin1StringView("items")).toArray();
   if(resultList.isEmpty()) {
     myLog() << "No results";
     stop();
@@ -293,33 +287,32 @@ void VNDBFetcher::parseVNResults() {
     coll->addField(f);
   }
 
-  QVariantMap resultMap;
-  foreach(const QVariant& result, resultList) {
+  for(const auto& result : resultList) {
     // be sure to check that the fetcher has not been stopped
     // crashes can occur if not
     if(!m_started) {
       break;
     }
-    resultMap = result.toMap();
 
+    const auto resultObj = result.toObject();
     Data::EntryPtr entry(new Data::Entry(coll));
-    entry->setField(QStringLiteral("title"), mapValue(resultMap, "title"));
-    entry->setField(QStringLiteral("vn-id"), mapValue(resultMap, "id"));
-    entry->setField(QStringLiteral("year"), mapValue(resultMap, "released").left(4));
+    entry->setField(QStringLiteral("title"), objValue(resultObj, "title"));
+    entry->setField(QStringLiteral("vn-id"), objValue(resultObj, "id"));
+    entry->setField(QStringLiteral("year"), objValue(resultObj, "released").left(4));
     entry->setField(QStringLiteral("genre"), i18n("Visual Novel"));
-    entry->setField(QStringLiteral("description"), mapValue(resultMap, "description"));
-    entry->setField(QStringLiteral("cover"), mapValue(resultMap, "image"));
+    entry->setField(QStringLiteral("description"), objValue(resultObj, "description"));
+    entry->setField(QStringLiteral("cover"), objValue(resultObj, "image"));
     if(optionalFields().contains(QStringLiteral("origtitle"))) {
-      entry->setField(QStringLiteral("origtitle"), mapValue(resultMap, "original"));
+      entry->setField(QStringLiteral("origtitle"), objValue(resultObj, "original"));
     }
     if(optionalFields().contains(QStringLiteral("alias"))) {
-      const QString aliases = mapValue(resultMap, "aliases");
+      const QString aliases = objValue(resultObj, "aliases");
       entry->setField(QStringLiteral("alias"), aliases.split(QStringLiteral("\n")).join(FieldFormat::delimiterString()));
     }
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
 
 //  m_start = m_entries.count();
@@ -346,32 +339,32 @@ void VNDBFetcher::parseReleaseResults(Data::EntryPtr entry_) {
     message(jsonError.errorString(), MessageHandler::Error);
     return;
   }
-  QVariantMap topResultMap = doc.object().toVariantMap();
-  QVariantList resultList = topResultMap.value(QStringLiteral("items")).toList();
+  const auto topResult = doc.object();
+  const auto resultList = topResult.value(QLatin1StringView("items")).toArray();
   if(resultList.isEmpty()) {
     myLog() << "No results";
     return;
   }
 
   // only work on the first release item
-  const QVariantMap resultMap = resultList.at(0).toMap();
+  const auto result = resultList.at(0).toObject();
 
   QStringList pubs, devs;
-  QVariantList producerList = resultMap.value(QStringLiteral("producers")).toList();
-  foreach(const QVariant& producerObject, producerList) {
-    const QVariantMap producerMap = producerObject.toMap();
-    if(producerMap.value(QStringLiteral("publisher")) == true) {
-      pubs += mapValue(producerMap, "name");
+  const auto producerList = result[QLatin1StringView("producers")].toArray();
+  for(const auto& producer : producerList) {
+    const auto producerObj = producer.toObject();
+    if(producerObj[QLatin1StringView("publisher")].toBool()) {
+      pubs += objValue(producerObj, "name");
     }
-    if(producerMap.value(QStringLiteral("developer")) == true) {
-      devs += mapValue(producerMap, "name");
+    if(producerObj[QLatin1StringView("developer")].toBool()) {
+      devs += objValue(producerObj, "name");
     }
   }
   entry_->setField(QStringLiteral("publisher"), pubs.join(FieldFormat::delimiterString()));
   entry_->setField(QStringLiteral("developer"), devs.join(FieldFormat::delimiterString()));
 
   // update release year
-  entry_->setField(QStringLiteral("year"), mapValue(resultMap, "released").left(4));
+  entry_->setField(QStringLiteral("year"), objValue(result, "released").left(4));
 }
 
 void VNDBFetcher::slotState() {
