@@ -22,22 +22,21 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h> // for TELLICO_VERSION
-
 #include "xmlfetcher.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
 #include "../utils/guiproxy.h"
 #include "../utils/xmlhandler.h"
 #include "../utils/datafileregistry.h"
+#include "../utils/tellico_utils.h"
 #include "../tellico_debug.h"
 
 #include <KIO/StoredTransferJob>
 #include <KIO/JobUiDelegate>
+#include <KJobWidgets>
 
 #include <QFile>
 #include <QTextStream>
-#include <KJobWidgets>
 
 using Tellico::Fetch::XMLFetcher;
 
@@ -74,9 +73,8 @@ void XMLFetcher::doSearch() {
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
-  m_job->addMetaData(QLatin1String("SendUserAgent"), QLatin1String("true"));
-  m_job->addMetaData(QStringLiteral("UserAgent"),
-                     QStringLiteral("Tellico/%1 ( https://tellico-project.org )").arg(QStringLiteral(TELLICO_VERSION)));
+  Tellico::addUserAgent(m_job);
+  doSearchHook(m_job.data());
   connect(m_job.data(), &KJob::result, this, &XMLFetcher::slotComplete);
   connect(m_job.data(), &KIO::TransferJob::redirection, this, &XMLFetcher::slotRedirected);
 }
@@ -90,7 +88,7 @@ void XMLFetcher::stop() {
     m_job = nullptr;
   }
   m_started = false;
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 void XMLFetcher::slotComplete(KJob* ) {
@@ -116,7 +114,7 @@ void XMLFetcher::slotComplete(KJob* ) {
     stop();
     return;
   }
-  if(data.left(5) != "<?xml") {
+  if(data.first(5) != "<?xml") {
     myLog() << "Invalid XML data:" << data.left(200);
     stop();
     return;
@@ -174,7 +172,7 @@ void XMLFetcher::slotComplete(KJob* ) {
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
     ++count;
   }
 
