@@ -55,10 +55,7 @@
 #include <KAcceleratorManager>
 #include <KSeparator>
 #include <KConfig>
-#include <kguiaddons_version.h>
-#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
 #include <KCountryFlagEmojiIconEngine>
-#endif
 
 #include <QSpinBox>
 #include <QFile>
@@ -304,7 +301,7 @@ void Z3950Fetcher::stop() {
     m_conn->abort();
     m_conn->wait(1000);
   }
-  emit signalDone(this);
+  Q_EMIT signalDone(this);
 }
 
 bool Z3950Fetcher::initMARC21Handler() {
@@ -492,7 +489,7 @@ void Z3950Fetcher::handleResult(const QString& result_) {
   foreach(Data::EntryPtr entry, entries) {
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+    Q_EMIT signalResultFound(r);
   }
 }
 
@@ -786,11 +783,11 @@ void Z3950Fetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
 void Z3950Fetcher::ConfigWidget::slotTogglePreset(bool on) {
   m_serverCombo->setEnabled(on);
   if(on) {
-    emit signalName(m_serverCombo->currentText());
+    Q_EMIT signalName(m_serverCombo->currentText());
   }
   m_hostEdit->setEnabled(!on);
   if(!on && !m_hostEdit->text().isEmpty()) {
-    emit signalName(m_hostEdit->text());
+    Q_EMIT signalName(m_hostEdit->text());
   }
   m_portSpinBox->setEnabled(!on);
   m_databaseEdit->setEnabled(!on);
@@ -800,12 +797,12 @@ void Z3950Fetcher::ConfigWidget::slotTogglePreset(bool on) {
   m_charSetCombo2->setEnabled(!on);
   m_syntaxCombo->setEnabled(!on);
   if(on) {
-    emit signalName(m_serverCombo->currentText());
+    Q_EMIT signalName(m_serverCombo->currentText());
   }
 }
 
 void Z3950Fetcher::ConfigWidget::slotPresetChanged() {
-  emit signalName(m_serverCombo->currentText());
+  Q_EMIT signalName(m_serverCombo->currentText());
 }
 
 void Z3950Fetcher::ConfigWidget::loadPresets(const QString& current_) {
@@ -842,7 +839,6 @@ void Z3950Fetcher::ConfigWidget::loadPresets(const QString& current_) {
     KConfigGroup cfg(&serverConfig, group);
     const QString country = cfg.readEntry("Country", QString());
 
-#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
     QIcon icon;
     if(!country.isEmpty()) {
       QHash<QString, QIcon>::ConstIterator it = flags.constFind(country);
@@ -854,9 +850,6 @@ void Z3950Fetcher::ConfigWidget::loadPresets(const QString& current_) {
       }
     }
     m_serverCombo->addItem(icon, name, group);
-#else
-    m_serverCombo->addItem(name, group);
-#endif
 
     if(current_.isEmpty() && idx == -1) {
       // set the initial selection to something depending on the language
