@@ -223,12 +223,7 @@ FetchDialog::FetchDialog(QWidget* parent_)
   foreach(Fetch::Fetcher::Ptr fetcher, sources) {
     m_sourceCombo->addItem(Fetch::Manager::self()->fetcherIcon(fetcher.data()), fetcher->source());
   }
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-  void (QComboBox::* activatedString)(const QString&) = &QComboBox::activated;
-  connect(m_sourceCombo, activatedString, this, &FetchDialog::slotSourceChanged);
-#else
   connect(m_sourceCombo, &QComboBox::textActivated, this, &FetchDialog::slotSourceChanged);
-#endif
   m_sourceCombo->setWhatsThis(i18n("Select the database to search"));
 
   // for whatever reason, the dialog window could get shrunk and truncate the text
@@ -268,11 +263,7 @@ FetchDialog::FetchDialog(QWidget* parent_)
   // set the xslt file AFTER setting the gradient image option
   m_entryView->setXSLTFile(QStringLiteral("Compact.xsl"));
   m_entryView->addXSLTStringParam("skip-fields", "id,mdate,cdate");
-  m_entryView->
-#ifdef USE_KHTML
-               view()->
-#endif
-               setWhatsThis(i18n("An entry may be shown here before adding it to the "
+  m_entryView->setWhatsThis(i18n("An entry may be shown here before adding it to the "
                                  "current collection by selecting it in the list above"));
 
   QWidget* box3 = new QWidget(mainWidget);
@@ -327,7 +318,7 @@ FetchDialog::FetchDialog(QWidget* parent_)
   setMinimumWidth(qMax(minimumWidth(), qMax(FETCH_MIN_WIDTH, minimumSizeHint().width())));
   setStatus(i18n("Ready."));
 
-  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("Fetch Dialog Options"));
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Fetch Dialog Options"));
   const auto splitList = config.readEntry("Splitter Sizes", QList<int>());
   if(splitList.empty()) {
     split->setSizes({3000, 5000}); // default to 3:5 ratio
@@ -374,7 +365,7 @@ FetchDialog::~FetchDialog() {
   // no additional entries to check images to keep though
   Data::Document::self()->removeImagesNotInCollection(entriesToCheck, Data::EntryList());
 
-  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("Fetch Dialog Options"));
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Fetch Dialog Options"));
   KWindowConfig::saveWindowSize(windowHandle(), config);
 
   config.writeEntry("Splitter Sizes", static_cast<QSplitter*>(m_treeWidget->parentWidget())->sizes());
@@ -660,7 +651,7 @@ void FetchDialog::slotInit() {
 
   // do this in the singleShot slot so it works
   // see note in entryeditdialog.cpp (Feb 2017)
-  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("Fetch Dialog Options"));
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Fetch Dialog Options"));
   KWindowConfig::restoreWindowSize(windowHandle(), config);
 
   if(!Fetch::Manager::self()->canFetch(Data::Document::self()->collection()->type())) {
