@@ -36,9 +36,6 @@
 #include <QUrl>
 
 #include <config.h>
-#ifdef HAVE_KSANE
-#include <ksane_version.h>
-#endif
 
 class QLabel;
 class QResizeEvent;
@@ -56,6 +53,9 @@ class KProcess;
 class KPageDialog;
 namespace KSaneIface { class KSaneWidget; }
 #endif
+
+class FieldWidgetTest;
+
 namespace Tellico {
   namespace GUI {
 
@@ -65,6 +65,8 @@ namespace Tellico {
 class ImageWidget : public QWidget {
 Q_OBJECT
 
+friend class ::FieldWidgetTest;
+
 public:
   ImageWidget(QWidget* parent);
   virtual ~ImageWidget();
@@ -91,11 +93,7 @@ private Q_SLOTS:
   void slotLinkOnlyClicked();
   void slotScanImage();
 #ifdef HAVE_KSANE
-#if KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
-  void imageReady(QByteArray &data, int w, int h, int bpl, int f);
-#else
   void imageReady(const QImage& scannedImage);
-#endif
 #endif
   void slotEditImage();
   void slotEditMenu(QAction* action);
