@@ -64,11 +64,7 @@ Q_SIGNALS:
 
 protected:
   virtual void mousePressEvent(QMouseEvent* e) override;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-  virtual void enterEvent(QEvent* e) override;
-#else
   virtual void enterEvent(QEnterEvent* e) override;
-  #endif
   virtual void leaveEvent(QEvent* e) override;
 
 private Q_SLOTS:
