@@ -86,8 +86,9 @@ void ImageDirectory::reset() {
 bool ImageDirectory::hasImage(const QString& id_) {
   // dir() is virtual
   if(dir().isEmpty()) return false;
-  const bool localExists = m_pathExists && m_isLocal && QFile::exists(dir().toLocalFile() + id_);
-  if(localExists) return true;
+  if(m_isLocal) {
+    return m_pathExists && QFile::exists(dir().toLocalFile() + id_);
+  }
 
   // now we're looking for a remote file. First, check if we know already
   if(m_imageExists.contains(id_)) {
@@ -95,11 +96,7 @@ bool ImageDirectory::hasImage(const QString& id_) {
   }
   QUrl imageUrl = dir();
   imageUrl.setPath(imageUrl.path() + id_);
-#if QT_VERSION_MAJOR < 6
-  KIO::StatJob* statJob = KIO::statDetails(imageUrl, KIO::StatJob::SourceSide, KIO::StatNoDetails, KIO::HideProgressInfo);
-#else
-  KIO::StatJob* statJob = KIO::stat(imageUrl, KIO::StatJob::SourceSide, KIO::StatNoDetails, KIO::HideProgressInfo);
-#endif
+  auto statJob = KIO::stat(imageUrl, KIO::StatJob::SourceSide, KIO::StatNoDetails, KIO::HideProgressInfo);
   // if no error, then file exists
   const bool noError = statJob->exec();
   m_imageExists.insert(id_, noError);
@@ -152,16 +149,12 @@ bool ImageDirectory::writeImage(const Data::Image& img_) {
       QDir dir;
       if(dir.mkdir(localPath)) {
         myLog() << "Created local directory:" << localPath;
+        m_pathExists = true;
       } else {
         myWarning() << "Unable to create dir:" << localPath;
       }
-      m_pathExists = true;
     } else {
-#if QT_VERSION_MAJOR < 6
-      auto statJob = KIO::statDetails(target, KIO::StatJob::SourceSide, KIO::StatNoDetails, KIO::HideProgressInfo);
-#else
       auto statJob = KIO::stat(target, KIO::StatJob::SourceSide, KIO::StatNoDetails, KIO::HideProgressInfo);
-#endif
       // if no error, then dir exists
       if(statJob->exec()) {
         m_pathExists = true;
@@ -241,7 +234,7 @@ void ImageZipArchive::setZip(std::unique_ptr<KZip> zip_) {
 }
 
 bool ImageZipArchive::hasImage(const QString& id_) {
-  return m_images.has(id_);
+  return m_images.contains(id_);
 }
 
 Tellico::Data::Image* ImageZipArchive::imageById(const QString& id_) {
