@@ -67,6 +67,17 @@ public:
   QTimer releaseImagesTimer;
 };
 
+inline
+bool tryCacheInsert(Tellico::Data::Image* img, QCache<QString, Data::Image>& cache) {
+  // if sizeInBytes() is greater than maxCost, then trying and failing to insert it would
+  // mean the image gets deleted
+  if(img->sizeInBytes() >= cache.maxCost()) {
+    myWarning() << "Increasing image cache size to" << 2*img->sizeInBytes();
+    cache.setMaxCost(2*img->sizeInBytes());
+  }
+  return cache.insert(img->id(), img, img->sizeInBytes());
+}
+
 ImageFactory::ImageFactory() : QObject(), d(new Private()) {
 }
 
@@ -93,7 +104,7 @@ void ImageFactory::init() {
 }
 
 Tellico::ImageFactory* ImageFactory::self() {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::self", "ImageFactory is not initialized!");
   return factory;
 }
 
@@ -111,7 +122,7 @@ QUrl ImageFactory::localDir() {
 }
 
 QUrl ImageFactory::imageDir() {
-  Q_ASSERT(factory);
+  Q_ASSERT_X(factory, "ImageFactory::imageDir()", "ImageFactory is not initialized!");
   switch(cacheDir()) {
     case LocalDir: return localDir();
     case DataDir: return dataDir();
@@ -136,7 +147,7 @@ Tellico::ImageFactory::CacheDir ImageFactory::cacheDir() {
 }
 
 QString ImageFactory::addImage(const QUrl& url_, bool quiet_, const QUrl& refer_, bool link_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::addImage", "ImageFactory is not initialized!");
   return factory->addImageImpl(url_, quiet_, refer_, link_).id();
 }
 
@@ -145,12 +156,13 @@ const Tellico::Data::Image& ImageFactory::addImageImpl(const QUrl& url_, bool qu
     myDebug() << "Returning null image";
     return Data::Image::null;
   }
+  myLog() << "Loading image from url:" << url_.toDisplayString(QUrl::PreferLocalFile | QUrl::NormalizePathSegments);
   ImageJob* job = new ImageJob(url_, QString(), quiet_);
   job->setLinkOnly(link_);
   job->setReferrer(refer_);
 
   if(!job->exec()) {
-    myWarning() << job->errorString();
+    myWarning() << "ImageJob failed:" << job->errorString();
     // ERR_UNKNOWN is used when the returned image is truly null
     // rather than network error or some such
     if(job->error() == KIO::ERR_UNKNOWN) {
@@ -165,22 +177,25 @@ const Tellico::Data::Image& ImageFactory::addImageImpl(const QUrl& url_, bool qu
     return Data::Image::null;
   }
 
-  myLog() << "Loading image from url:" << img.id() << url_.toDisplayString(QUrl::PreferLocalFile | QUrl::NormalizePathSegments);
   // hold the image in memory since it probably isn't written locally to disk yet
-  if(!d->imageDict.contains(img.id())) {
-    d->imageDict.insert(img.id(), new Data::Image(img));
-    s_imageInfoMap.insert(img.id(), Data::ImageInfo(img));
+  bool putInDict = true;
+  if(link_ && url_.isLocalFile()) {
+    putInDict = !tryCacheInsert(new Data::Image(img), d->imageCache);
   }
+  if(putInDict && !d->imageDict.contains(img.id())) {
+    d->imageDict.insert(img.id(), new Data::Image(img));
+  }
+  s_imageInfoMap.insert(img.id(), Data::ImageInfo(img));
   return img;
 }
 
 QString ImageFactory::addImage(const QImage& image_, const QString& format_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::addImage(QImage)", "ImageFactory is not initialized!");
   return factory->addImageImpl(image_, format_).id();
 }
 
 QString ImageFactory::addImage(const QPixmap& pix_, const QString& format_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::addImage(QPixmap)", "ImageFactory is not initialized!");
   return factory->addImageImpl(pix_.toImage(), format_).id();
 }
 
@@ -204,7 +219,7 @@ const Tellico::Data::Image& ImageFactory::addImageImpl(const QImage& image_, con
 }
 
 QString ImageFactory::addImage(const QByteArray& data_, const QString& format_, const QString& id_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::addImage(QByteArray)", "ImageFactory is not initialized!");
   return factory->addImageImpl(data_, format_, id_).id();
 }
 
@@ -261,26 +276,12 @@ const Tellico::Data::Image& ImageFactory::addCachedImageImpl(const QString& id_,
   }
 
   s_imageInfoMap.insert(img->id(), Data::ImageInfo(*img));
-
-  // if sizeInBytes() is greater than maxCost, then trying and failing to insert it would
-  // mean the image gets deleted
-  if(img->sizeInBytes() > d->imageCache.maxCost()) {
-    // can't hold it in the cache
-    myWarning() << "Image cache is unable to hold the image, it's too big!";
-    myWarning() << "Image name is " << img->id();
-    myWarning() << "Image size is " << img->sizeInBytes();
-    myWarning() << "Max cache size is " << d->imageCache.maxCost();
-
-    // add it back to the dict, but add the image to the list of
-    // images to release later. Necessary to avoid a memory leak since new Image()
-    // was called, we need to keep the pointer
-    d->imageDict.insert(img->id(), img);
-    s_imagesToRelease.add(img->id());
-  } else if(!d->imageCache.insert(img->id(), img, img->sizeInBytes())) {
+  if(!tryCacheInsert(img, d->imageCache)) {
     // at this point, img has been deleted!
     myWarning() << "Unable to insert into image cache";
     return Data::Image::null;
   }
+  s_imagesToRelease.add(img->id());
   return *img;
 }
 
@@ -319,8 +320,9 @@ bool ImageFactory::writeCachedImage(const QString& id_, CacheDir dir_, bool forc
       Data::Image* img = factory->d->imageDict.take(id_);
       Q_ASSERT(img);
       // imageCache.insert will delete the image by itself if the cost exceeds the cache size
-      if(factory->d->imageCache.insert(img->id(), img, img->sizeInBytes())) {
+      if(tryCacheInsert(img, factory->d->imageCache)) {
         s_imageInfoMap.remove(id_);
+        s_imagesToRelease.add(id_);
       }
     }
   }
@@ -345,28 +347,28 @@ bool ImageFactory::writeCachedImage(const QString& id_, ImageDirectory* imgDir_,
 }
 
 const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::imageById", "ImageFactory is not initialized!");
   if(id_.isEmpty() || !factory || factory->d->nullImages.contains(id_)) {
     return Data::Image::null;
   }
-//  myLog() << "imageById" << id_;
+//  myLog() << "Calling imageById:" << id_;
 
   // can't think of a better place to regularly check for images to release
   // but don't release image that just got asked for
   s_imagesToRelease.remove(id_);
   factory->d->releaseImagesTimer.start(5000);
 
- // first check the cache, used for images that are in the data file, or are only temporary
- // then the dict, used for images downloaded, but not yet saved anywhere
+  // first check the cache, used for images that are in the data file, or are only temporary
+  // then the dict, used for images downloaded, but not yet saved anywhere
   Data::Image* img = factory->d->imageCache.object(id_);
   if(img) {
-//    myLog() << "found in cache";
+//    myLog() << "...found in cache";
     return *img;
   }
 
   img = factory->d->imageDict.value(id_);
   if(img) {
-//    myLog() << "found in dict";
+//    myLog() << "...found in dict";
     return *img;
   }
 
@@ -377,6 +379,7 @@ const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
   const QUrl imageUrl(id_);
   if((s_imageInfoMap.contains(id_) && s_imageInfoMap[id_].linkOnly) || !imageUrl.isRelative()) {
     if(imageUrl.isValid()) {
+//      myLog() << "...adding image by url:" << id_;
       return factory->addImageImpl(imageUrl, true, QUrl(), true);
     }
   }
@@ -387,7 +390,6 @@ const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
   if(factory->d->tempImageDir.hasImage(id_)) {
     const Data::Image& img2 = factory->addCachedImageImpl(id_, TempDir);
     if(!img2.isNull()) {
-//      myLog() << "found in tmp dir";
       return img2;
     }
   }
@@ -488,7 +490,7 @@ const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
 }
 
 bool ImageFactory::hasImageInDir(const QString& id_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::hasImageInDir", "ImageFactory is not initialized!");
   if(id_.isEmpty() || !factory) {
     return false;
   }
@@ -515,7 +517,7 @@ bool ImageFactory::hasImageInDirOrMemory(const QString& id_) {
 }
 
 void ImageFactory::requestImageById(const QString& id_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::requestImageById()", "ImageFactory is not initialized!");
   if(hasImageInDirOrMemory(id_)) {
     QTimer::singleShot(0, factory, [id_] () {
       auto img = factory->addCachedImageImpl(id_, cacheDir());
@@ -537,7 +539,8 @@ void ImageFactory::requestImageById(const QString& id_) {
     if(u.isValid()) {
       factory->requestImageByUrlImpl(u, true /* quiet */, QUrl() /* referrer */, linkOnly);
       if(!linkOnly) {
-        myDebug() << "Loading an image url that is not link only. The image id will get updated.";
+        myDebug() << "Loading an image url that is not link-only. The image id will get updated.";
+        myDebug() << id_;
       }
     }
     return;
@@ -621,7 +624,7 @@ QPixmap ImageFactory::pixmap(const QString& id_, int width_, int height_) {
   QPixmap pix2(*pix); // retain a copy of pix in case it doesn't go into the cache
   // pixmap size is w x h x d, divided by 8 bits
   const int size = (pix->width()*pix->height()*pix->depth()/8);
-  if(!factory->d->pixmapCache.insert(key, pix, pix->width()*pix->height()*pix->depth()/8)) {
+  if(!factory->d->pixmapCache.insert(key, pix, size)) {
     // at this point, pix might be deleted
     myWarning() << "can't save in cache: " << id_;
     myWarning() << "### Current pixmap size is " << size;
@@ -735,7 +738,7 @@ void ImageFactory::releaseImages() {
   }
 
   myLog() << "Releasing" << s_imagesToRelease.count() << "images from internal memory";
-  for(const QString& id : s_imagesToRelease) {
+  for(const QString& id : std::as_const(s_imagesToRelease)) {
     if(!d->imageDict.contains(id)) {
       continue;
     }
@@ -749,7 +752,7 @@ void ImageFactory::releaseImages() {
 }
 
 void ImageFactory::emitImageMismatch() {
-  emit imageLocationMismatch();
+  Q_EMIT imageLocationMismatch();
 }
 
 QUrl ImageFactory::localDirectory(const QUrl& url_) {
@@ -770,19 +773,19 @@ QUrl ImageFactory::localDirectory(const QUrl& url_) {
 }
 
 void ImageFactory::setLocalDirectory(const QUrl& url_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::setLocalDirectory", "ImageFactory is not initialized!");
   const auto localDirName = localDirectory(url_);
   if(localDirName.isEmpty()) {
     myLog() << "Clearing the local directory name";
     factory->d->localImageDir.reset();
   } else {
-    myLog() << "Setting local directory to" << localDirName.toDisplayString(QUrl::PreferLocalFile);
+    myLog() << "Setting local image dir:" << localDirName.toDisplayString(QUrl::PreferLocalFile);
     factory->d->localImageDir.setDirectory(localDirName);
   }
 }
 
 void ImageFactory::setZipArchive(std::unique_ptr<KZip> zip_) {
-  Q_ASSERT(factory && "ImageFactory is not initialized!");
+  Q_ASSERT_X(factory, "ImageFactory::setZipArchive()", "ImageFactory is not initialized!");
   if(!zip_) {
     return;
   }
@@ -805,9 +808,15 @@ void ImageFactory::slotImageJobResult(KJob* job_) {
   }
 
   // hold the image in memory since it probably isn't written locally to disk yet
-  if(!d->imageDict.contains(img.id())) {
-    d->imageDict.insert(img.id(), new Data::Image(img));
-    s_imageInfoMap.insert(img.id(), Data::ImageInfo(img));
+  // unless it's a local link only
+  bool putInDict = true;
+  if(imageJob->linkOnly() && imageJob->url().isLocalFile()) {
+    putInDict = !tryCacheInsert(new Data::Image(img), d->imageCache);
   }
-  emit factory->imageAvailable(img.id());
+  if(putInDict && !d->imageDict.contains(img.id())) {
+    d->imageDict.insert(img.id(), new Data::Image(img));
+  }
+  s_imageInfoMap.insert(img.id(), Data::ImageInfo(img));
+  s_imagesToRelease.add(img.id());
+  Q_EMIT factory->imageAvailable(img.id());
 }
