@@ -22,18 +22,21 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
 #include "imagejob.h"
 #include "../utils/guiproxy.h"
+#include "../utils/tellico_utils.h"
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
 #include <KIO/StoredTransferJob>
+#include <KJobWidgets>
 
 #include <QTimer>
 #include <QFileInfo>
 #include <QBuffer>
 #include <QImageReader>
+#include <QFutureWatcher>
+#include <QtConcurrentRun>
 
 namespace {
   static const int IMAGEJOB_TIMEOUT = 5; // seconds
@@ -41,13 +44,14 @@ namespace {
 
 using Tellico::ImageJob;
 
-ImageJob::ImageJob(const QUrl& url_, const QString& id_, bool quiet_) : KIO::Job()
-    , m_url(url_), m_id(id_), m_linkOnly(false), m_quiet(quiet_) {
+ImageJob::ImageJob(const QUrl& url_, const QString& id_, bool quiet_) : KIO::Job(), m_quiet(quiet_) {
+  m_info.url = url_;
+  m_info.id = id_;
+  KJobWidgets::setWindow(this, GUI::Proxy::widget());
   QTimer::singleShot(0, this, &ImageJob::slotStart);
 }
 
-ImageJob::~ImageJob() {
-}
+ImageJob::~ImageJob() = default;
 
 QString ImageJob::errorString() const {
   // by default, KIO::Job returns an error string depending on the error code and
@@ -55,12 +59,20 @@ QString ImageJob::errorString() const {
   return errorText();
 }
 
+QUrl ImageJob::url() const {
+  return m_info.url;
+}
+
+bool ImageJob::linkOnly() const {
+  return m_info.linkOnly;
+}
+
 const Tellico::Data::Image& ImageJob::image() const {
   return m_image;
 }
 
 void ImageJob::setLinkOnly(bool linkOnly_) {
-  m_linkOnly = linkOnly_;
+  m_info.linkOnly = linkOnly_;
 }
 
 void ImageJob::setReferrer(const QUrl& referrer_) {
@@ -68,26 +80,36 @@ void ImageJob::setReferrer(const QUrl& referrer_) {
 }
 
 void ImageJob::slotStart() {
-  if(!m_url.isValid()) {
+  if(!m_info.url.isValid()) {
     setError(KIO::ERR_MALFORMED_URL);
     emitResult();
-  } else if(m_url.isLocalFile()) {
-    const QString fileName = m_url.toLocalFile();
-    if(!QFileInfo(fileName).isReadable()) {
+  } else if(m_info.url.isLocalFile()) {
+    const QString fileName = m_info.url.toLocalFile();
+    QFileInfo fi(fileName);
+    if(!fi.isReadable()) {
+      if(!fi.exists()) {
+        myLog() << "Image does not exist:" << fileName;
+      } else {
+        myLog() << "Unable to read" << fileName;
+      }
       setError(KIO::ERR_CANNOT_OPEN_FOR_READING);
       setErrorText(i18n("Tellico is unable to load the image - %1.", fileName));
-    } else {
-      m_image = Data::Image(fileName, m_id);
+      emitResult();
+      return;
+    }
+    auto watcher = new QFutureWatcher<Tellico::Data::Image>(this);
+    connect(watcher, &QFutureWatcher<Tellico::Data::Image>::finished, this, [this, watcher]() {
+      watcher->deleteLater();
+      m_image = watcher->result();
       if(m_image.isNull()) {
         setError(KIO::ERR_UNKNOWN);
         m_image = Data::Image::null;
       }
-      if(m_linkOnly) {
-        m_image.setLinkOnly(true);
-        m_image.setID(m_url.url());
-      }
-    }
-    emitResult();
+      emitResult();
+    });
+
+    QFuture<Tellico::Data::Image> future = QtConcurrent::run(loadFromFile, fileName, m_info);
+    watcher->setFuture(future);
   } else {
     KIO::JobFlags flags = KIO::DefaultFlags;
     if(m_quiet || !GUI::Proxy::widget()) {
@@ -95,11 +117,9 @@ void ImageJob::slotStart() {
     }
     // non-local valid url
     // KIO::storedGet seems to handle Content-Encoding: gzip ok
-    KIO::StoredTransferJob* getJob = KIO::storedGet(m_url, KIO::NoReload, flags);
+    KIO::StoredTransferJob* getJob = KIO::storedGet(m_info.url, KIO::NoReload, flags);
     QObject::connect(getJob, &KJob::result, this, &ImageJob::getJobResult);
-    getJob->addMetaData(QLatin1String("SendUserAgent"), QLatin1String("true"));
-    getJob->addMetaData(QStringLiteral("UserAgent"),
-                        QStringLiteral("Tellico/%1").arg(QStringLiteral(TELLICO_VERSION)));
+    Tellico::addUserAgent(getJob);
     if(!m_referrer.isEmpty()) {
       getJob->addMetaData(QStringLiteral("referrer"), m_referrer.url());
     }
@@ -112,7 +132,7 @@ void ImageJob::slotStart() {
 }
 
 void ImageJob::getJobResult(KJob* job_) {
-  const auto errorText = i18n("Tellico is unable to load the image - %1.", m_url.toDisplayString());
+  const auto errorText = i18n("Tellico is unable to load the image - %1.", m_info.url.toDisplayString());
   KIO::StoredTransferJob* getJob = qobject_cast<KIO::StoredTransferJob*>(job_);
   if(!getJob || getJob->error()) {
     // error handling for subjob is handled by KCompositeJob
@@ -121,33 +141,19 @@ void ImageJob::getJobResult(KJob* job_) {
     return;
   }
 
-  // If we used the Image() c'tor that take a bytearray of data, I'm not sure how to
-  // figure out the image format directly. Instead, write into a buffer and use QImageReader
-  QByteArray data = getJob->data();
-  QBuffer buffer(&data);
-  buffer.open(QIODevice::ReadOnly);
-  const auto format = QString::fromLatin1(QImageReader::imageFormat(&buffer));
-  m_image = Data::Image(data, format, m_id);
-  if(m_image.isNull()) {
-    setErrorText(errorText);
-    setError(KIO::ERR_UNKNOWN);
-    m_image = Data::Image::null;
-  } else {
-    // if we can't write the input format, then change to one we can
-    const auto outputFormat = Data::Image::outputFormat(m_image.format());
-    if(m_image.format() != outputFormat) {
-      m_image.setFormat(outputFormat);
-      // recalculate m_id if necessary, since the format is included in the id
-      if(m_id.isEmpty()) {
-        m_image.calculateID();
-      }
+  auto watcher = new QFutureWatcher<Tellico::Data::Image>(this);
+  connect(watcher, &QFutureWatcher<Tellico::Data::Image>::finished, this, [this, watcher]() {
+    watcher->deleteLater();
+    m_image = watcher->result();
+    if(m_image.isNull()) {
+      setError(KIO::ERR_UNKNOWN);
+      m_image = Data::Image::null;
     }
-    if(m_linkOnly) {
-      m_image.setLinkOnly(true);
-      m_image.setID(m_url.url());
-    }
-  }
-  emitResult();
+    emitResult();
+  });
+
+  QFuture<Tellico::Data::Image> future = QtConcurrent::run(loadFromData, getJob->data(), m_info);
+  watcher->setFuture(future);
 }
 
 void ImageJob::getJobTimeout() {
@@ -156,3 +162,38 @@ void ImageJob::getJobTimeout() {
     job->kill(KIO::Job::EmitResult);
   }
 }
+
+Tellico::Data::Image ImageJob::loadFromFile(const QString& file_, const Info& info_) {
+  Tellico::Data::Image img(file_, info_.id);
+  if(info_.linkOnly) {
+    img.setLinkOnly(true);
+    img.setID(info_.url.url());
+  }
+  return img;
+}
+
+Tellico::Data::Image ImageJob::loadFromData(const QByteArray& data_, const Info& info_) {
+  QByteArray data(data_);
+  // If we used the Image() c'tor that take a bytearray of data, I'm not sure how to
+  // figure out the image format directly. Instead, write into a buffer and use QImageReader
+  QBuffer buffer(&data);
+  buffer.open(QIODevice::ReadOnly);
+  const auto format = QString::fromLatin1(QImageReader::imageFormat(&buffer));
+  Tellico::Data::Image img(data, format, info_.id);
+
+  // if we can't write the input format, then change to one we can
+  const auto outputFormat = Data::Image::outputFormat(img.format());
+  if(img.format() != outputFormat) {
+    img.setFormat(outputFormat);
+    // recalculate m_id if necessary, since the format is included in the id
+    if(info_.id.isEmpty()) {
+      img.calculateID();
+    }
+  }
+
+  if(info_.linkOnly) {
+    img.setLinkOnly(true);
+    img.setID(info_.url.url());
+  }
+  return img;
+}
