@@ -45,25 +45,28 @@ namespace {
   }
 }
 
-Tellico::StringComparison* Tellico::StringComparison::create(Data::FieldPtr field_) {
+std::unique_ptr<Tellico::StringComparison> Tellico::StringComparison::create(Data::FieldPtr field_) {
   if(!field_) {
     myWarning() << "No field for creating a string comparison";
     return nullptr;
   }
+  StringComparison* comp = nullptr;
   if(field_->type() == Data::Field::Number || field_->type() == Data::Field::Rating) {
-    return new NumberComparison();
+    comp = new NumberComparison();
   } else if(field_->type() == Data::Field::Bool) {
-    return new BoolComparison();
+    comp = new BoolComparison();
   } else if(field_->type() == Data::Field::Date || field_->formatType() == FieldFormat::FormatDate) {
-    return new ISODateComparison();
+    comp =  new ISODateComparison();
   } else if(field_->formatType() == FieldFormat::FormatTitle) {
-    return new TitleComparison();
-  } else if(field_->property(QStringLiteral("lcc")) == QLatin1String("true") ||
-            field_->name() == QLatin1String("lcc")) {
+    comp = new TitleComparison();
+  } else if(field_->property(QStringLiteral("lcc")) == QLatin1StringView("true") ||
+            field_->name() == QLatin1StringView("lcc")) {
     // allow LCC comparison if LCC property is set, or if the name is lcc
-    return new LCCComparison();
+    comp = new LCCComparison();
+  } else {
+    comp = new StringComparison();
   }
-  return new StringComparison();
+  return std::unique_ptr<StringComparison>(comp);
 }
 
 Tellico::StringComparison::StringComparison() {
@@ -137,13 +140,13 @@ int Tellico::NumberComparison::compare(const QString& str1_, const QString& str2
 // http://library.dts.edu/Pages/RM/Helps/lc_call.shtml
 
 Tellico::LCCComparison::LCCComparison() : StringComparison(),
-  m_regexp(QLatin1String("^([A-Z]+)"
-                         "(\\d+(?:\\.\\d+)?)"
-                         "\\.?([A-Z]*)"
-                         "(\\d*)"
-                         "\\.?([A-Z]*)"
-                         "(\\d*)"
-                         "(?: (.+))?")) {
+  m_regexp(QStringLiteral("^([A-Z]+)"
+                          "(\\d+(?:\\.\\d+)?)"
+                          "\\.?([A-Z]*)"
+                          "(\\d*)"
+                          "\\.?([A-Z]*)"
+                          "(\\d*)"
+                          "(?: (.+))?")) {
 }
 
 int Tellico::LCCComparison::compare(const QString& str1_, const QString& str2_) {
@@ -208,11 +211,7 @@ int Tellico::ISODateComparison::compare(const QString& str1, const QString& str2
   // so dates would sort as expected without padding month and day with zero
   // and accounting for "current year - 1 - 1" default scheme
   const QDate now = QDate::currentDate();
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-  QStringList dlist1 = str1.split(QLatin1Char('-'), QString::KeepEmptyParts);
-#else
   QStringList dlist1 = str1.split(QLatin1Char('-'), Qt::KeepEmptyParts);
-#endif
   bool ok = true;
   int y1 = dlist1.count() > 0 ? dlist1[0].toInt(&ok) : now.year();
   if(!ok) {
@@ -228,11 +227,7 @@ int Tellico::ISODateComparison::compare(const QString& str1, const QString& str2
   }
   QDate date1(y1, m1, d1);
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-  QStringList dlist2 = str2.split(QLatin1Char('-'), QString::KeepEmptyParts);
-#else
   QStringList dlist2 = str2.split(QLatin1Char('-'), Qt::KeepEmptyParts);
-#endif
   int y2 = dlist2.count() > 0 ? dlist2[0].toInt(&ok) : now.year();
   if(!ok) {
     y2 = now.year();
