@@ -97,7 +97,7 @@ bool Manager::installTemplate(const QString& file_) {
 
   bool success = true;
 
-  static const QRegularExpression digitsDashRx(QLatin1String("^\\d+-"));
+  static const QRegularExpression digitsDashRx(QStringLiteral("^\\d+-"));
   // is there a better way to figure out if the url points to a XSL file or a tar archive
   // than just trying to open it?
   KTar archive(file_);
@@ -133,7 +133,7 @@ bool Manager::installTemplate(const QString& file_) {
   if(xslFile.isEmpty()) {
     success = false;
   } else {
-    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("KNewStuffFiles"));
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("KNewStuffFiles"));
     config.writeEntry(file_, allFiles);
     config.writeEntry(xslFile, file_);
   }
@@ -163,7 +163,7 @@ bool Manager::removeTemplateByName(const QString& name_) {
 
   QString xslFile = userTemplates().value(name_);
   if(!xslFile.isEmpty()) {
-    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("KNewStuffFiles"));
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("KNewStuffFiles"));
     QString file = config.readEntry(xslFile, QString());
     if(!file.isEmpty()) {
       return removeTemplate(file);
@@ -181,7 +181,7 @@ bool Manager::removeTemplate(const QString& file_) {
   }
   GUI::CursorSaver cs;
 
-  KConfigGroup fileGroup(KSharedConfig::openConfig(), QLatin1String("KNewStuffFiles"));
+  KConfigGroup fileGroup(KSharedConfig::openConfig(), QStringLiteral("KNewStuffFiles"));
   QStringList files = fileGroup.readEntry(file_, QStringList());
 
   if(files.isEmpty()) {
@@ -225,7 +225,7 @@ bool Manager::installScript(const QString& file_) {
   QString exeFile;
   QString sourceName;
 
-  static const QRegularExpression digitsDashRx(QLatin1String("^\\d+-"));
+  static const QRegularExpression digitsDashRx(QStringLiteral("^\\d+-"));
   if(archive.open(QIODevice::ReadOnly)) {
     const KArchiveDirectory* archiveDir = archive.directory();
     exeFile = findEXE(archiveDir);
@@ -295,7 +295,7 @@ bool Manager::installScript(const QString& file_) {
   cg.writeEntry("NewStuffName", sourceName);
   cg.writeEntry("DeleteOnRemove", true);
 
-  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("KNewStuffFiles"));
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("KNewStuffFiles"));
   config.writeEntry(sourceName, realFile);
   config.writeEntry(realFile, scriptFolder);
   //  myDebug() << "exeFile = " << exeFile;
@@ -320,7 +320,7 @@ bool Manager::removeScriptByName(const QString& name_) {
     return false;
   }
 
-  KConfigGroup config(KSharedConfig::openConfig(), QLatin1String("KNewStuffFiles"));
+  KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("KNewStuffFiles"));
   QString file = config.readEntry(name_, QString());
   if(!file.isEmpty()) {
     return removeScript(file);
@@ -339,7 +339,7 @@ bool Manager::removeScript(const QString& file_) {
   const QString sourceName = fi.completeBaseName();
 
   bool success = true;
-  KConfigGroup fileGroup(KSharedConfig::openConfig(), QLatin1String("KNewStuffFiles"));
+  KConfigGroup fileGroup(KSharedConfig::openConfig(), QStringLiteral("KNewStuffFiles"));
   QString scriptFolder = fileGroup.readEntry(file_, QString());
   if(scriptFolder.isEmpty()) {
     scriptFolder = fileGroup.readEntry(realFile, QString());
