@@ -209,11 +209,11 @@ void ComparisonTest::testChoiceField() {
   coll->addField(field);
 
   Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll));
-  entry1->setField(field->name(), allowed.at(0));
+  entry1->setField(field, allowed.at(0));
   Tellico::Data::EntryPtr entry2(new Tellico::Data::Entry(coll));
-  entry2->setField(field->name(), allowed.at(1));
+  entry2->setField(field, allowed.at(1));
 
-  Tellico::FieldComparison* comp = Tellico::FieldComparison::create(field);
+  auto comp = Tellico::FieldComparison::create(field);
   // even though the second allowed value would sort first, it comes second in the list
   QCOMPARE(comp->compare(entry1, entry2), -1);
 }
@@ -226,7 +226,7 @@ void ComparisonTest::testImage() {
   Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll));
   Tellico::Data::EntryPtr entry2(new Tellico::Data::Entry(coll));
 
-  Tellico::FieldComparison* comp = Tellico::FieldComparison::create(field);
+  auto comp = Tellico::FieldComparison::create(field);
   QCOMPARE(comp->compare(entry1, entry2), 0);
 
   QUrl u1 = QUrl::fromLocalFile(QFINDTESTDATA("data/img1.jpg"));
@@ -234,10 +234,10 @@ void ComparisonTest::testImage() {
   QUrl u2 = QUrl::fromLocalFile(QFINDTESTDATA("../../icons/128-apps-tellico.png"));
   QString id2 = Tellico::ImageFactory::addImage(u2);
 
-  entry1->setField(QLatin1String("image"), id1);
+  entry1->setField(QStringLiteral("image"), id1);
   QCOMPARE(comp->compare(entry1, entry2), 1);
-  entry2->setField(QLatin1String("image"), id1);
+  entry2->setField(QStringLiteral("image"), id1);
   QCOMPARE(comp->compare(entry1, entry2), 0);
-  entry2->setField(QLatin1String("image"), id2);
+  entry2->setField(QStringLiteral("image"), id2);
   QVERIFY(comp->compare(entry1, entry2) < 0);
 }
