@@ -230,8 +230,8 @@ void EntryComparisonTest::testVideoMatch() {
   QVERIFY(c->sameEntry(e1, e2) >= Tellico::EntryComparison::ENTRY_PERFECT_MATCH);
 
   // imdb link should be perfect match by itself, ignoring host
-  e1->setField(QStringLiteral("imdb"), QLatin1String("https://www.imdb.com/title/tt1856080/"));
-  e2->setField(QStringLiteral("imdb"), QLatin1String("https://us.imdb.com/title/tt1856080/"));
+  e1->setField(QStringLiteral("imdb"), QStringLiteral("https://www.imdb.com/title/tt1856080/"));
+  e2->setField(QStringLiteral("imdb"), QStringLiteral("https://us.imdb.com/title/tt1856080/"));
   e2->setField(QStringLiteral("title"), QString());
   e2->setField(QStringLiteral("year"), QString());
   QVERIFY(c->sameEntry(e1, e2) >= Tellico::EntryComparison::ENTRY_PERFECT_MATCH);
