@@ -22,12 +22,15 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <config.h>
 
 #include "fieldwidgettest.h"
 #include "../gui/boolfieldwidget.h"
 #include "../gui/choicefieldwidget.h"
 #include "../gui/datefieldwidget.h"
 #include "../gui/datewidget.h"
+#include "../gui/imagefieldwidget.h"
+#include "../gui/imagewidget.h"
 #include "../gui/linefieldwidget.h"
 #include "../gui/lineedit.h"
 #include "../gui/numberfieldwidget.h"
@@ -39,19 +42,28 @@
 #include "../gui/urlfieldwidget.h"
 #include "../document.h"
 #include "../images/imagefactory.h"
+#include "../images/image.h"
 #include "../collections/bookcollection.h"
 #include "../collectionfactory.h"
 
 #include <KLocalizedString>
 #include <KTextEdit>
 #include <KUrlRequester>
+#include <KComboBox>
+#ifdef HAVE_KSANE
+#include <KSaneWidget>
+#endif
 
 #include <QTest>
 #include <QCheckBox>
+#include <QToolButton>
 #include <QComboBox>
 #include <QTableWidget>
 #include <QSignalSpy>
 #include <QStandardPaths>
+#include <QMimeData>
+#include <QLoggingCategory>
+#include <QClipboard>
 
 // needs a GUI
 QTEST_MAIN( FieldWidgetTest )
@@ -61,6 +73,8 @@ void FieldWidgetTest::initTestCase() {
   KLocalizedString::setApplicationDomain("tellico");
   Tellico::RegisterCollection<Tellico::Data::BookCollection> registerBook(Tellico::Data::Collection::Book, "book");
   Tellico::ImageFactory::init();
+  KLocalizedString::setApplicationDomain("tellico");
+  QLoggingCategory::setFilterRules(QStringLiteral("tellico.debug = true\ntellico.info = true"));
 }
 
 void FieldWidgetTest::testBool() {
@@ -189,9 +203,30 @@ void FieldWidgetTest::testDate() {
   QCOMPARE(dw->date(), sputnik);
   QCOMPARE(spy.count(), 1);
 
-  w.clear();
+  dw->setDate(QStringLiteral("-1-2")); // try an edge case
+  QCOMPARE(w.text(), QStringLiteral("-01-02"));
+
+  w.setText(QString());
   QVERIFY(w.text().isEmpty());
   QVERIFY(dw->date().isNull());
+
+  auto spinWidgets = dw->findChildren<Tellico::GUI::SpinBox *>();
+  QCOMPARE(spinWidgets.size(), 2);
+  auto yearSpin = spinWidgets.at(1);
+  auto daySpin = spinWidgets.at(0);
+  auto monthCombo = dw->findChild<KComboBox *>();
+
+  monthCombo->setCurrentIndex(1); // index 0 is the empty string
+  QCOMPARE(w.text(), QStringLiteral("-01-"));
+  QCOMPARE(spy.count(), 2);
+
+  yearSpin->setValue(1900);
+  QCOMPARE(w.text(), QStringLiteral("1900-01-"));
+  QCOMPARE(spy.count(), 3);
+
+  daySpin->setValue(2);
+  QCOMPARE(w.text(), QStringLiteral("1900-01-02"));
+  QCOMPARE(spy.count(), 4);
 }
 
 void FieldWidgetTest::testLine() {
@@ -228,6 +263,21 @@ void FieldWidgetTest::testLine() {
   // verify completion object is removed
   QVERIFY(!le->compObj()); // don't call completionObject() since it recreates it
 
+  w.setEditEnabled(false); // mimic editing multiple entries
+  w.editMultiple(false);
+  auto editMultiple = w.m_editMultiple;
+  QVERIFY(editMultiple);
+  QVERIFY(!le->isEnabled());
+  QVERIFY(!editMultiple->isChecked());
+  QVERIFY(editMultiple->isHidden());
+
+  w.setEditEnabled(true);
+  w.editMultiple(true);
+  QVERIFY(le->isEnabled());
+  QVERIFY(editMultiple->isChecked());
+  QVERIFY(!editMultiple->isHidden());
+  QCOMPARE(spy.count(), 3);
+
   w.clear();
   QVERIFY(w.text().isEmpty());
 }
@@ -248,31 +298,31 @@ void FieldWidgetTest::testPara() {
   QCOMPARE(spy.count(), 0);
 
   // test replacing EOL
-  edit->setText(QLatin1String("test1\ntest2"));
+  edit->setText(QStringLiteral("test1\ntest2"));
   QCOMPARE(w.text(), QStringLiteral("test1<br/>test2"));
   QCOMPARE(spy.count(), 1);
 
-  field->setProperty(QLatin1String("replace-line-feeds"), QLatin1String("false"));
+  field->setProperty(QStringLiteral("replace-line-feeds"), QStringLiteral("false"));
   w.updateField(field, field);
-  edit->setText(QLatin1String("test1\ntest2"));
+  edit->setText(QStringLiteral("test1\ntest2"));
   QCOMPARE(w.text(), QStringLiteral("test1\ntest2"));
 
-  field->setProperty(QLatin1String("replace-line-feeds"), QLatin1String("true"));
+  field->setProperty(QStringLiteral("replace-line-feeds"), QStringLiteral("true"));
   w.updateField(field, field);
-  w.setText(QLatin1String("test1<br>test2"));
+  w.setText(QStringLiteral("test1<br>test2"));
   QCOMPARE(edit->toPlainText(), QStringLiteral("test1\ntest2"));
   QCOMPARE(w.text(), QStringLiteral("test1<br/>test2"));
 
-  field->setProperty(QLatin1String("replace-line-feeds"), QString());
+  field->setProperty(QStringLiteral("replace-line-feeds"), QString());
   w.updateField(field, field);
-  w.setText(QLatin1String("test1<br>test2"));
+  w.setText(QStringLiteral("test1<br>test2"));
   QCOMPARE(edit->toPlainText(), QStringLiteral("test1\ntest2"));
   QCOMPARE(w.text(), QStringLiteral("test1<br/>test2"));
 
   w.clear();
   QVERIFY(w.text().isEmpty());
 
-  QString textWithEmoji = QString::fromUtf8("Title 🏡️");
+  QString textWithEmoji = QStringLiteral("Title 🏡️");
   w.setText(textWithEmoji);
   QCOMPARE(w.text(), textWithEmoji);
 }
@@ -302,6 +352,10 @@ void FieldWidgetTest::testNumber() {
   QCOMPARE(w.text(), QStringLiteral("3"));
   QCOMPARE(spy.count(), 1);
 
+  sb->stepBy(2);
+  QCOMPARE(w.text(), QStringLiteral("5"));
+  QCOMPARE(spy.count(), 2);
+
   // now set AllowMultiple and check that the spinbox is deleted and a line edit is used
   field->setFlags(Tellico::Data::Field::AllowMultiple);
   w.setText(QStringLiteral("1"));
@@ -311,14 +365,14 @@ void FieldWidgetTest::testNumber() {
   QVERIFY(le);
   // value should be unchanged
   QCOMPARE(w.text(), QStringLiteral("1"));
-  QCOMPARE(spy.count(), 1);
+  QCOMPARE(spy.count(), 2);
   w.setText(QStringLiteral("1;2"));
   QCOMPARE(w.text(), QStringLiteral("1; 2"));
-  QCOMPARE(spy.count(), 1);
+  QCOMPARE(spy.count(), 2);
 
   le->setText(QStringLiteral("2"));
   QCOMPARE(w.text(), QStringLiteral("2"));
-  QCOMPARE(spy.count(), 2);
+  QCOMPARE(spy.count(), 3);
 
   w.clear();
   QVERIFY(w.text().isEmpty());
@@ -356,6 +410,13 @@ void FieldWidgetTest::testRating() {
   rating->setText(QStringLiteral("6"));
   QCOMPARE(w.text(), QStringLiteral("6"));
   QCOMPARE(spy.count(), 0);
+
+  auto clearButton = rating->findChild<QToolButton *>();
+  QVERIFY(clearButton);
+  QVERIFY(clearButton->isEnabled());
+  clearButton->click();
+  QVERIFY(w.text().isEmpty());
+  QCOMPARE(spy.count(), 0);
 }
 
 void FieldWidgetTest::testTable() {
@@ -407,6 +468,16 @@ void FieldWidgetTest::testTable() {
   QCOMPARE(spy.count(), 3);
   QCOMPARE(w.text(), QStringLiteral("true::new text"));
 
+  auto rowCount = tw->rowCount();
+  tw->setCurrentCell(rowCount-1, 0);
+  auto item = new QTableWidgetItem(QStringLiteral("last row"));
+  tw->setItem(rowCount-1, 0, item);
+  QCOMPARE(spy.count(), 4);
+  tw->setCurrentCell(rowCount-1, 1);
+  // verify a new row is created since the last row was edited
+  QCOMPARE(rowCount+1, tw->rowCount());
+  delete tw->takeItem(rowCount-1, 0);
+
   w.m_col = 0;
   w.renameColumn(QStringLiteral("col name"));
   QCOMPARE(tw->horizontalHeaderItem(0)->text(), QStringLiteral("col name"));
@@ -415,7 +486,7 @@ void FieldWidgetTest::testTable() {
   w.updateField(field, field);
   QCOMPARE(tw->columnCount(), 4);
   QCOMPARE(w.text(), QStringLiteral("true::new text"));
-  QCOMPARE(spy.count(), 3);
+  QCOMPARE(spy.count(), 4);
 
   w.clear();
   QVERIFY(w.text().isEmpty());
@@ -458,7 +529,138 @@ void FieldWidgetTest::testUrl() {
   // will be exactly up one level
   QCOMPARE(w.text(), link.url());
 
-  w.clear();
+  w.setText(QString());
   QVERIFY(w.text().isEmpty());
   QVERIFY(requester->url().isEmpty());
 }
+
+void FieldWidgetTest::testImage() {
+  Tellico::Data::FieldPtr field(new Tellico::Data::Field(QStringLiteral("img"),
+                                                         QStringLiteral("img"),
+                                                         Tellico::Data::Field::Image));
+  Tellico::GUI::ImageFieldWidget w(field, nullptr);
+  QSignalSpy spy(&w, &Tellico::GUI::FieldWidget::valueChanged);
+  int spyCount = 0;
+  QVERIFY(w.expands());
+  QVERIFY(w.text().isEmpty());
+  auto imgWidget = dynamic_cast<Tellico::GUI::ImageWidget*>(w.widget());
+  QVERIFY(imgWidget);
+  auto linkOnlyCb = imgWidget->findChild<QCheckBox *>();
+  QVERIFY(linkOnlyCb);
+  QVERIFY(!linkOnlyCb->isChecked());
+  QVERIFY(linkOnlyCb->isEnabled());
+  auto editButton = imgWidget->findChild<QToolButton *>();
+  QVERIFY(editButton);
+  QVERIFY(!editButton->isEnabled());
+
+  field->setProperty(QStringLiteral("link"), QStringLiteral("true"));
+  w.updateField(field, field);
+  QVERIFY(linkOnlyCb->isChecked());
+  linkOnlyCb->setChecked(false);
+  QVERIFY(!linkOnlyCb->isChecked());
+  QVERIFY(!editButton->isEnabled());
+
+  QUrl u = QUrl::fromLocalFile(QFINDTESTDATA("../../icons/128-apps-tellico.png"));
+  // addImage(url, quiet, referer, link)
+  QString id = Tellico::ImageFactory::addImage(u, false, QUrl(), true);
+  QCOMPARE(id, u.url());
+  w.setText(id);
+  QCOMPARE(w.text(), id);
+  // it's a link-only image so linkOnlyCb should be checked now
+  QVERIFY(linkOnlyCb->isChecked());
+  QVERIFY(linkOnlyCb->isEnabled());
+  QVERIFY(editButton->isEnabled());
+
+  auto img = Tellico::ImageFactory::self()->imageById(id);
+  imgWidget->copyImage();
+  QCOMPARE(img, QApplication::clipboard()->image(QClipboard::Clipboard));
+  if(QApplication::clipboard()->supportsSelection()) {
+    QCOMPARE(img, QApplication::clipboard()->image(QClipboard::Selection));
+  }
+
+  // unlink the image
+  linkOnlyCb->click();
+  QVERIFY(!linkOnlyCb->isChecked());
+  id = w.text();
+  QVERIFY(u.url() != id);
+  QVERIFY(!id.isEmpty());
+  QCOMPARE(spy.count(), ++spyCount);
+
+  w.clear();
+  QVERIFY(w.text().isEmpty());
+  QVERIFY(!linkOnlyCb->isChecked());
+  QVERIFY(linkOnlyCb->isEnabled());
+  QVERIFY(!editButton->isEnabled());
+
+  // different image than before
+  imgWidget->m_img = QFINDTESTDATA("../../icons/64-apps-tellico.png");
+  imgWidget->slotFinished(); // finished editing the image, now load
+  const auto id64 = w.text();
+  QVERIFY(!linkOnlyCb->isChecked());
+  QVERIFY(!linkOnlyCb->isEnabled());
+  QVERIFY(editButton->isEnabled());
+  QCOMPARE(spy.count(), ++spyCount);
+
+  QImage img32(QFINDTESTDATA("../../icons/32-apps-tellico.png"));
+  QVERIFY(!img32.isNull());
+  QPixmap pix = QPixmap::fromImage(img32);
+  QVERIFY(!pix.isNull());
+
+  // test a drop event for an image
+  QScopedPointer<QMimeData> mimeData(new QMimeData);
+  mimeData->setImageData(pix);
+  QDragEnterEvent event1(QPoint(), Qt::DropAction::CopyAction, mimeData.data(),
+                         Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier);
+  QVERIFY(qApp->sendEvent(imgWidget, &event1));
+  QDropEvent event2(QPoint(), Qt::DropAction::CopyAction, mimeData.data(),
+                    Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier);
+  QVERIFY(qApp->sendEvent(imgWidget, &event2));
+  QCOMPARE(spy.count(), ++spyCount);
+  // KDE CI has a different hash. TODO: figure out why
+//  QCOMPARE(w.text(), QLatin1String("a1e8417ef84d1ce7f37620810f125093.png"));
+  QCOMPARE(pix, imgWidget->m_pixmap);
+
+  w.clear();
+
+  // test a drop event for text
+  mimeData.reset(new QMimeData);
+  mimeData->setText(QFINDTESTDATA("../../icons/64-apps-tellico.png"));
+  QDragEnterEvent event3(QPoint(), Qt::DropAction::CopyAction, mimeData.data(),
+                         Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier);
+  QVERIFY(qApp->sendEvent(imgWidget, &event3));
+  QDropEvent event4(QPoint(), Qt::DropAction::CopyAction, mimeData.data(),
+                    Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier);
+  QVERIFY(qApp->sendEvent(imgWidget, &event4));
+  QCOMPARE(spy.count(), ++spyCount);
+  QCOMPARE(w.text(), id64);
+
+  QVERIFY(!linkOnlyCb->isChecked());
+  QVERIFY(linkOnlyCb->isEnabled()); // image can now be linked
+  QVERIFY(editButton->isEnabled());
+
+  w.setText(QString());
+  // confirm clear
+  QVERIFY(w.text().isEmpty());
+  QVERIFY(imgWidget->m_pixmap.isNull());
+  QVERIFY(imgWidget->m_scaled.isNull());
+  QVERIFY(imgWidget->m_originalURL.isEmpty());
+
+#ifdef HAVE_KSANE
+  imgWidget->imageReady(img32); // nothing happens since there's no scan widget
+  QVERIFY(!linkOnlyCb->isChecked());
+  QCOMPARE(spy.count(), spyCount); // no increment
+
+  imgWidget->m_saneWidget = new KSaneIface::KSaneWidget(imgWidget);
+  imgWidget->imageReady(img32);
+  QVERIFY(!linkOnlyCb->isChecked());
+  QVERIFY(!linkOnlyCb->isEnabled());
+  QVERIFY(editButton->isEnabled());
+  QCOMPARE(spy.count(), ++spyCount);
+
+  // try to unlink the image, which shouldn't work
+  linkOnlyCb->click();
+  QVERIFY(!linkOnlyCb->isChecked());
+  // KDE CI has a different hash. TODO: figure out why
+//  QCOMPARE(w.text(), QLatin1String("dde5bf2cbd90fad8635a26dfb362e0ff.png"));
+#endif
+}
