@@ -34,6 +34,8 @@
 #include "../entry.h"
 #include "../document.h"
 #include "../images/imagefactory.h"
+#include "../models/entrygroupmodel.h"
+#include "../models/modelmanager.h"
 #include "../utils/datafileregistry.h"
 #include "../config/tellico_config.h"
 
@@ -88,17 +90,27 @@ void HtmlExporterTest::testHtml() {
   // save the document, so the images get copied out of the .tc file into the local image directory
   QVERIFY(doc->saveDocument(QUrl::fromLocalFile(fileName)));
 
+  auto groupModel = new Tellico::EntryGroupModel(this);
+  Tellico::ModelManager::self()->setGroupModel(groupModel);
+
   Tellico::Data::CollPtr coll = doc->collection();
   QVERIFY(coll);
 
-  Tellico::Export::HTMLExporter exp(coll);
+  Tellico::Export::HTMLExporter exp(coll, Tellico::Data::Document::self()->URL());
   exp.setEntries(coll->entries());
   exp.setExportEntryFiles(true);
   exp.setEntryXSLTFile(QStringLiteral("Fancy"));
   exp.setColumns(QStringList() << QStringLiteral("Title") << QStringLiteral("Gift")
                                << QStringLiteral("Rating") << QStringLiteral("Front Cover"));
+  exp.setSortTitles({QStringLiteral("Title"), QStringLiteral("Gift"), QStringLiteral("Rating")});
+  exp.setPrintGrouped(true);
+  exp.setGroupBy({QStringLiteral("binding"), QStringLiteral("author")});
+  exp.setMaxImageSize(250, 250);
   exp.setURL(QUrl::fromLocalFile(tempDirName + "/testHtml.html"));
 
+  QCOMPARE(exp.formatString(), QLatin1String("HTML"));
+  QVERIFY(exp.fileFilter().contains(QLatin1String(";;All Files (*)")));
+
   QString output = exp.text();
   QVERIFY(!output.isEmpty());
 
@@ -110,6 +122,10 @@ void HtmlExporterTest::testHtml() {
   QVERIFY(output.contains(QStringLiteral("href=\"testHtml_files/Catching_Fire__The_Second_Book_of_the_Hunger_Games_-1.html")));
   // verify relative location of image file
   QVERIFY(output.contains(QStringLiteral("src=\"testHtml_files/17b54b2a742c6d342a75f122d615a793.jpeg")));
+  // verify group heading
+  QVERIFY(output.contains(QStringLiteral("<td class=\"groupName\" colspan=\"4\">Collins, Suzanne</td>")));
+  // verify max image size
+  QVERIFY(output.contains(QStringLiteral("height=\"250\"")));
 
   QVERIFY(exp.exec());
   QFile f(tempDirName + "/testHtml.html");
@@ -153,7 +169,7 @@ void HtmlExporterTest::testHtmlTitle() {
   Tellico::Data::EntryPtr e(new Tellico::Data::Entry(coll));
   coll->addEntries(e);
 
-  Tellico::Export::HTMLExporter exporter(coll);
+  Tellico::Export::HTMLExporter exporter(coll, QUrl());
   exporter.setEntries(coll->entries());
 
   QString output = exporter.text();
@@ -161,7 +177,7 @@ void HtmlExporterTest::testHtmlTitle() {
   QVERIFY(!output.isEmpty());
 
   // check https://bugs.kde.org/show_bug.cgi?id=348381
-  static const QRegularExpression rx("<title>.*</title>");
+  static const QRegularExpression rx(QStringLiteral("<title>.*</title>"));
   QRegularExpressionMatch match = rx.match(output);
   QVERIFY(match.hasMatch());
   QCOMPARE(match.captured(), QStringLiteral("<title>Robby's Books</title>"));
@@ -176,7 +192,7 @@ void HtmlExporterTest::testReportHtml() {
   e->setField(QStringLiteral("rating"), QStringLiteral("3"));
   coll->addEntries(e);
 
-  Tellico::Export::HTMLExporter exporter(coll);
+  Tellico::Export::HTMLExporter exporter(coll, QUrl());
   exporter.setXSLTFile(QFINDTESTDATA("../../xslt/report-templates/Column_View.xsl"));
   exporter.setEntries(coll->entries());
 
@@ -184,13 +200,13 @@ void HtmlExporterTest::testReportHtml() {
   QVERIFY(!output.isEmpty());
 
   // check that cdate is passed correctly
-  static const QRegularExpression rx("div class=\"box header-right\"><span>(.*)</span");
+  static const QRegularExpression rx(QStringLiteral("div class=\"box header-right\"><span>(.*)</span"));
   QRegularExpressionMatch match = rx.match(output);
   QVERIFY(match.hasMatch());
   QCOMPARE(match.captured(1), QLocale().toString(QDate::currentDate()));
 
   // test image location in tmp directory
-  Tellico::Export::HTMLExporter exporter2(coll);
+  Tellico::Export::HTMLExporter exporter2(coll, QUrl());
   exporter2.setXSLTFile(QFINDTESTDATA("../../xslt/report-templates/Image_List.xsl"));
   exporter2.setEntries(coll->entries());
   exporter2.setColumns(QStringList() << QStringLiteral("Title") << QStringLiteral("Rating"));
@@ -211,7 +227,7 @@ void HtmlExporterTest::testReportHtml() {
 
 void HtmlExporterTest::testDirectoryNames() {
   Tellico::Data::CollPtr coll(new Tellico::Data::BookCollection(true));
-  Tellico::Export::HTMLExporter exp(coll);
+  Tellico::Export::HTMLExporter exp(coll, QUrl());
 
   exp.setURL(QUrl::fromLocalFile(QDir::homePath() + QStringLiteral("/test.html")));
   QCOMPARE(exp.fileDir(), QUrl::fromLocalFile(QDir::homePath() + QStringLiteral("/test_files/")));
@@ -240,14 +256,14 @@ void HtmlExporterTest::testTemplatesTidy() {
                            QStringLiteral("yes") };
   QProcessEnvironment tidyEnv;
   // suppress warning about no tidyrc file
-  tidyEnv.insert("HTML_TIDY", "/dev/null");
+  tidyEnv.insert(QStringLiteral("HTML_TIDY"), QStringLiteral("/dev/null"));
 
   QUrl url = QUrl::fromLocalFile(tellicoFile);
   Tellico::Import::TellicoImporter importer(url);
   Tellico::Data::CollPtr coll = importer.collection();
   QVERIFY(coll);
 
-  Tellico::Export::HTMLExporter exporter(coll);
+  Tellico::Export::HTMLExporter exporter(coll, url);
   exporter.setParseDOM(false); // shows error for <wbr> tags and is not necessary for check
   exporter.setEntries(coll->entries());
   exporter.setXSLTFile(xsltFile);
@@ -306,6 +322,18 @@ void HtmlExporterTest::testTemplatesTidy_data() {
     QTest::newRow(test1.toUtf8().constData()) << file << ted;
     QTest::newRow(test2.toUtf8().constData()) << file << moody;
   }
+  QDir xsltDir(QFINDTESTDATA(QStringLiteral("../../xslt/tellico2html.xsl")));
+  xsltDir.cdUp();
+  foreach(const QString& file, xsltDir.entryList({"tellico*.xsl"}, QDir::Files)) {
+    // only want selected of these templates
+    if(file.contains(QLatin1String("tellico2gcstar")) ||
+       file.contains(QLatin1String("tellico2onix")) ||
+       file.contains(QLatin1String("tellico-common"))) continue;
+    const QString test1 = file + QLatin1String(":ted");
+    const QString test2 = file + QLatin1String(":moody");
+    QTest::newRow(test1.toUtf8().constData()) << file << ted;
+    QTest::newRow(test2.toUtf8().constData()) << file << moody;
+  }
 }
 
 void HtmlExporterTest::testEntryTemplates() {
@@ -317,7 +345,7 @@ void HtmlExporterTest::testEntryTemplates() {
   Tellico::Data::CollPtr coll = importer.collection();
   QVERIFY(coll);
 
-  Tellico::Export::HTMLExporter exporter(coll);
+  Tellico::Export::HTMLExporter exporter(coll, url);
   exporter.setParseDOM(false); // shows error for <wbr> tags and is not necessary for check
   exporter.setEntries(coll->entries());
   exporter.setXSLTFile(xsltFile);
@@ -344,3 +372,38 @@ void HtmlExporterTest::testEntryTemplates_data() {
     QTest::newRow(file.toUtf8().constData()) << file;
   }
 }
+
+void HtmlExporterTest::testPrinting() {
+  auto groupModel = new Tellico::EntryGroupModel(this);
+  Tellico::ModelManager::self()->setGroupModel(groupModel);
+
+  Tellico::Config::setImageLocation(Tellico::Config::ImagesInFile);
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA(QStringLiteral("data/with-image.tc")));
+  Tellico::Import::TellicoImporter importer(url);
+  Tellico::Data::CollPtr coll = importer.collection();
+  QVERIFY(coll);
+
+  // mimic PrintHandler::generateHtml()
+  Tellico::Export::HTMLExporter exporter(coll, url);
+  exporter.setEntries(coll->entries());
+  exporter.setXSLTFile(QFINDTESTDATA(QStringLiteral("../../xslt/tellico-printing.xsl")));
+  exporter.setPrintHeaders(true);
+  exporter.setPrintGrouped(true);
+  exporter.setGroupBy({ QStringLiteral("author") });
+  exporter.setColumns({ QStringLiteral("Title"),
+                        QStringLiteral("Gift"),
+                        QStringLiteral("Rating"),
+                        QStringLiteral("Front Cover")});
+  exporter.setMaxImageSize(100, 100);
+  exporter.setOptions(Tellico::Export::ExportUTF8 | Tellico::Export::ExportFormatted);
+
+  const QString output = exporter.text();
+  QVERIFY(!output.isEmpty());
+
+  // verify relative location of image pics
+  QVERIFY(output.contains(QStringLiteral("pics/checkmark.png")));
+  // verify relative location of image file
+  QVERIFY(output.contains(QStringLiteral("/17b54b2a742c6d342a75f122d615a793.jpeg")));
+  // verify max image size
+  QVERIFY(output.contains(QStringLiteral("height=\"100\"")));
+}
