@@ -48,15 +48,22 @@ void ItunesFetcherTest::testBurningEdge() {
   cg.writeEntry("Custom Fields", QStringLiteral("itunes"));
 
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Album, Tellico::Fetch::Keyword,
-                                       QStringLiteral("Burning Edge Of Dawn"));
+                                       QStringLiteral("Burning Edge of Dawn"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::ItunesFetcher(this));
   fetcher->readConfig(cg);
 
-  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 5);
 
-  QCOMPARE(results.size(), 1);
-
-  Tellico::Data::EntryPtr entry = results.at(0);
+  Tellico::Data::EntryPtr entry;
+  // apparently there are other albums with similar names
+  for(const auto& tmpEntry : results) {
+    if(tmpEntry->field(QStringLiteral("artist")) == QLatin1String("Andrew Peterson")) {
+      entry = tmpEntry;
+      break;
+    } else {
+      qDebug() << "Skipping" << tmpEntry->title();
+    }
+  }
   QVERIFY(entry);
 
   QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("The Burning Edge of Dawn"));
@@ -160,7 +167,7 @@ void ItunesFetcherTest::testEscapingGravity() {
   QVERIFY(entry);
 
   QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Escaping Gravity: My Quest to Transform NASA and Launch a New Space Age"));
-  QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("Lori Garver; Walter Isaacson; Grover Gardner"));
+  QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("Lori Garver"));
   QCOMPARE(entry->field(QStringLiteral("pub_year")), QStringLiteral("2022"));
   QCOMPARE(entry->field(QStringLiteral("binding")), QStringLiteral("E-Book"));
   QCOMPARE(entry->field(QStringLiteral("genre")), QStringLiteral("Biographies & Memoirs"));
