@@ -76,7 +76,7 @@ void MobyGamesFetcherTest::testTitle() {
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 5);
   Tellico::Data::EntryPtr entry;
   for(const auto& testEntry : std::as_const(results)) {
-    if(testEntry->field("platform") == QLatin1String("Nintendo Wii")) {
+    if(testEntry->field(QStringLiteral("platform")) == QLatin1String("Nintendo Wii")) {
       entry = testEntry;
       break;
     } else {
@@ -157,7 +157,7 @@ void MobyGamesFetcherTest::testRaw() {
   QCOMPARE(entry->field("year"), QStringLiteral("2006"));
   QCOMPARE(entry->field("platform"), QStringLiteral("Nintendo Wii"));
   QVERIFY(entry->field("genre").contains(QStringLiteral("Action")));
-//  QCOMPARE(entry->field("certification"), QStringLiteral("Teen"));
+  QCOMPARE(entry->field("certification"), QStringLiteral("Teen"));
   QCOMPARE(entry->field("pegi"), QStringLiteral("PEGI 12"));
   QCOMPARE(entry->field("publisher"), QStringLiteral("Nintendo Co., Ltd."));
   QCOMPARE(entry->field("developer"), QStringLiteral("Nintendo EAD"));
