@@ -44,15 +44,12 @@
 #include "../config/tellico_config.h"
 
 #include <KLocalizedString>
+#include <KProtocolInfo>
 
 #include <QTest>
 #include <QNetworkInterface>
 #include <QDate>
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#include <QTextCodec>
-#else
 #include <QStringEncoder>
-#endif
 #include <QStandardPaths>
 #include <QLoggingCategory>
 #include <QSignalSpy>
@@ -201,7 +198,7 @@ void TellicoReadTest::testBibtexCollection() {
   auto filter1 = filterList.front();
   QCOMPARE(filter1->name(), QStringLiteral("1990"));
 
-  Tellico::Export::TellicoXMLExporter exporter(coll);
+  Tellico::Export::TellicoXMLExporter exporter(coll, url);
   exporter.setEntries(coll->entries());
   exporter.setOptions(exporter.options() | Tellico::Export::ExportComplete);
   Tellico::Import::TellicoImporter importer2(exporter.text());
@@ -251,7 +248,7 @@ void TellicoReadTest::testTableData() {
   QVERIFY(coll);
   QCOMPARE(coll->entryCount(), 3);
 
-  Tellico::Export::TellicoXMLExporter exporter(coll);
+  Tellico::Export::TellicoXMLExporter exporter(coll, url);
   exporter.setEntries(coll->entries());
   Tellico::Import::TellicoImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
@@ -372,8 +369,7 @@ void TellicoReadTest::testLocalImageLink() {
   QVERIFY(!Tellico::ImageFactory::self()->hasImageInMemory(imageId));
   QVERIFY(!Tellico::ImageFactory::self()->hasImageInfo(imageId));
 
-  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("/data/image_link_test.xml"));
-  QFile f(url.toLocalFile());
+  QFile f(QFINDTESTDATA("/data/image_link_test.xml"));
   QVERIFY(f.exists());
   QVERIFY(f.open(QIODevice::ReadOnly | QIODevice::Text));
 
@@ -508,7 +504,7 @@ void TellicoReadTest::testDataImage() {
   QString fileText = in.readAll();
   // replace %COVER% with image file location
   fileText.replace(QSL("%COVER%"),
-                   QString::fromUtf8("data:image/png;base64,") +
+                   QLatin1String("data:image/png;base64,") +
                    QLatin1String(imgData));
 
   Tellico::Import::TellicoImporter importer(fileText);
@@ -555,18 +551,11 @@ void TellicoReadTest::testXMLHandler_data() {
   QTest::newRow("LATIN1") << QByteArray("<?xml version=\"1.0\" encoding=\"LATIN1\"?>\n<x>value</x>")
                           << QStringLiteral("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<x>value</x>") << true;
 
-  QString usa = QString::fromUtf8("США");
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-  QTextCodec* cp1251 = QTextCodec::codecForName("cp1251");
-  QByteArray usaBytes = QByteArray("<?xml version=\"1.0\" encoding=\"cp1251\"?>\n<x>")
-                      + cp1251->fromUnicode(usa)
-                      + QByteArray("</x>");
-#else
+  QString usa = QStringLiteral("США");
   QStringEncoder toCp1251("cp1251");
   QByteArray usaBytes = QByteArray("<?xml version=\"1.0\" encoding=\"cp1251\"?>\n<x>")
                       + QByteArray(toCp1251(usa))
                       + QByteArray("</x>");
-#endif
   QString usaString = QStringLiteral("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<x>")
                     + usa
                     + QStringLiteral("</x>");
@@ -596,7 +585,11 @@ void TellicoReadTest::testXmlName_data() {
   QTest::newRow("colon:") << false << QSL("colon:") << QSL("colon");
   QTest::newRow("Svět")   << true  << QSL("Svět")   << QSL("Svět");
   QTest::newRow("<test>") << false << QSL("<test>") << QSL("test");
+#if LIBXML_VERSION >= 21500
+  QTest::newRow("is-€:")  << false << QSL("is-€:")  << QSL("is-€");
+#else
   QTest::newRow("is-€:")  << false << QSL("is-€:")  << QSL("is-");
+#endif
 }
 
 void TellicoReadTest::testRecoverXmlName() {
@@ -618,8 +611,13 @@ void TellicoReadTest::testRecoverXmlName_data() {
                            << QByteArray("<fields><field name=\"nr\"/></fields><nrs><nr>x</nr></nrs>");
   QTest::newRow("<nr:>4")  << QByteArray("<fields><field d=\"nr:\" name=\"nr:\" d=\"nr:\"/></fields><nr:>x</nr:>")
                            << QByteArray("<fields><field d=\"nr:\" name=\"nr\" d=\"nr:\"/></fields><nr>x</nr>");
+#if LIBXML_VERSION >= 21500
+  QTest::newRow("<is-€:>") << QByteArray("<fields><field name=\"is-€:\"/></fields><is-€:>x</is-€:>")
+                           << QByteArray("<fields><field name=\"is-€\"/></fields><is-€>x</is-€>");
+#else
   QTest::newRow("<is-€:>") << QByteArray("<fields><field name=\"is-€:\"/></fields><is-€:>x</is-€:>")
                            << QByteArray("<fields><field name=\"is-\"/></fields><is->x</is->");
+#endif
 }
 
 void TellicoReadTest::testBug418067() {
@@ -679,9 +677,9 @@ void TellicoReadTest::testRelativeLink() {
   QVERIFY(handler.isValid());
 
   Tellico::Data::Document::self()->setURL(url); // set the base url
-  QUrl expected = url.resolved(QUrl(QLatin1String("collectorz/image.png")));
+  QUrl expected = url.resolved(QUrl(QStringLiteral("collectorz/image.png")));
 
-  Tellico::Export::TellicoXMLExporter exp(coll);
+  Tellico::Export::TellicoXMLExporter exp(coll, url);
   exp.setEntries(coll->entries());
   exp.setURL(url);
   QString output = handler.applyStylesheet(exp.text());
@@ -707,7 +705,7 @@ void TellicoReadTest::testEmptyFirstTableRow() {
   const QStringList rows = Tellico::FieldFormat::splitTable(entry->field(QSL("table")));
   QCOMPARE(rows.count(), 2);
 
-  Tellico::Export::TellicoXMLExporter exporter(coll);
+  Tellico::Export::TellicoXMLExporter exporter(coll, url);
   exporter.setEntries(coll->entries());
   Tellico::Import::TellicoImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
@@ -728,7 +726,7 @@ void TellicoReadTest::testBug443845() {
   Tellico::Data::EntryPtr entry1(new Tellico::Data::Entry(coll));
   entry1->setField(QStringLiteral("title"), badTitle);
   coll->addEntries(entry1);
-  Tellico::Export::TellicoXMLExporter exporter(coll);
+  Tellico::Export::TellicoXMLExporter exporter(coll, QUrl());
   exporter.setEntries(coll->entries());
   // exported XML should not contain the illegal control character
   QVERIFY(!exporter.text().contains(QChar(0x0C)));
@@ -746,7 +744,7 @@ void TellicoReadTest::testBug443845() {
 
 void TellicoReadTest::testEmoji() {
   // https://www.fileformat.info/info/unicode/char/1f3e1/index.htm
-  QString textWithEmoji = QString::fromUtf8("Title 🏡️");
+  const QString textWithEmoji = QStringLiteral("Title 🏡️");
   // stripping control codes should not affect the emoji
   QCOMPARE(Tellico::removeControlCodes(textWithEmoji), textWithEmoji);
 
@@ -759,7 +757,7 @@ void TellicoReadTest::testEmoji() {
   entry1->setField(QStringLiteral("title"), textWithEmoji);
   QCOMPARE(entry1->title(), textWithEmoji);
   coll->addEntries(entry1);
-  Tellico::Export::TellicoXMLExporter exporter(coll);
+  Tellico::Export::TellicoXMLExporter exporter(coll, QUrl());
   exporter.setEntries(coll->entries());
 
   Tellico::Import::TellicoImporter importer(exporter.text());
@@ -794,13 +792,19 @@ void TellicoReadTest::testXmlWithJunk() {
 }
 
 void TellicoReadTest::testRemote() {
+  if(!hasNetwork()) QSKIP("This test requires network access", SkipSingle);
+
+  if(!KProtocolInfo::isKnownProtocol(QStringLiteral("fish"))) {
+    QSKIP("This test requires the KIO 'fish' protocol", SkipSingle);
+  }
+
   Tellico::Config::setImageLocation(Tellico::Config::ImagesInLocalDir);
   QString tempDirName;
   QTemporaryDir tempDir;
   QVERIFY(tempDir.isValid());
   tempDir.setAutoRemove(true);
   tempDirName = tempDir.path();
-  QString image = QLatin1String("17b54b2a742c6d342a75f122d615a793.jpeg");
+  QString image = QStringLiteral("17b54b2a742c6d342a75f122d615a793.jpeg");
   QString fileName = tempDirName +      QLatin1String("/with-local-image.tc");
   QString imageDirName = tempDirName +  QLatin1String("/with-local-image_files/");
   QString imageFileName = imageDirName + image;
@@ -812,11 +816,8 @@ void TellicoReadTest::testRemote() {
   QVERIFY(QFile::copy(QFINDTESTDATA(QLatin1String("data/with-local-image_files/") + image),
                       imageFileName));
 
-  QUrl localUrl = QUrl::fromLocalFile(fileName);
   QUrl remoteUrl(QLatin1String("fish://localhost/") + fileName);
-
-  // use the localUrl since the CI doesn't support fish protocol
-  Tellico::Data::Document::self()->openDocument(localUrl);
+  Tellico::Data::Document::self()->openDocument(remoteUrl);
 
   // Document has a 500 msec timer to load images
   qApp->processEvents();
@@ -828,7 +829,7 @@ void TellicoReadTest::testRemote() {
   QVERIFY(!coll->entries().isEmpty());
   auto entry = coll->entries().front();
   QVERIFY(entry);
-  auto cover = entry->field(QLatin1String("cover"));
+  auto cover = entry->field(QStringLiteral("cover"));
   QVERIFY(!cover.isEmpty());
   QCOMPARE(cover, image);
   QVERIFY(!Tellico::ImageFactory::self()->hasImageInMemory(image));
@@ -848,7 +849,7 @@ void TellicoReadTest::testImageLocation() {
 
   Tellico::Config::setImageLocation(Tellico::Config::ImagesInFile);
   const QString fileName = QFINDTESTDATA("data/with-local-image.tc");
-  const QString image = QLatin1String("17b54b2a742c6d342a75f122d615a793.jpeg");
+  const QString image = QStringLiteral("17b54b2a742c6d342a75f122d615a793.jpeg");
 
   Tellico::Data::Document::self()->openDocument(QUrl::fromLocalFile(fileName));
   Tellico::Data::CollPtr coll = Tellico::Data::Document::self()->collection();
@@ -856,7 +857,7 @@ void TellicoReadTest::testImageLocation() {
   QVERIFY(!coll->entries().isEmpty());
   auto entry = coll->entries().front();
   QVERIFY(entry);
-  auto cover = entry->field(QLatin1String("cover"));
+  auto cover = entry->field(QStringLiteral("cover"));
   QVERIFY(!cover.isEmpty());
   QCOMPARE(cover, image);
   QVERIFY(!Tellico::ImageFactory::self()->hasImageInMemory(image));
