@@ -72,7 +72,8 @@ void Z3950FetcherTest::testIsbn() {
 
   QCOMPARE(results.size(), 2);
 
-  Tellico::Data::EntryPtr entry = results.at(1);
+  Tellico::Data::EntryPtr entry = results.at(0);
+  if(!entry->title().startsWith("Found")) entry = results.at(1);
   QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Foundations of Qt development"));
   QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("Thelin, Johan."));
   QCOMPARE(entry->field(QStringLiteral("isbn")), QStringLiteral("1-59059-831-8"));
@@ -125,7 +126,7 @@ void Z3950FetcherTest::testPortugal() {
 //  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Bibtex, Tellico::Fetch::ISBN,
 //                                       QString::fromUtf8("972-706-024-2"));
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Bibtex, Tellico::Fetch::Title,
-                                       QString::fromUtf8("Memórias póstumas de Brás Cubas"));
+                                       QStringLiteral("Memórias póstumas de Brás Cubas"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::Z3950Fetcher(this,
                                                                         QStringLiteral("z3950.porbase.bnportugal.gov.pt"),
                                                                         210,
