@@ -155,11 +155,7 @@ bool AlexandriaExporter::writeFile(const QDir& dir_, Tellico::Data::EntryPtr ent
 
   QTextStream ts(&file);
   // alexandria uses utf-8 all the time
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-  ts.setCodec("UTF-8");
-#else
   ts.setEncoding(QStringConverter::Utf8);
-#endif
 
   ts << "--- !ruby/object:Alexandria::Book\n";
   ts << "authors:\n";
@@ -183,7 +179,7 @@ bool AlexandriaExporter::writeFile(const QDir& dir_, Tellico::Data::EntryPtr ent
   // I have no idea how to debug ruby, so err on safe side and add quotes
   ts << "isbn: \"" << isbn << "\"\n";
 
-  static const QRegularExpression rx(QLatin1String("<br/?>"), QRegularExpression::CaseInsensitiveOption);
+  static const QRegularExpression rx(QStringLiteral("<br/?>"), QRegularExpression::CaseInsensitiveOption);
   tmp = entry_->formattedField(QStringLiteral("comments"), format);
   tmp.replace(rx, QStringLiteral("\n"));
   ts << "notes: |-\n";
