@@ -46,9 +46,9 @@ public:
    */
   virtual ~GriffithImporter();
 
-  virtual bool canImport(int type) const Q_DECL_OVERRIDE;
-  virtual void beginXSLTHandler(XSLTHandler* handler) Q_DECL_OVERRIDE;
-  virtual QWidget* widget(QWidget*) Q_DECL_OVERRIDE { return nullptr; }
+  virtual bool canImport(int type) const override;
+  virtual void beginXSLTHandler(XSLTHandler* handler) override;
+  virtual QWidget* widget(QWidget*) override { return nullptr; }
 
 private:
   Data::CollPtr m_coll;
