@@ -26,7 +26,6 @@
 #include "xslthandler.h"
 #include "tellicoxmlexporter.h"
 #include "../collection.h"
-#include "../document.h"
 #include "../core/filehandler.h"
 #include "../core/netaccess.h"
 #include "../config/tellico_config.h"
@@ -69,7 +68,8 @@ extern "C" {
 
 using Tellico::Export::HTMLExporter;
 
-HTMLExporter::HTMLExporter(Tellico::Data::CollPtr coll_) : Tellico::Export::Exporter(coll_),
+HTMLExporter::HTMLExporter(Tellico::Data::CollPtr coll_, const QUrl& baseUrl_)
+  : Tellico::Export::Exporter(coll_),
     m_handler(nullptr),
     m_printHeaders(true),
     m_printGrouped(false),
@@ -85,6 +85,7 @@ HTMLExporter::HTMLExporter(Tellico::Data::CollPtr coll_) : Tellico::Export::Expo
     m_checkPrintGrouped(nullptr),
     m_checkExportEntryFiles(nullptr),
     m_checkExportImages(nullptr),
+    m_baseUrl(baseUrl_),
     m_xsltFile(QStringLiteral("tellico2html.xsl")) {
 }
 
@@ -101,6 +102,51 @@ QString HTMLExporter::fileFilter() const {
   return i18n("HTML Files") + QLatin1String(" (*.html)") + QLatin1String(";;") + i18n("All Files") + QLatin1String(" (*)");
 }
 
+void HTMLExporter::setCollectionURL(const QUrl& url) {
+  m_collectionURL = url;
+  m_links.clear();
+}
+
+void HTMLExporter::setPrintHeaders(bool printHeaders) {
+  m_printHeaders = printHeaders;
+}
+
+void HTMLExporter::setPrintGrouped(bool printGrouped) {
+  m_printGrouped = printGrouped;
+}
+
+void HTMLExporter::setMaxImageSize(int w, int h) {
+  m_imageWidth = w;
+  m_imageHeight = h;
+}
+
+void HTMLExporter::setGroupBy(const QStringList& groupBy) {
+  m_groupBy = groupBy;
+}
+
+void HTMLExporter::setSortTitles(const QStringList& l) {
+  m_sort1 = l[0];
+  m_sort2 = l[1];
+  m_sort3 = l[2];
+}
+
+void HTMLExporter::setColumns(const QStringList& columns) {
+  m_columns = columns;
+}
+
+void HTMLExporter::setParseDOM(bool parseDOM) {
+  m_parseDOM = parseDOM;
+  reset();
+}
+
+void HTMLExporter::setExportEntryFiles(bool exportEntryFiles) {
+  m_exportEntryFiles = exportEntryFiles;
+}
+
+void HTMLExporter::setCustomHtml(const QString& html_) {
+  m_customHtml = html_;
+}
+
 void HTMLExporter::reset() {
   // since the ExportUTF8 option may have changed, need to delete handler
   delete m_handler;
@@ -236,7 +282,7 @@ QString HTMLExporter::text() {
   writeImages(coll);
 
   // now grab the XML
-  TellicoXMLExporter exporter(coll);
+  TellicoXMLExporter exporter(coll, m_baseUrl);
   exporter.setURL(url());
   exporter.setEntries(entries());
   exporter.setFields(fields());
@@ -296,7 +342,7 @@ QString HTMLExporter::text() {
 }
 
 void HTMLExporter::setFormattingOptions(Tellico::Data::CollPtr coll) {
-  QString file = Data::Document::self()->URL().fileName();
+  QString file = baseUrl().fileName();
   if(file != TC_I18N1(Tellico::untitledFilename)) {
     m_handler->addStringParam("filename", QFile::encodeName(file));
   }
@@ -318,11 +364,14 @@ void HTMLExporter::setFormattingOptions(Tellico::Data::CollPtr coll) {
   }
 
   if(sortTitles.count() > 0) {
-    m_handler->addStringParam("sort-name1", coll->fieldNameByTitle(sortTitles[0]).toUtf8());
+    auto f = coll->fieldByTitle(sortTitles[0]);
+    if(f) m_handler->addStringParam("sort-name1", f->name().toUtf8());
     if(sortTitles.count() > 1) {
-      m_handler->addStringParam("sort-name2", coll->fieldNameByTitle(sortTitles[1]).toUtf8());
+      f = coll->fieldByTitle(sortTitles[1]);
+      if(f) m_handler->addStringParam("sort-name2", f->name().toUtf8());
       if(sortTitles.count() > 2) {
-        m_handler->addStringParam("sort-name3", coll->fieldNameByTitle(sortTitles[2]).toUtf8());
+        f = coll->fieldByTitle(sortTitles[2]);
+        if(f) m_handler->addStringParam("sort-name3", f->name().toUtf8());
       }
     }
   }
@@ -337,7 +386,8 @@ void HTMLExporter::setFormattingOptions(Tellico::Data::CollPtr coll) {
       if(m_groupBy.count() > 1) {
         s = i18n("People");
       } else {
-        s = coll->fieldTitleByName(m_groupBy[0]);
+        auto f = coll->fieldByName(m_groupBy[0]);
+        if(f) s = f->title();
       }
       sortString = i18n("(grouped by %1)", s);
     }
@@ -381,7 +431,8 @@ void HTMLExporter::setFormattingOptions(Tellico::Data::CollPtr coll) {
 
   QStringList showFields;
   foreach(const QString& column, m_columns) {
-    showFields << coll->fieldNameByTitle(column);
+    auto f = coll->fieldByTitle(column);
+    if(f) showFields << f->name();
   }
   if(!showFields.isEmpty()) {
     m_handler->addStringParam("column-names", showFields.join(QLatin1String(" ")).toUtf8());
@@ -409,7 +460,7 @@ void HTMLExporter::setFormattingOptions(Tellico::Data::CollPtr coll) {
 void HTMLExporter::writeImages(Tellico::Data::CollPtr coll_) {
   // keep track of which image fields to write, this is for field titles
   StringSet imageFields;
-  foreach(const QString& column, m_columns) {
+  for(const QString& column : std::as_const(m_columns)) {
     if(coll_->fieldByTitle(column) && coll_->fieldByTitle(column)->type() == Data::Field::Image) {
       imageFields.add(column);
     }
@@ -462,28 +513,26 @@ void HTMLExporter::writeImages(Tellico::Data::CollPtr coll_) {
   const int processCount = 100; // process after every 100 events
 
   StringSet imageSet; // track which images are written
-  foreach(const QString& imageField, imageFields) {
+  for(const QString& imageField : std::as_const(imageFields)) {
     foreach(Data::EntryPtr entryIt, entries()) {
-      QString id = entryIt->field(imageField);
+      const QString id = entryIt->field(imageField);
       // if no id or is already written, continue
-      if(id.isEmpty() || imageSet.has(id)) {
+      if(id.isEmpty() || imageSet.contains(id)) {
         continue;
       }
       imageSet.add(id);
       // try writing
-      bool success = false;
       if(useTemp) {
         // for link-only images, no need to write it out
-        success = ImageFactory::imageInfo(id).linkOnly || ImageFactory::writeCachedImage(id, ImageFactory::TempDir);
+        if(!ImageFactory::imageInfo(id).linkOnly) {
+          ImageFactory::writeCachedImage(id, ImageFactory::TempDir);
+        }
       } else {
         const Data::Image& img = ImageFactory::imageById(id);
+        if(img.isNull()) continue;
         QUrl target = imgDir;
         target.setPath(target.path() + QLatin1Char('/') + id);
-        success = !img.isNull() && FileHandler::writeDataURL(target, img.byteArray(), true);
-      }
-      if(!success) {
-        myWarning() << "unable to write image file: "
-                    << imgDir.path() << id;
+        FileHandler::writeDataURL(target, img.byteArray(), true /* force */);
       }
 
       if(++count == processCount) {
@@ -596,9 +645,8 @@ QString HTMLExporter::fileDirName() const {
   return fi.completeBaseName() + QLatin1String("_files/");
 }
 
-// how ugly is this?
-const xmlChar* HTMLExporter::handleLink(const xmlChar* link_) {
-  return reinterpret_cast<xmlChar*>(qstrdup(handleLink(QString::fromUtf8(reinterpret_cast<const char*>(link_))).toUtf8().constData()));
+QString HTMLExporter::handleLink(const xmlChar* link_) {
+  return handleLink(QString::fromUtf8(reinterpret_cast<const char*>(link_)));
 }
 
 QString HTMLExporter::handleLink(const QString& link_) {
@@ -653,12 +701,8 @@ QString HTMLExporter::handleLink(const QString& link_) {
   return m_links[link_];
 }
 
-const xmlChar* HTMLExporter::analyzeInternalCSS(const xmlChar* str_) {
-  return reinterpret_cast<xmlChar*>(qstrdup(analyzeInternalCSS(QString::fromUtf8(reinterpret_cast<const char*>(str_))).toUtf8().constData()));
-}
-
-QString HTMLExporter::analyzeInternalCSS(const QString& str_) {
-  QString str = str_;
+QByteArray HTMLExporter::analyzeInternalCSS(const xmlChar* str_) {
+  QString str = QString::fromUtf8(reinterpret_cast<const char*>(str_));
   int start = 0;
   int end = 0;
   const QString url = QStringLiteral("url(");
@@ -677,7 +721,7 @@ QString HTMLExporter::analyzeInternalCSS(const QString& str_) {
 
     str.replace(start, end-start, handleLink(str.mid(start, end-start)));
   }
-  return str;
+  return str.toUtf8();
 }
 
 void HTMLExporter::createDir() {
@@ -713,7 +757,7 @@ bool HTMLExporter::copyFiles() {
   createDir();
   QUrl target;
   for(QList<QUrl>::ConstIterator it = m_files.constBegin(); it != m_files.constEnd() && !m_cancelled; ++it, ++j) {
-    if(m_copiedFiles.has((*it).url())) {
+    if(m_copiedFiles.contains((*it).url())) {
       continue;
     }
 
@@ -756,7 +800,7 @@ bool HTMLExporter::writeEntryFiles() {
   // I can't reliable encode a string as a URI, so I'm punting, and I'll just replace everything but
   // a-zA-Z0-9 with an underscore. This MUST match the filename template in tellico2html.xsl
   // the id is used so uniqueness is guaranteed
-  static const QRegularExpression badChars(QLatin1String("[^-a-zA-Z0-9]"));
+  static const QRegularExpression badChars(QStringLiteral("[^-a-zA-Z0-9]"));
   FieldFormat::Request formatted = (options() & Export::ExportFormatted ?
                                                    FieldFormat::ForceFormat :
                                                    FieldFormat::AsIsFormat);
@@ -766,7 +810,7 @@ bool HTMLExporter::writeEntryFiles() {
 
   GUI::CursorSaver cs(Qt::WaitCursor);
 
-  HTMLExporter exporter(collection());
+  HTMLExporter exporter(collection(), m_baseUrl);
   long opt = options() | Export::ExportForce;
   opt &= ~ExportProgress;
   exporter.setFields(fields());
@@ -834,7 +878,7 @@ bool HTMLExporter::writeEntryFiles() {
   KIO::JobFlags flags = KIO::DefaultFlags;
   if(!m_widget) flags |= KIO::HideProgressInfo;
 
-  foreach(const QString& dataImageName, dataImages) {
+  for(const QString& dataImageName : std::as_const(dataImages)) {
     // copy the image out of the resources
     QImage dataImage(QStringLiteral(":/icons/") + dataImageName);
     if(dataImage.isNull()) {
@@ -888,7 +932,8 @@ void HTMLExporter::parseDOM(xmlNode* node_) {
                                                        nodeName == "TD"))) */
           xmlChar* value = xmlGetProp(node_, attr->name);
           if(value) {
-            xmlSetProp(node_, attr->name, handleLink(value));
+            const auto newValue = handleLink(value).toUtf8();
+            xmlSetProp(node_, attr->name, reinterpret_cast<const xmlChar*>(newValue.constData()));
             xmlFree(value);
           }
           // each node only has one significant attribute, so break now
@@ -904,7 +949,8 @@ void HTMLExporter::parseDOM(xmlNode* node_) {
       }
       xmlChar* value = xmlNodeGetContent(nodeToReplace);
       if(value) {
-        xmlNodeSetContent(nodeToReplace, analyzeInternalCSS(value));
+        auto newValue = analyzeInternalCSS(value);
+        xmlNodeSetContent(nodeToReplace, reinterpret_cast<const xmlChar*>(newValue.constData()));
         xmlFree(value);
       }
       // no longer need to parse child text nodes
