@@ -163,7 +163,7 @@ Tellico::Data::CollPtr RISImporter::collection() {
       risFields.insert(ris, f);
     }
   }
-  emit signalTotalSteps(this, urls().count() * 100);
+  Q_EMIT signalTotalSteps(this, urls().count() * 100);
 
   if(text().isEmpty()) {
     int count = 0;
@@ -212,7 +212,7 @@ void RISImporter::readText(const QString& text_, int n, const QHash<QString, Tel
   // however, at least one website (Springer) outputs RIS with no space after the final "ER -"
   // so just strip the white space later
   // also be gracious and allow any amount of space before hyphen
-  static const QRegularExpression rx(QLatin1String("^(\\w\\w)\\s+-(.*)$"));
+  static const QRegularExpression rx(QStringLiteral("^(\\w\\w)\\s+-(.*)$"));
   QString currLine, nextLine;
   for(currLine = t.readLine(); !m_cancelled && !t.atEnd(); currLine = nextLine, j += currLine.length()) {
     nextLine = t.readLine();
@@ -312,7 +312,7 @@ void RISImporter::readText(const QString& text_, int n, const QHash<QString, Tel
     entry->setField(f, value);
 
     if(showProgress && j%stepSize == 0) {
-      emit signalProgress(this, n*100 + 100*j/length);
+      Q_EMIT signalProgress(this, n*100 + 100*j/length);
     }
   }
 
@@ -337,8 +337,8 @@ Tellico::Data::FieldPtr RISImporter::fieldByTag(const QString& tag_) {
     f = new Data::Field(QStringLiteral("pdf"), i18n("PDF"), Data::Field::URL);
     f->setProperty(QStringLiteral("ris"), QStringLiteral("L1"));
     f->setCategory(i18n("Miscellaneous"));
+    m_coll->addField(f);
   }
-  m_coll->addField(f);
   return f;
 }
 
@@ -356,7 +356,7 @@ bool RISImporter::maybeRIS(const QUrl& url_) {
   // and then first text line must be valid RIS
   QTextStream t(&text);
 
-  static const QRegularExpression rx(QLatin1String("^(\\w\\w)\\s+-(.*)$"));
+  static const QRegularExpression rx(QStringLiteral("^(\\w\\w)\\s+-(.*)$"));
   QString currLine;
   for(currLine = t.readLine(); !t.atEnd(); currLine = t.readLine()) {
     if(currLine.trimmed().isEmpty()) {
