@@ -55,27 +55,24 @@ TellicoImporter::TellicoImporter(const QString& text_) : DataImporter(text_),
     m_cancelled(false), m_hasImages(false), m_buffer(nullptr), m_zip(nullptr), m_imgDir(nullptr) {
 }
 
-TellicoImporter::~TellicoImporter() {
-}
+TellicoImporter::~TellicoImporter() = default;
 
 Tellico::Data::CollPtr TellicoImporter::collection() {
   if(m_coll) {
     return m_coll;
   }
 
-  QByteArray s; // read first 5 characters
-  if(source() == URL) {
-    if(!fileRef().open()) {
-      return Data::CollPtr();
+  auto getFirstData = [this] {
+    if(source() == URL && fileRef().open()) {
+      return fileRef().file()->peek(5);
+    } else {
+      return QByteArray(data().constData(), 6);
     }
-    QIODevice* f = fileRef().file();
-    s = f->peek(5);
-  } else {
-    if(data().size() < 5) {
-      m_format = Error;
-      return Data::CollPtr();
-    }
-    s = QByteArray(data().constData(), 6);
+  };
+  const auto s = getFirstData(); // read first 5 characters
+  if(s.size() < 5) {
+    m_format = Error;
+    return Data::CollPtr();
   }
 
   // hack for processEvents and deletion
@@ -83,7 +80,7 @@ Tellico::Data::CollPtr TellicoImporter::collection() {
 
   // need to decide if the data is xml text, or a zip file
   // if the first 5 characters are <?xml then treat it like text
-  if(s.size() >= 5 && s[0] == '<' && s[1] == '?' && s[2] == 'x' && s[3] == 'm' && s[4] == 'l') {
+  if(s[0] == '<' && s[1] == '?' && s[2] == 'x' && s[3] == 'm' && s[4] == 'l') {
     m_format = XML;
     loadXMLData(source() == URL ? fileRef().file()->readAll() : data(), true);
   } else {
@@ -104,7 +101,7 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
 
   const int blockSize = qMax(data_.size()/100 + 1, MIN_BLOCK_SIZE);
   int pos = 0;
-  emit signalTotalSteps(this, data_.size());
+  Q_EMIT signalTotalSteps(this, data_.size());
 
   // hack to allow processEvents
   QPointer<TellicoImporter> thisPtr(this);
@@ -129,7 +126,7 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
     }
     pos += blockSize;
     if(thisPtr && showProgress) {
-      emit signalProgress(this, pos);
+      Q_EMIT signalProgress(this, pos);
       qApp->processEvents();
     }
   }
