@@ -30,19 +30,13 @@
 
 #include "../datavectors.h"
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#define TC_STRINGVIEW const QStringRef&
-#else
-#define TC_STRINGVIEW QStringView
-#endif
-
 namespace Tellico {
   namespace Import {
     namespace SAX {
 
 class StateData {
 public:
-  StateData() : syntaxVersion(0), collType(0), defaultFields(false), loadImages(false), hasImages(false), showImageLoadErrors(true) {}
+  StateData() : syntaxVersion(0), collType(0), defaultFields(false), loadImages(false), hasImages(false), showImageLoadErrors(true), imagePathsAsLinks(false) {}
   QString text;
   QString error;
   QString ns; // namespace
@@ -62,6 +56,7 @@ public:
   bool loadImages;
   bool hasImages;
   bool showImageLoadErrors;
+  bool imagePathsAsLinks;
   QUrl baseUrl;
 };
 
@@ -70,15 +65,15 @@ public:
   StateHandler(StateData* data) : d(data) {}
   virtual ~StateHandler() {}
 
-  virtual bool start(TC_STRINGVIEW nsUri, TC_STRINGVIEW localName, const QXmlStreamAttributes& attributes) = 0;
-  virtual bool   end(TC_STRINGVIEW nsUri, TC_STRINGVIEW localName) = 0;
+  virtual bool start(QStringView nsUri, QStringView localName, const QXmlStreamAttributes& attributes) = 0;
+  virtual bool   end(QStringView nsUri, QStringView localName) = 0;
 
-  StateHandler* nextHandler(TC_STRINGVIEW nsUri, TC_STRINGVIEW localName);
+  StateHandler* nextHandler(QStringView nsUri, QStringView localName);
 protected:
   StateData* d;
 private:
   Q_DISABLE_COPY(StateHandler)
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW)  { return nullptr; }
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView)  { return nullptr; }
 };
 
 class NullHandler : public StateHandler {
@@ -86,8 +81,8 @@ public:
   NullHandler(StateData* data) : StateHandler(data) {}
   virtual ~NullHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override { return true; }
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override { return true; }
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override { return true; }
+  virtual bool   end(QStringView, QStringView) override { return true; }
 };
 
 class RootHandler : public StateHandler {
@@ -95,11 +90,11 @@ public:
   RootHandler(StateData* data) : StateHandler(data) {}
   virtual ~RootHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override { return true; }
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override { return true; }
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override { return true; }
+  virtual bool   end(QStringView, QStringView) override { return true; }
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class DocumentHandler : public StateHandler {
@@ -107,11 +102,11 @@ public:
   DocumentHandler(StateData* data) : StateHandler(data) {}
   virtual ~DocumentHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class CollectionHandler : public StateHandler {
@@ -119,11 +114,11 @@ public:
   CollectionHandler(StateData* data) : StateHandler(data) {}
   virtual ~CollectionHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class FieldsHandler : public StateHandler {
@@ -131,11 +126,11 @@ public:
   FieldsHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldsHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class FieldHandler : public StateHandler {
@@ -143,11 +138,11 @@ public:
   FieldHandler(StateData* data) : StateHandler(data), isI18n(false) {}
   virtual ~FieldHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
   bool isI18n;
 };
 
@@ -156,8 +151,8 @@ public:
   FieldPropertyHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldPropertyHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
   QString m_propertyName;
@@ -168,8 +163,8 @@ public:
   BibtexPreambleHandler(StateData* data) : StateHandler(data) {}
   virtual ~BibtexPreambleHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 };
 
 class BibtexMacrosHandler : public StateHandler {
@@ -177,11 +172,11 @@ public:
   BibtexMacrosHandler(StateData* data) : StateHandler(data) {}
   virtual ~BibtexMacrosHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class BibtexMacroHandler : public StateHandler {
@@ -189,8 +184,8 @@ public:
   BibtexMacroHandler(StateData* data) : StateHandler(data) {}
   virtual ~BibtexMacroHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
   QString m_macroName;
@@ -201,11 +196,11 @@ public:
   EntryHandler(StateData* data) : StateHandler(data) {}
   virtual ~EntryHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class FieldValueContainerHandler : public StateHandler {
@@ -213,11 +208,11 @@ public:
   FieldValueContainerHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldValueContainerHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class FieldValueHandler : public StateHandler {
@@ -226,11 +221,11 @@ public:
     , m_i18n(false), m_validateISBN(false) {}
   virtual ~FieldValueHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
   bool m_i18n;
   bool m_validateISBN;
 };
@@ -240,8 +235,8 @@ public:
   DateValueHandler(StateData* data) : StateHandler(data) {}
   virtual ~DateValueHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 };
 
 class TableColumnHandler : public StateHandler {
@@ -249,8 +244,8 @@ public:
   TableColumnHandler(StateData* data) : StateHandler(data) {}
   virtual ~TableColumnHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 };
 
 class ImagesHandler : public StateHandler {
@@ -258,11 +253,11 @@ public:
   ImagesHandler(StateData* data) : StateHandler(data) {}
   virtual ~ImagesHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class ImageHandler : public StateHandler {
@@ -271,8 +266,8 @@ public:
     , m_link(false), m_width(0), m_height(0) {}
   virtual ~ImageHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
   QString m_format;
@@ -287,11 +282,11 @@ public:
   FiltersHandler(StateData* data) : StateHandler(data) {}
   virtual ~FiltersHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class FilterHandler : public StateHandler {
@@ -299,11 +294,11 @@ public:
   FilterHandler(StateData* data) : StateHandler(data) {}
   virtual ~FilterHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class FilterRuleHandler : public StateHandler {
@@ -311,8 +306,8 @@ public:
   FilterRuleHandler(StateData* data) : StateHandler(data) {}
   virtual ~FilterRuleHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 };
 
 class BorrowersHandler : public StateHandler {
@@ -320,11 +315,11 @@ public:
   BorrowersHandler(StateData* data) : StateHandler(data) {}
   virtual ~BorrowersHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class BorrowerHandler : public StateHandler {
@@ -332,11 +327,11 @@ public:
   BorrowerHandler(StateData* data) : StateHandler(data) {}
   virtual ~BorrowerHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
-  virtual StateHandler* nextHandlerImpl(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual StateHandler* nextHandlerImpl(QStringView, QStringView) override;
 };
 
 class LoanHandler : public StateHandler {
@@ -345,8 +340,8 @@ public:
     , m_id(-1), m_inCalendar(false) {}
   virtual ~LoanHandler() {}
 
-  virtual bool start(TC_STRINGVIEW, TC_STRINGVIEW, const QXmlStreamAttributes&) override;
-  virtual bool   end(TC_STRINGVIEW, TC_STRINGVIEW) override;
+  virtual bool start(QStringView, QStringView, const QXmlStreamAttributes&) override;
+  virtual bool   end(QStringView, QStringView) override;
 
 private:
   int m_id;
