@@ -32,7 +32,6 @@
 #include <KUrlRequester>
 #include <KUser>
 #include <KConfigGroup>
-#include <kio_version.h>
 
 #include <QLabel>
 #include <QGroupBox>
@@ -42,7 +41,8 @@
 using namespace Tellico;
 using Tellico::Export::XSLTExporter;
 
-XSLTExporter::XSLTExporter(Data::CollPtr coll_) : Export::Exporter(coll_),
+XSLTExporter::XSLTExporter(Data::CollPtr coll_, const QUrl& baseUrl_)
+  : Export::Exporter(coll_, baseUrl_),
     m_widget(nullptr),
     m_URLRequester(nullptr) {
 }
@@ -56,17 +56,23 @@ QString XSLTExporter::fileFilter() const {
 }
 
 bool XSLTExporter::exec() {
-  QUrl u = m_URLRequester->url();
+  QUrl u;
+  if(m_URLRequester) {
+    u = m_URLRequester->url();
+  }
+  if(u.isEmpty() || !u.isValid()) {
+    u = m_xsltFile;
+  }
   if(u.isEmpty() || !u.isValid()) {
     return false;
   }
-  //  XSLTHandler handler(FileHandler::readXMLFile(url));
+
   XSLTHandler handler(u);
   handler.addStringParam("date", QDate::currentDate().toString(Qt::ISODate).toLatin1());
   handler.addStringParam("time", QTime::currentTime().toString(Qt::ISODate).toLatin1());
   handler.addStringParam("user", KUser(KUser::UseRealUserID).loginName().toLatin1());
 
-  TellicoXMLExporter exporter(collection());
+  TellicoXMLExporter exporter(collection(), baseUrl());
   exporter.setEntries(entries());
   exporter.setFields(fields());
   exporter.setOptions(options());
@@ -96,17 +102,9 @@ QWidget* XSLTExporter::widget(QWidget* parent_) {
 
   l->addWidget(gbox);
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 108, 0)
-  // these are in the old KDE4 filter format, not the Qt5 format
-  QString filter = QLatin1String("*.xsl|") + i18n("XSL Files")
-                 + QLatin1Char('\n')
-                 + QLatin1String("*|") + i18n("All Files");
-  m_URLRequester->setFilter(filter);
-#else
   const QStringList filters = {i18n("XSL Files") + QLatin1String(" (*.xsl)"),
                                i18n("All Files") + QLatin1String(" (*)")};
   m_URLRequester->setNameFilters(filters);
-#endif
   m_URLRequester->setMode(KFile::File | KFile::ExistingOnly);
   if(!m_xsltFile.isEmpty()) {
     m_URLRequester->setUrl(m_xsltFile);
