@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2003-2009 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2003-2025 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -22,6 +22,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <config.h> // for TELLICO_VERSION
+
 #include "tellico_utils.h"
 #include "string_utils.h"
 #include "../tellico_debug.h"
@@ -164,3 +166,9 @@ void Tellico::activateDialog(QDialog* dlg_) {
   dlg_->raise();
   dlg_->activateWindow();
 }
+
+void Tellico::addUserAgent(KIO::Job* job_) {
+  job_->addMetaData(QStringLiteral("SendUserAgent"), QStringLiteral("true"));
+  job_->addMetaData(QStringLiteral("UserAgent"),
+                    QStringLiteral("Tellico/%1 ( https://tellico-project.org )").arg(QStringLiteral(TELLICO_VERSION)));
+}
